@@ -24,7 +24,7 @@ sub _printop {
 }
 
 sub B::OP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     printf <<'EOT', class($op), $$op, $op->ppaddr, _printop($op->next), _printop($op->sibling), $op->targ, $op->type;
 %s (0x%lx)
 	op_ppaddr	%s
@@ -43,21 +43,21 @@ EOT
 }
 
 sub B::UNOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::OP::debug();
     printf "\top_first\t\%s\n", _printop($op->first);
 }
 
 sub B::BINOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::UNOP::debug();
     printf "\top_last \t\%s\n", _printop($op->last);
 }
 
 sub B::LOOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::BINOP::debug();
-    printf <<'EOT', _printop($op->redoop), _printop($op->nextop), _printop($op->lastop);
+    printf <<'EOT', < _printop($op->redoop), _printop($op->nextop), _printop($op->lastop);
 	op_redoop	%s
 	op_nextop	%s
 	op_lastop	%s
@@ -65,36 +65,36 @@ EOT
 }
 
 sub B::LOGOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::UNOP::debug();
     printf "\top_other\t\%s\n", _printop($op->other);
 }
 
 sub B::LISTOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::BINOP::debug();
     printf "\top_children\t\%d\n", $op->children;
 }
 
 sub B::PMOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::LISTOP::debug();
     printf "\top_pmreplroot\t0x\%x\n", ${$op->pmreplroot};
     printf "\top_pmreplstart\t0x\%x\n", ${$op->pmreplstart};
     if (ITHREADS) {
-      printf "\top_pmstashpv\t\%s\n", cstring($op->pmstashpv);
-      printf "\top_pmoffset\t\%d\n", $op->pmoffset;
+      printf "\top_pmstashpv\t\%s\n", < cstring( <$op->pmstashpv);
+      printf "\top_pmoffset\t\%d\n", < $op->pmoffset;
     } else {
-      printf "\top_pmstash\t\%s\n", cstring($op->pmstash);
+      printf "\top_pmstash\t\%s\n", < cstring( <$op->pmstash);
     }
-    printf "\top_precomp->precomp\t\%s\n", cstring($op->precomp);
-    printf "\top_pmflags\t0x\%x\n", $op->pmflags;
-    printf "\top_reflags\t0x\%x\n", $op->reflags;
+    printf "\top_precomp->precomp\t\%s\n", < cstring( <$op->precomp);
+    printf "\top_pmflags\t0x\%x\n", < $op->pmflags;
+    printf "\top_reflags\t0x\%x\n", < $op->reflags;
     $op->pmreplroot->debug;
 }
 
 sub B::COP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::OP::debug();
     my $cop_io = class($op->io) eq 'SPECIAL' ? '' : $op->io->as_string;
     printf <<'EOT', $op->label, $op->stashpv, $op->file, $op->cop_seq, $op->line, ${$op->warnings}, cstring($cop_io);
@@ -109,26 +109,26 @@ EOT
 }
 
 sub B::SVOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::OP::debug();
     printf "\top_sv\t\t0x\%x\n", ${$op->sv};
     $op->sv->debug;
 }
 
 sub B::PVOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::OP::debug();
-    printf "\top_pv\t\t\%s\n", cstring($op->pv);
+    printf "\top_pv\t\t\%s\n", < cstring( <$op->pv);
 }
 
 sub B::PADOP::debug {
-    my ($op) = @_;
+    my ($op) = < @_;
     $op->B::OP::debug();
-    printf "\top_padix\t\%ld\n", $op->padix;
+    printf "\top_padix\t\%ld\n", < $op->padix;
 }
 
 sub B::NULL::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     if ($$sv == ${sv_undef()}) {
 	print "&sv_undef\n";
     } else {
@@ -137,12 +137,12 @@ sub B::NULL::debug {
 }
 
 sub B::SV::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     if (!$$sv) {
-	print class($sv), " = NULL\n";
+	print < class($sv), " = NULL\n";
 	return;
     }
-    printf <<'EOT', class($sv), $$sv, $sv->REFCNT, $sv->FLAGS;
+    printf <<'EOT', < class($sv), $$sv, < $sv->REFCNT, < $sv->FLAGS;
 %s (0x%x)
 	REFCNT		%d
 	FLAGS		0x%x
@@ -150,7 +150,7 @@ EOT
 }
 
 sub B::RV::debug {
-    my ($rv) = @_;
+    my ($rv) = < @_;
     B::SV::debug($rv);
     printf <<'EOT', ${$rv->RV};
 	RV		0x%x
@@ -159,65 +159,65 @@ EOT
 }
 
 sub B::PV::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     $sv->B::SV::debug();
     my $pv = $sv->PV();
-    printf <<'EOT', cstring($pv), length($pv);
+    printf <<'EOT', < cstring($pv), length($pv);
 	xpv_pv		%s
 	xpv_cur		%d
 EOT
 }
 
 sub B::IV::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     $sv->B::SV::debug();
-    printf "\txiv_iv\t\t\%d\n", $sv->IV;
+    printf "\txiv_iv\t\t\%d\n", < $sv->IV;
 }
 
 sub B::NV::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     $sv->B::IV::debug();
-    printf "\txnv_nv\t\t\%s\n", $sv->NV;
+    printf "\txnv_nv\t\t\%s\n", < $sv->NV;
 }
 
 sub B::PVIV::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     $sv->B::PV::debug();
-    printf "\txiv_iv\t\t\%d\n", $sv->IV;
+    printf "\txiv_iv\t\t\%d\n", < $sv->IV;
 }
 
 sub B::PVNV::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     $sv->B::PVIV::debug();
-    printf "\txnv_nv\t\t\%s\n", $sv->NV;
+    printf "\txnv_nv\t\t\%s\n", < $sv->NV;
 }
 
 sub B::PVLV::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     $sv->B::PVNV::debug();
-    printf "\txlv_targoff\t\%d\n", $sv->TARGOFF;
-    printf "\txlv_targlen\t\%u\n", $sv->TARGLEN;
-    printf "\txlv_type\t\%s\n", cstring(chr($sv->TYPE));
+    printf "\txlv_targoff\t\%d\n", < $sv->TARGOFF;
+    printf "\txlv_targlen\t\%u\n", < $sv->TARGLEN;
+    printf "\txlv_type\t\%s\n", < cstring(chr($sv->TYPE));
 }
 
 sub B::BM::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     $sv->B::PVNV::debug();
-    printf "\txbm_useful\t\%d\n", $sv->USEFUL;
-    printf "\txbm_previous\t\%u\n", $sv->PREVIOUS;
-    printf "\txbm_rare\t\%s\n", cstring(chr($sv->RARE));
+    printf "\txbm_useful\t\%d\n", < $sv->USEFUL;
+    printf "\txbm_previous\t\%u\n", < $sv->PREVIOUS;
+    printf "\txbm_rare\t\%s\n", < cstring(chr($sv->RARE));
 }
 
 sub B::CV::debug {
-    my ($sv) = @_;
+    my ($sv) = < @_;
     $sv->B::PVNV::debug();
-    my ($stash) = $sv->STASH;
-    my ($start) = $sv->START;
-    my ($root) = $sv->ROOT;
-    my ($padlist) = $sv->PADLIST;
-    my ($file) = $sv->FILE;
-    my ($gv) = $sv->GV;
-    printf <<'EOT', $$stash, $$start, $$root, $$gv, $file, $sv->DEPTH, $padlist, ${$sv->OUTSIDE}, $sv->OUTSIDE_SEQ;
+    my ($stash) = < $sv->STASH;
+    my ($start) = < $sv->START;
+    my ($root) = < $sv->ROOT;
+    my ($padlist) = < $sv->PADLIST;
+    my ($file) = < $sv->FILE;
+    my ($gv) = < $sv->GV;
+    printf <<'EOT', $$stash, $$start, $$root, $$gv, $file, < $sv->DEPTH, $padlist, ${$sv->OUTSIDE}, < $sv->OUTSIDE_SEQ;
 	STASH		0x%x
 	START		0x%x
 	ROOT		0x%x
@@ -235,11 +235,11 @@ EOT
 }
 
 sub B::AV::debug {
-    my ($av) = @_;
+    my ($av) = < @_;
     $av->B::SV::debug;
-    my(@array) = $av->ARRAY;
-    print "\tARRAY\t\t(", join(", ", map("0x" . $$_, @array)), ")\n";
-    printf <<'EOT', scalar(@array), $av->MAX, $av->OFF;
+    my(@array) = @( < $av->ARRAY );
+    print "\tARRAY\t\t(", join(", ", map("0x" . $$_, < @array)), ")\n";
+    printf <<'EOT', scalar(nelems @array), < $av->MAX, < $av->OFF;
 	FILL		%d
 	MAX		%d
 	OFF		%d
@@ -247,16 +247,16 @@ EOT
 }
 
 sub B::GV::debug {
-    my ($gv) = @_;
+    my ($gv) = < @_;
     if (%done_gv{$$gv}++) {
-	printf "GV \%s::\%s\n", $gv->STASH->NAME, $gv->SAFENAME;
+	printf "GV \%s::\%s\n", < $gv->STASH->NAME, < $gv->SAFENAME;
 	return;
     }
-    my ($sv) = $gv->SV;
-    my ($av) = $gv->AV;
-    my ($cv) = $gv->CV;
+    my ($sv) = < $gv->SV;
+    my ($av) = < $gv->AV;
+    my ($cv) = < $gv->CV;
     $gv->B::SV::debug;
-    printf <<'EOT', $gv->SAFENAME, $gv->STASH->NAME, $gv->STASH, $$sv, $gv->GvREFCNT, $gv->FORM, $$av, ${$gv->HV}, ${$gv->EGV}, $$cv, $gv->CVGEN, $gv->LINE, $gv->FILE, $gv->GvFLAGS;
+    printf <<'EOT', < $gv->SAFENAME, < $gv->STASH->NAME, < $gv->STASH, $$sv, < $gv->GvREFCNT, < $gv->FORM, $$av, ${$gv->HV}, ${$gv->EGV}, $$cv, < $gv->CVGEN, < $gv->LINE, < $gv->FILE, < $gv->GvFLAGS;
 	NAME		%s
 	STASH		%s (0x%x)
 	SV		0x%x
