@@ -16,7 +16,7 @@ use warnings;
 use strict;
 use Carp;
 require Tie::Hash;
-@DB_File::HASHINFO::ISA = qw(Tie::Hash);
+@DB_File::HASHINFO::ISA = @( qw(Tie::Hash) );
 
 sub new
 {
@@ -49,7 +49,7 @@ sub FETCH
     my $self  = shift ;
     my $key   = shift ;
 
-    return $self->{GOT}{$key} if exists $self->{VALID}{$key}  ;
+    return $self->{GOT}->{$key} if exists $self->{VALID}->{$key}  ;
 
     my $pkg = ref $self ;
     croak "{$pkg}::FETCH - Unknown element '$key'" ;
@@ -62,13 +62,13 @@ sub STORE
     my $key   = shift ;
     my $value = shift ;
 
-    my $type = $self->{VALID}{$key};
+    my $type = $self->{VALID}->{$key};
 
     if ( $type )
     {
     	croak "Key '$key' not associated with a code reference" 
 	    if $type == 2 && !ref $value && ref $value ne 'CODE';
-        $self->{GOT}{$key} = $value ;
+        $self->{GOT}->{$key} = $value ;
         return ;
     }
     
@@ -81,9 +81,9 @@ sub DELETE
     my $self = shift ;
     my $key  = shift ;
 
-    if ( exists $self->{VALID}{$key} )
+    if ( exists $self->{VALID}->{$key} )
     {
-        delete $self->{GOT}{$key} ;
+        delete $self->{GOT}->{$key} ;
         return ;
     }
     
@@ -96,7 +96,7 @@ sub EXISTS
     my $self = shift ;
     my $key  = shift ;
 
-    exists $self->{VALID}{$key} ;
+    exists $self->{VALID}->{$key} ;
 }
 
 sub NotHere
@@ -116,7 +116,7 @@ package DB_File::RECNOINFO ;
 use warnings;
 use strict ;
 
-@DB_File::RECNOINFO::ISA = qw(DB_File::HASHINFO) ;
+@DB_File::RECNOINFO::ISA = @( qw(DB_File::HASHINFO) ) ;
 
 sub TIEHASH
 {
@@ -134,7 +134,7 @@ package DB_File::BTREEINFO ;
 use warnings;
 use strict ;
 
-@DB_File::BTREEINFO::ISA = qw(DB_File::HASHINFO) ;
+@DB_File::BTREEINFO::ISA = @( qw(DB_File::HASHINFO) ) ;
 
 sub TIEHASH
 {
@@ -178,17 +178,17 @@ require Tie::Hash;
 require Exporter;
 BEGIN {
     $use_XSLoader = 1 ;
-    { eval { require XSLoader } ; }
+    { try { require XSLoader } ; }
 
     if ($@) {
         $use_XSLoader = 0 ;
         require DynaLoader;
-        @ISA = qw(DynaLoader);
+        @ISA = @( qw(DynaLoader) );
     }
 }
 
 push @ISA, qw(Tie::Hash Exporter);
-@EXPORT = qw(
+@EXPORT = @( qw(
         $DB_BTREE $DB_HASH $DB_RECNO 
 
 	BTREEMAGIC
@@ -220,14 +220,14 @@ push @ISA, qw(Tie::Hash Exporter);
 	R_SNAPSHOT
 	__R_UNUSED
 
-);
+) );
 
-eval {
+try {
     # Make all Fcntl O_XXX constants available for importing
     require Fcntl;
-    my @O = grep m/^O_/, @Fcntl::EXPORT;
-    Fcntl->import(@O);  # first we import what we want to export
-    push(@EXPORT, @O);
+    my @O = @( grep m/^O_/, < @Fcntl::EXPORT );
+    Fcntl->import(< @O);  # first we import what we want to export
+    push(@EXPORT, < @O);
 };
 
 if ($use_XSLoader)
@@ -240,7 +240,7 @@ else
 
 sub tie_hash_or_array
 {
-    my (@arg) = @_ ;
+    my (@arg) = @( < @_ ) ;
     my $tieHASH = ( (caller(1))[[3]] =~ m/TIEHASH/ ) ;
 
     use File::Spec;
@@ -248,10 +248,10 @@ sub tie_hash_or_array
         if defined @arg[1] ;
 
     @arg[4] = tied %{ @arg[4] } 
-	if @arg +>= 5 && ref @arg[4] && (dump::view(@arg[4]) =~ m/=HASH/) && tied %{ @arg[4] } ;
+	if (nelems @arg) +>= 5 && ref @arg[4] && (dump::view(@arg[4]) =~ m/=HASH/) && tied %{ @arg[4] } ;
 
-    @arg[2] = O_CREAT()^|^O_RDWR() if @arg +>=3 && ! defined @arg[2];
-    @arg[3] = 0666               if @arg +>=4 && ! defined @arg[3];
+    @arg[2] = O_CREAT()^|^O_RDWR() if (nelems @arg) +>=3 && ! defined @arg[2];
+    @arg[3] = 0666               if (nelems @arg) +>=4 && ! defined @arg[3];
 
     # make recno in Berkeley DB version 2 (or better) work like 
     # recno in version 1.
@@ -266,17 +266,12 @@ sub tie_hash_or_array
 	chmod @arg[3] ? @arg[3] : 0666 , @arg[1] ;
     }
 
-    DoTie_($tieHASH, @arg) ;
+    DoTie_($tieHASH, < @arg) ;
 }
 
 sub TIEHASH
 {
-    tie_hash_or_array(@_) ;
-}
-
-sub TIEARRAY
-{
-    tie_hash_or_array(@_) ;
+    tie_hash_or_array(< @_) ;
 }
 
 sub CLEAR 
@@ -291,7 +286,7 @@ sub CLEAR
         push @keys, $key;
         $status = $self->seq($key, $value, R_NEXT());
     }
-    foreach $key (reverse @keys) {
+    foreach $key (reverse < @keys) {
         my $s = $self->del($key); 
     }
 }
@@ -315,180 +310,13 @@ sub STORESIZE
 }
  
 
-sub SPLICE
-{
-    my $self = shift;
-    my $offset = shift;
-    if (not defined $offset) {
-	warnings::warnif('uninitialized', 'Use of uninitialized value in splice');
-	$offset = 0;
-    }
-
-    my $no_length = ! @_;
-    my $length = @_ ? shift : 0;
-    # Carping about definedness comes _after_ the OFFSET sanity check.
-    # This is so we get the same error messages as Perl's splice().
-    # 
-
-    my @list = @_;
-
-    my $size = $self->FETCHSIZE();
-    
-    # 'If OFFSET is negative then it start that far from the end of
-    # the array.'
-    # 
-    if ($offset +< 0) {
-	my $new_offset = $size + $offset;
-	if ($new_offset +< 0) {
-	    die "Modification of non-creatable array value attempted, "
-	      . "subscript $offset";
-	}
-	$offset = $new_offset;
-    }
-
-    if (not defined $length) {
-	warnings::warnif('uninitialized', 'Use of uninitialized value in splice');
-	$length = 0;
-    }
-
-    if ($offset +> $size) {
- 	$offset = $size;
-	warnings::warnif('misc', 'splice() offset past end of array')
-            if $splice_end_array;
-    }
-
-    # 'If LENGTH is omitted, removes everything from OFFSET onward.'
-    if ($no_length) {
-	$length = $size - $offset;
-    }
-
-    # 'If LENGTH is negative, leave that many elements off the end of
-    # the array.'
-    # 
-    if ($length +< 0) {
-	$length = $size - $offset + $length;
-
-	if ($length +< 0) {
-	    # The user must have specified a length bigger than the
-	    # length of the array passed in.  But perl's splice()
-	    # doesn't catch this, it just behaves as for length=0.
-	    # 
-	    $length = 0;
-	}
-    }
-
-    if ($length +> $size - $offset) {
-	$length = $size - $offset;
-    }
-
-    # $num_elems holds the current number of elements in the database.
-    my $num_elems = $size;
-
-    # 'Removes the elements designated by OFFSET and LENGTH from an
-    # array,'...
-    # 
-    my @removed = ();
-    foreach (0 .. $length - 1) {
-	my $old;
-	my $status = $self->get($offset, $old);
-	if ($status != 0) {
-	    my $msg = "error from Berkeley DB on get($offset, \$old)";
-	    if ($status == 1) {
-		$msg .= ' (no such element?)';
-	    }
-	    else {
-		$msg .= ": error status $status";
-		if (defined $! and $! ne '') {
-		    $msg .= ", message $!";
-		}
-	    }
-	    die $msg;
-	}
-	push @removed, $old;
-
-	$status = $self->del($offset);
-	if ($status != 0) {
-	    my $msg = "error from Berkeley DB on del($offset)";
-	    if ($status == 1) {
-		$msg .= ' (no such element?)';
-	    }
-	    else {
-		$msg .= ": error status $status";
-		if (defined $! and $! ne '') {
-		    $msg .= ", message $!";
-		}
-	    }
-	    die $msg;
-	}
-
-	-- $num_elems;
-    }
-
-    # ...'and replaces them with the elements of LIST, if any.'
-    my $pos = $offset;
-    while (defined (my $elem = shift @list)) {
-	my $old_pos = $pos;
-	my $status;
-	if ($pos +>= $num_elems) {
-	    $status = $self->put($pos, $elem);
-	}
-	else {
-	    $status = $self->put($pos, $elem, $self->R_IBEFORE);
-	}
-
-	if ($status != 0) {
-	    my $msg = "error from Berkeley DB on put($pos, $elem, ...)";
-	    if ($status == 1) {
-		$msg .= ' (no such element?)';
-	    }
-	    else {
-		$msg .= ", error status $status";
-		if (defined $! and $! ne '') {
-		    $msg .= ", message $!";
-		}
-	    }
-	    die $msg;
-	}
-
-	die "pos unexpectedly changed from $old_pos to $pos with R_IBEFORE"
-	  if $old_pos != $pos;
-
-	++ $pos;
-	++ $num_elems;
-    }
-
-    if (wantarray) {
-	# 'In list context, returns the elements removed from the
-	# array.'
-	# 
-	return @removed;
-    }
-    elsif (defined wantarray and not wantarray) {
-	# 'In scalar context, returns the last element removed, or
-	# undef if no elements are removed.'
-	# 
-	if (@removed) {
-	    my $last = pop @removed;
-	    return "$last";
-	}
-	else {
-	    return undef;
-	}
-    }
-    elsif (not defined wantarray) {
-	# Void context
-    }
-    else { die }
-}
-sub ::DB_File::splice { &SPLICE }
-
 sub find_dup
 {
     croak "Usage: \$db->find_dup(key,value)\n"
-        unless @_ == 3 ;
+        unless (nelems @_) == 3 ;
  
     my $db        = shift ;
-    my ($origkey, $value_wanted) = @_ ;
+    my ($origkey, $value_wanted) = < @_ ;
     my ($key, $value) = ($origkey, 0);
     my ($status) = 0 ;
 
@@ -505,11 +333,11 @@ sub find_dup
 sub del_dup
 {
     croak "Usage: \$db->del_dup(key,value)\n"
-        unless @_ == 3 ;
+        unless (nelems @_) == 3 ;
  
     my $db        = shift ;
-    my ($key, $value) = @_ ;
-    my ($status) = $db->find_dup($key, $value) ;
+    my ($key, $value) = < @_ ;
+    my $status = $db->find_dup($key, $value) ;
     return $status if $status != 0 ;
 
     $status = $db->del($key, R_CURSOR() ) ;
@@ -519,16 +347,15 @@ sub del_dup
 sub get_dup
 {
     croak "Usage: \$db->get_dup(key [,flag])\n"
-        unless @_ == 2 or @_ == 3 ;
+        unless (nelems @_) == 2 or (nelems @_) == 3 ;
  
     my $db        = shift ;
     my $key       = shift ;
     my $flag	  = shift ;
     my $value 	  = 0 ;
     my $origkey   = $key ;
-    my $wantarray = wantarray ;
-    my %values	  = () ;
-    my @values    = () ;
+    my %values	  = %( () ) ;
+    my @values    = @( () ) ;
     my $counter   = 0 ;
     my $status    = 0 ;
  
@@ -539,18 +366,13 @@ sub get_dup
          $status = $db->seq($key, $value, R_NEXT()) ) {
  
         # save the value or count number of matches
-        if ($wantarray) {
-	    if ($flag)
-                { ++ %values{$value} }
-	    else
-                { push (@values, $value) }
-	}
+        if ($flag)
+          { ++ %values{$value} }
         else
-            { ++ $counter }
-     
+          { push (@values, $value) }
     }
  
-    return ($wantarray ? ($flag ? %values : @values) : $counter) ;
+    return  $flag ? %values : @values;
 }
 
 
