@@ -60,14 +60,14 @@ our($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 
 require Exporter;
 use XSLoader ();
-@ISA = qw(Exporter);
+@ISA = @( qw(Exporter) );
 BEGIN {
   $VERSION = "1.06";
 }
 
 # Items to export into callers namespace by default
 # (move infrequently used names to @EXPORT_OK below)
-@EXPORT =
+@EXPORT = @(
   qw(
 	FD_CLOEXEC
 	F_ALLOCSP
@@ -137,10 +137,10 @@ BEGIN {
 	O_TEXT
 	O_TRUNC
 	O_WRONLY
-     );
+     ) );
 
 # Other items we are prepared to export if requested
-@EXPORT_OK = qw(
+@EXPORT_OK = @( qw(
 	DN_ACCESS
 	DN_ATTRIB
 	DN_CREATE
@@ -189,9 +189,9 @@ BEGIN {
 	_S_IFMT S_IFREG S_IFDIR S_IFLNK
 	&S_ISREG &S_ISDIR &S_ISLNK &S_ISSOCK &S_ISBLK &S_ISCHR &S_ISFIFO
 	&S_ISWHT &S_ISENFMT &S_IFMT &S_IMODE
-);
+) );
 # Named groups of exports
-%EXPORT_TAGS = (
+%EXPORT_TAGS = %(
     'flock'   => \@(qw(LOCK_SH LOCK_EX LOCK_NB LOCK_UN)),
     'Fcompat' => \@(qw(FAPPEND FASYNC FCREAT FDEFER FDSYNC FEXCL FLARGEFILE
 		     FNDELAY FNONBLOCK FRSYNC FSYNC FTRUNC)),
@@ -215,7 +215,7 @@ BEGIN {
   XSLoader::load 'Fcntl', $VERSION;
 }
 
-sub S_IFMT  { @_ ? ( @_[0] ^&^ _S_IFMT() ) : _S_IFMT()  }
+sub S_IFMT  { (nelems @_) ?  @( @_[0] ^&^ _S_IFMT() ) : _S_IFMT()  }
 sub S_IMODE { @_[0] ^&^ 07777 }
 
 sub S_ISREG    { ( @_[0] ^&^ _S_IFMT() ) == S_IFREG()   }
