@@ -26,10 +26,10 @@ $VERSION = '2.006';
 sub saveStatus
 {
     my $self   = shift ;
-    ${ *$self->{ErrorNo} } = shift() + 0 ;
-    ${ *$self->{Error} } = '' ;
+    ${ $self->{ErrorNo} } = shift() + 0 ;
+    ${ $self->{Error} } = '' ;
 
-    return ${ *$self->{ErrorNo} } ;
+    return ${ $self->{ErrorNo} } ;
 }
 
 
@@ -37,8 +37,8 @@ sub saveErrorString
 {
     my $self   = shift ;
     my $retval = shift ;
-    ${ *$self->{Error} } = shift() . (${*$self->{Error}} ? "\nprevious: ${*$self->{Error}}" : "") ;
-    ${ *$self->{ErrorNo} } = shift() + 0 if @_ ;
+    ${ $self->{Error} } = shift() . (${$self->{Error}} ? "\nprevious: ${$self->{Error}}" : "") ;
+    ${ $self->{ErrorNo} } = shift() + 0 if (nelems @_) ;
 
     return $retval;
 }
@@ -55,13 +55,13 @@ sub closeError
     my $self = shift ;
     my $retval = shift ;
 
-    my $errno = *$self->{ErrorNo};
-    my $error = ${ *$self->{Error} };
+    my $errno = $self->{ErrorNo};
+    my $error = ${ $self->{Error} };
 
     $self->close();
 
-    *$self->{ErrorNo} = $errno ;
-    ${ *$self->{Error} } = $error ;
+    $self->{ErrorNo} = $errno ;
+    ${ $self->{Error} } = $error ;
 
     return $retval;
 }
@@ -71,13 +71,13 @@ sub closeError
 sub error
 {
     my $self   = shift ;
-    return ${ *$self->{Error} } ;
+    return ${ $self->{Error} } ;
 }
 
 sub errorNo
 {
     my $self   = shift ;
-    return ${ *$self->{ErrorNo} } ;
+    return ${ $self->{ErrorNo} } ;
 }
 
 
@@ -87,19 +87,19 @@ sub writeAt
     my $offset = shift;
     my $data = shift;
 
-    if (defined *$self->{FH}) {
-        my $here = tell(*$self->{FH});
+    if (defined $self->{FH}) {
+        my $here = tell($self->{FH});
         return $self->saveErrorString(undef, "Cannot seek to end of output filehandle: $!", $!) 
             if $here +< 0 ;
-        seek(*$self->{FH}, $offset, SEEK_SET)
+        seek($self->{FH}, $offset, SEEK_SET)
             or return $self->saveErrorString(undef, "Cannot seek to end of output filehandle: $!", $!) ;
-        defined *$self->{FH}->write($data, length $data)
+        defined $self->{FH}->write($data, length $data)
             or return $self->saveErrorString(undef, $!, $!) ;
-        seek(*$self->{FH}, $here, SEEK_SET)
+        seek($self->{FH}, $here, SEEK_SET)
             or return $self->saveErrorString(undef, "Cannot seek to end of output filehandle: $!", $!) ;
     }
     else {
-        substr(${ *$self->{Buffer} }, $offset, length($data), $data) ;
+        substr(${ $self->{Buffer} }, $offset, length($data), $data) ;
     }
 
     return 1;
@@ -114,17 +114,17 @@ sub output
     return 1 
         if length $data == 0 && ! $last ;
 
-    if ( *$self->{FilterEnvelope} ) {
+    if ( $self->{FilterEnvelope} ) {
         *_ = \$data;
-        &{ *$self->{FilterEnvelope} }();
+        &{ $self->{FilterEnvelope} }();
     }
 
-    if ( defined *$self->{FH} ) {
-        defined IO::Handle::write(*$self->{FH}, $data, length $data )
+    if ( defined $self->{FH} ) {
+        defined IO::Handle::write($self->{FH}, $data, length $data )
           or return $self->saveErrorString(0, $!, $!); 
     }
     else {
-        ${ *$self->{Buffer} } .= $data ;
+        ${ $self->{Buffer} } .= $data ;
     }
 
     return 1;
@@ -132,7 +132,7 @@ sub output
 
 sub getOneShotParams
 {
-    return ( 'MultiStream' => \@(1, 1, Parse_boolean,   1),
+    return  @( 'MultiStream' => \@(1, 1, Parse_boolean,   1),
            );
 }
 
@@ -154,11 +154,10 @@ sub checkParams
 
             'FilterEnvelope' => \@(1, 1, Parse_any,   undef),
 
-            $self->getExtraParams(),
-            *$self->{OneShot} ? $self->getOneShotParams() 
-                              : (),
+            < $self->getExtraParams(),
+            $self->{OneShot} ? < $self->getOneShotParams() : (),
         ), 
-        @_) or $self->croakError("{$class}: $got->{Error}")  ;
+        < @_) or die("$(dump::view($class)): $(dump::view($got->{Error}))")  ;
 
     return $got ;
 }
@@ -168,11 +167,11 @@ sub _create
     my $obj = shift;
     my $got = shift;
 
-    *$obj->{Closed} = 1 ;
+    $obj->{Closed} = 1 ;
 
     my $class = ref $obj;
     $obj->croakError("$class: Missing Output parameter")
-        if ! @_ && ! $got ;
+        if ! nelems @_ && ! $got ;
 
     my $outValue = shift ;
     my $oneShot = 1 ;
@@ -180,7 +179,7 @@ sub _create
     if (! $got)
     {
         $oneShot = 0 ;
-        $got = $obj->checkParams($class, undef, @_)
+        $got = $obj->checkParams($class, undef, < @_)
           or $obj->croakError("invalid params");
     }
 
@@ -192,26 +191,16 @@ sub _create
       or $obj->croakError("invalid output param");
 
     if ($outType eq 'buffer') {
-        *$obj->{Buffer} = $outValue;
+        $obj->{Buffer} = $outValue;
     }
     else {
         my $buff = "" ;
-        *$obj->{Buffer} = \$buff ;
+        $obj->{Buffer} = \$buff ;
     }
 
-    # Merge implies Append
-    my $merge = $got->value('Merge') ;
-    my $appendOutput = $got->value('Append') || $merge ;
-    *$obj->{Append} = $appendOutput;
-    *$obj->{FilterEnvelope} = $got->value('FilterEnvelope') ;
-
-    if ($merge)
-    {
-        # Switch off Merge mode if output file/buffer is empty/doesn't exist
-        if (($outType eq 'buffer' && length $$outValue == 0 ) ||
-            ($outType ne 'buffer' && (! -e $outValue || (-w _ && -z _))) )
-          { $merge = 0 }
-    }
+    my $appendOutput = $got->value('Append');
+    $obj->{Append} = $appendOutput;
+    $obj->{FilterEnvelope} = $got->value('FilterEnvelope') ;
 
     # If output is a file, check that it is writable
     if ($outType eq 'filename' && -e $outValue && ! -w _)
@@ -231,27 +220,25 @@ sub _create
     $obj->saveStatus(STATUS_OK) ;
 
     my $status ;
-    if (! $merge)
     {
-        *$obj->{Compress} = $obj->mkComp($class, $got)
+        $obj->{Compress} = $obj->mkComp($class, $got)
             or $obj->croakError("Failed making Compress");
         
-        *$obj->{UnCompSize} = U64->new() ;
-        *$obj->{CompSize} = U64->new() ;
+        $obj->{UnCompSize} = U64->new() ;
+        $obj->{CompSize} = U64->new() ;
 
         if ( $outType eq 'buffer') {
-            ${ *$obj->{Buffer} }  = ''
+            ${ $obj->{Buffer} }  = ''
                 unless $appendOutput ;
         }
         else {
             if ($outType eq 'handle') {
-                *$obj->{FH} = $outValue ;
-                setBinModeOutput(*$obj->{FH}) ;
+                $obj->{FH} = $outValue ;
                 IO::Handle::flush($outValue);
-                *$obj->{Handle} = 1 ;
+                $obj->{Handle} = 1 ;
                 if ($appendOutput)
                 {
-                    seek(*$obj->{FH}, 0, SEEK_END)
+                    seek($obj->{FH}, 0, SEEK_END)
                         or return $obj->saveErrorString(undef, "Cannot seek to end of output filehandle: $!", $!) ;
 
                 }
@@ -260,29 +247,23 @@ sub _create
                 my $mode = '>' ;
                 $mode = '>>'
                     if $appendOutput;
-                *$obj->{FH} = IO::File->new( "$outValue", "$mode")
+                $obj->{FH} = IO::File->new( "$outValue", "$mode")
                     or return $obj->saveErrorString(undef, "cannot open file '$outValue': $!", $!) ;
-                *$obj->{StdIO} = ($outValue eq '-'); 
-                setBinModeOutput(*$obj->{FH}) ;
+                $obj->{StdIO} = ($outValue eq '-'); 
             }
         }
 
-        *$obj->{Header} = $obj->mkHeader($got) ;
-        $obj->output( *$obj->{Header} )
+        $obj->{Header} = $obj->mkHeader($got) ;
+        $obj->output( $obj->{Header} )
             or $obj->croakError("Failed writing header");
     }
-    else
-    {
-        *$obj->{Compress} = $obj->createMerge($outValue, $outType)
-            or return undef;
-    }
 
-    *$obj->{Closed} = 0 ;
-    *$obj->{AutoClose} = $got->value('AutoClose') ;
-    *$obj->{Output} = $outValue;
-    *$obj->{ClassName} = $class;
-    *$obj->{Got} = $got;
-    *$obj->{OneShot} = 0 ;
+    $obj->{Closed} = 0 ;
+    $obj->{AutoClose} = $got->value('AutoClose') ;
+    $obj->{Output} = $outValue;
+    $obj->{ClassName} = $class;
+    $obj->{Got} = $got;
+    $obj->{OneShot} = 0 ;
 
     return $obj ;
 }
@@ -310,24 +291,24 @@ sub _def
 {
     my $obj = shift ;
     
-    my $class= (caller)[[0]] ;
-    my $name = (caller(1))[[3]] ;
+    my $class= @(caller)[0] ;
+    my $name = @(caller(1))[3] ;
 
     $obj->croakError("$name: expected at least 1 parameters\n")
-        unless @_ +>= 1 ;
+        unless (nelems @_) +>= 1 ;
 
     my $input = shift ;
-    my $haveOut = @_ ;
+    my $haveOut = (nelems @_) ;
     my $output = shift ;
 
-    my $x = Validator->new($class, *$obj->{Error}, $name, $input, $output)
+    my $x = Validator->new($class, $obj->{Error}, $name, $input, $output)
         or return undef ;
 
     push @_, $output if $haveOut && $x->{Hash};
 
-    *$obj->{OneShot} = 1 ;
+    $obj->{OneShot} = 1 ;
 
-    my $got = $obj->checkParams($name, undef, @_)
+    my $got = $obj->checkParams($name, undef, < @_)
         or return undef ;
 
     $x->{Got} = $got ;
@@ -349,14 +330,14 @@ sub _def
     if ($x->{GlobMap})
     {
         $x->{oneInput} = 1 ;
-        foreach my $pair (@{ $x->{Pairs} })
+        foreach my $pair (< @{ $x->{Pairs} })
         {
-            my ($from, $to) = @$pair ;
-            $obj->_singleTarget($x, 1, $from, $to, @_)
+            my ($from, $to) = < @$pair ;
+            $obj->_singleTarget($x, 1, $from, $to, < @_)
                 or return undef ;
         }
 
-        return scalar @{ $x->{Pairs} } ;
+        return scalar nelems @{ $x->{Pairs} } ;
     }
 
     if (! $x->{oneOutput} )
@@ -366,12 +347,12 @@ sub _def
 
         $x->{inType} = $inFile ? 'filename' : 'buffer';
         
-        foreach my $in ($x->{oneInput} ? $input : @$input)
+        foreach my $in ($x->{oneInput} ? $input : < @$input)
         {
             my $out ;
             $x->{oneInput} = 1 ;
 
-            $obj->_singleTarget($x, $inFile, $in, \$out, @_)
+            $obj->_singleTarget($x, $inFile, $in, \$out, < @_)
                 or return undef ;
 
             push @$output, \$out ;
@@ -385,7 +366,7 @@ sub _def
     }
 
     # finally the 1 to 1 and n to 1
-    return $obj->_singleTarget($x, 1, $input, $output, @_);
+    return $obj->_singleTarget($x, 1, $input, $output, < @_);
 
     croak "should not be here" ;
 }
@@ -399,10 +380,7 @@ sub _singleTarget
     
     if ($x->{oneInput})
     {
-        $obj->getFileInfo($x->{Got}, $input)
-            if isaFilename($input) and $inputIsFilename ;
-
-        my $z = $obj->_create($x->{Got}, @_)
+        my $z = $obj->_create($x->{Got}, < @_)
             or return undef ;
 
 
@@ -418,7 +396,7 @@ sub _singleTarget
         my $keep = $x->{Got}->clone();
 
         #for my $element ( ($x->{inType} eq 'hash') ? keys %$input : @$input)
-        for my $element ( @$input)
+        for my $element ( < @$input)
         {
             my $isFilename = isaFilename($element);
 
@@ -432,7 +410,7 @@ sub _singleTarget
                 $obj->getFileInfo($x->{Got}, $element)
                     if $isFilename;
 
-                $obj->_create($x->{Got}, @_)
+                $obj->_create($x->{Got}, < @_)
                     or return undef ;
             }
 
@@ -462,7 +440,7 @@ sub _wr2
 
     if ( ref $input && ref $input eq 'SCALAR' )
     {
-        return $self->syswrite($input, @_) ;
+        return $self->syswrite($input, < @_) ;
     }
 
     if ( ! ref $input  || isaFilehandle($input))
@@ -476,21 +454,21 @@ sub _wr2
             $fh = IO::File->new( "$input", "<")
                 or return $self->saveErrorString(undef, "cannot open file '$input': $!", $!) ;
         }
-        binmode $fh if *$self->{Got}->valueOrDefault('BinModeIn') ;
+        binmode $fh if $self->{Got}->valueOrDefault('BinModeIn') ;
 
         my $status ;
         my $buff ;
         my $count = 0 ;
         while (($status = read($fh, $buff, 16 * 1024)) +> 0) {
             $count += length $buff;
-            defined $self->syswrite($buff, @_) 
+            defined $self->syswrite($buff, < @_) 
                 or return undef ;
         }
 
         return $self->saveErrorString(undef, $!, $!) 
             if $status +< 0 ;
 
-        if ( (!$isFilehandle || *$self->{AutoClose}) && ! ref $input && $input ne '-')
+        if ( (!$isFilehandle || $self->{AutoClose}) && ! ref $input && $input ne '-')
         {    
             $fh->close() 
                 or return undef ;
@@ -509,16 +487,16 @@ sub addInterStream
     my $input = shift ;
     my $inputIsFilename = shift ;
 
-    if (*$self->{Got}->value('MultiStream'))
+    if ($self->{Got}->value('MultiStream'))
     {
-        $self->getFileInfo(*$self->{Got}, $input)
+        $self->getFileInfo($self->{Got}, $input)
             #if isaFilename($input) and $inputIsFilename ;
             if isaFilename($input) ;
 
         # TODO -- newStream needs to allow gzip/zip header to be modified
         return $self->newStream();
     }
-    elsif (*$self->{Got}->value('AutoFlush'))
+    elsif ($self->{Got}->value('AutoFlush'))
     {
         #return $self->flush(Z_FULL_FLUSH);
     }
@@ -549,7 +527,7 @@ sub DESTROY
     # TODO - memory leak with 5.8.0 - this isn't called until 
     #        global destruction
     #
-    %{ *$self } = () ;
+    %{ $self } = %( () ) ;
     undef $self ;
 }
 
@@ -565,7 +543,7 @@ sub syswrite
 
     my $buffer ;
     if (ref @_[0] ) {
-        $self->croakError( *$self->{ClassName} . "::write: not a scalar reference" )
+        $self->croakError( $self->{ClassName} . "::write: not a scalar reference" )
             unless ref @_[0] eq 'SCALAR' ;
         $buffer = @_[0] ;
     }
@@ -574,19 +552,19 @@ sub syswrite
     }
 
 
-    if (@_ +> 1) {
+    if ((nelems @_) +> 1) {
         my $slen = defined $$buffer ? length($$buffer) : 0;
         my $len = $slen;
         my $offset = 0;
         $len = @_[1] if @_[1] +< $len;
 
-        if (@_ +> 2) {
+        if ((nelems @_) +> 2) {
             $offset = @_[2] || 0;
-            $self->croakError(*$self->{ClassName} . "::write: offset outside string") 
+            $self->croakError($self->{ClassName} . "::write: offset outside string") 
                 if $offset +> $slen;
             if ($offset +< 0) {
                 $offset += $slen;
-                $self->croakError( *$self->{ClassName} . "::write: offset outside string") if $offset +< 0;
+                $self->croakError( $self->{ClassName} . "::write: offset outside string") if $offset +< 0;
             }
             my $rem = $slen - $offset;
             $len = $rem if $rem +< $len;
@@ -597,23 +575,23 @@ sub syswrite
 
     return 0 if ! defined $$buffer || length $$buffer == 0 ;
 
-    if (*$self->{Encoding}) {
-        $$buffer = *$self->{Encoding}->encode($$buffer);
+    if ($self->{Encoding}) {
+        $$buffer = $self->{Encoding}->encode($$buffer);
     }
 
     $self->filterUncompressed($buffer);
 
     my $buffer_length = defined $$buffer ? length($$buffer) : 0 ;
-    *$self->{UnCompSize}->add($buffer_length) ;
+    $self->{UnCompSize}->add($buffer_length) ;
 
     my $outBuffer='';
-    my $status = *$self->{Compress}->compr($buffer, $outBuffer) ;
+    my $status = $self->{Compress}->compr($buffer, $outBuffer) ;
 
-    return $self->saveErrorString(undef, *$self->{Compress}{Error}, 
-                                         *$self->{Compress}{ErrorNo})
+    return $self->saveErrorString(undef, $self->{Compress}->{Error}, 
+                                         $self->{Compress}->{ErrorNo})
         if $status == STATUS_ERROR;
 
-    *$self->{CompSize}->add(length $outBuffer) ;
+    $self->{CompSize}->add(length $outBuffer) ;
 
     $self->output($outBuffer)
         or return undef;
@@ -626,20 +604,20 @@ sub print
     my $self = shift;
 
     #if (ref $self) {
-    #    $self = *$self{GLOB} ;
+    #    $self = $self{GLOB} ;
     #}
 
     if (defined $\) {
         if (defined $,) {
-            defined $self->syswrite(join($,, @_) . $\);
+            defined $self->syswrite(join($,, < @_) . $\);
         } else {
-            defined $self->syswrite(join("", @_) . $\);
+            defined $self->syswrite(join("", < @_) . $\);
         }
     } else {
         if (defined $,) {
-            defined $self->syswrite(join($,, @_));
+            defined $self->syswrite(join($,, < @_));
         } else {
-            defined $self->syswrite(join("", @_));
+            defined $self->syswrite(join("", < @_));
         }
     }
 }
@@ -648,7 +626,7 @@ sub printf
 {
     my $self = shift;
     my $fmt = shift;
-    defined $self->syswrite(sprintf($fmt, @_));
+    defined $self->syswrite(sprintf($fmt, < @_));
 }
 
 
@@ -658,22 +636,22 @@ sub flush
     my $self = shift ;
 
     my $outBuffer='';
-    my $status = *$self->{Compress}->flush($outBuffer, @_) ;
-    return $self->saveErrorString(0, *$self->{Compress}{Error}, 
-                                    *$self->{Compress}{ErrorNo})
+    my $status = $self->{Compress}->flush($outBuffer, < @_) ;
+    return $self->saveErrorString(0, $self->{Compress}->{Error}, 
+                                    $self->{Compress}->{ErrorNo})
         if $status == STATUS_ERROR;
 
-    if ( defined *$self->{FH} ) {
-        IO::Handle::clearerr(*$self->{FH});
+    if ( defined $self->{FH} ) {
+        IO::Handle::clearerr($self->{FH});
     }
 
-    *$self->{CompSize}->add(length $outBuffer) ;
+    $self->{CompSize}->add(length $outBuffer) ;
 
     $self->output($outBuffer)
         or return 0;
 
-    if ( defined *$self->{FH} ) {
-        defined IO::Handle::flush(*$self->{FH})
+    if ( defined $self->{FH} ) {
+        defined IO::Handle::flush($self->{FH})
             or return $self->saveErrorString(0, $!, $!); 
     }
 
@@ -687,23 +665,23 @@ sub newStream
     $self->_writeTrailer()
         or return 0 ;
 
-    my $got = $self->checkParams('newStream', *$self->{Got}, @_)
+    my $got = $self->checkParams('newStream', $self->{Got}, < @_)
         or return 0 ;    
 
     $self->ckParams($got)
         or $self->croakError("newStream: $self->{Error}");
 
-    *$self->{Header} = $self->mkHeader($got) ;
-    $self->output(*$self->{Header} )
+    $self->{Header} = $self->mkHeader($got) ;
+    $self->output($self->{Header} )
         or return 0;
     
     my $status = $self->reset() ;
-    return $self->saveErrorString(0, *$self->{Compress}{Error}, 
-                                  *$self->{Compress}{ErrorNo})
+    return $self->saveErrorString(0, $self->{Compress}->{Error}, 
+                                  $self->{Compress}->{ErrorNo})
         if $status == STATUS_ERROR;
 
-    *$self->{UnCompSize}->reset();
-    *$self->{CompSize}->reset();
+    $self->{UnCompSize}->reset();
+    $self->{CompSize}->reset();
 
     return 1 ;
 }
@@ -711,7 +689,7 @@ sub newStream
 sub reset
 {
     my $self = shift ;
-    return *$self->{Compress}->reset() ;
+    return $self->{Compress}->reset() ;
 }
 
 sub _writeTrailer
@@ -720,11 +698,11 @@ sub _writeTrailer
 
     my $trailer = '';
 
-    my $status = *$self->{Compress}->close($trailer) ;
-    return $self->saveErrorString(0, *$self->{Compress}{Error}, *$self->{Compress}{ErrorNo})
+    my $status = $self->{Compress}->close($trailer) ;
+    return $self->saveErrorString(0, $self->{Compress}->{Error}, $self->{Compress}->{ErrorNo})
         if $status == STATUS_ERROR;
 
-    *$self->{CompSize}->add(length $trailer) ;
+    $self->{CompSize}->add(length $trailer) ;
 
     $trailer .= $self->mkTrailer();
     defined $trailer
@@ -744,10 +722,10 @@ sub close
 {
     my $self = shift ;
 
-    return 1 if *$self->{Closed} || ! *$self->{Compress} ;
-    *$self->{Closed} = 1 ;
+    return 1 if $self->{Closed} || ! $self->{Compress} ;
+    $self->{Closed} = 1 ;
 
-    untie *$self;
+    untie $self;
 
     $self->_writeTrailer()
         or return 0 ;
@@ -758,15 +736,15 @@ sub close
     $self->output( "", 1 )
         or return 0;
 
-    if (defined *$self->{FH}) {
+    if (defined $self->{FH}) {
 
-        #if (! *$self->{Handle} || *$self->{AutoClose}) {
-        if ((! *$self->{Handle} || *$self->{AutoClose}) && ! *$self->{StdIO}) {
+        #if (! $self->{Handle} || $self->{AutoClose}) {
+        if ((! $self->{Handle} || $self->{AutoClose}) && ! $self->{StdIO}) {
             $! = 0 ;
-            close(*$self->{FH})
+            close($self->{FH})
                 or return $self->saveErrorString(0, $!, $!); 
         }
-        delete *$self->{FH} ;
+        delete $self->{FH} ;
         # This delete can set $! in older Perls, so reset the errno
         $! = 0 ;
     }
@@ -782,31 +760,31 @@ sub close
 #sub crc
 #{
 #    my $self = shift ;
-#    return *$self->{Compress}->crc32() ;
+#    return $self->{Compress}->crc32() ;
 #}
 #
 #sub msg
 #{
 #    my $self = shift ;
-#    return *$self->{Compress}->msg() ;
+#    return $self->{Compress}->msg() ;
 #}
 #
 #sub dict_adler
 #{
 #    my $self = shift ;
-#    return *$self->{Compress}->dict_adler() ;
+#    return $self->{Compress}->dict_adler() ;
 #}
 #
 #sub get_Level
 #{
 #    my $self = shift ;
-#    return *$self->{Compress}->get_Level() ;
+#    return $self->{Compress}->get_Level() ;
 #}
 #
 #sub get_Strategy
 #{
 #    my $self = shift ;
-#    return *$self->{Compress}->get_Strategy() ;
+#    return $self->{Compress}->get_Strategy() ;
 #}
 
 
@@ -814,14 +792,14 @@ sub tell
 {
     my $self = shift ;
 
-    return *$self->{UnCompSize}->get32bit() ;
+    return $self->{UnCompSize}->get32bit() ;
 }
 
 sub eof
 {
     my $self = shift ;
 
-    return *$self->{Closed} ;
+    return $self->{Closed} ;
 }
 
 
@@ -844,14 +822,14 @@ sub seek
         $target = $here + $position ;
     }
     else {
-        $self->croakError(*$self->{ClassName} . "::seek: unknown value, $whence, for whence parameter");
+        $self->croakError($self->{ClassName} . "::seek: unknown value, $whence, for whence parameter");
     }
 
     # short circuit if seeking to current offset
     return 1 if $target == $here ;    
 
     # Outlaw any attempt to seek backwards
-    $self->croakError(*$self->{ClassName} . "::seek: cannot seek backwards")
+    $self->croakError($self->{ClassName} . "::seek: cannot seek backwards")
         if $target +< $here ;
 
     # Walk the file to the new offset
@@ -868,30 +846,30 @@ sub binmode
 {
     1;
 #    my $self     = shift ;
-#    return defined *$self->{FH} 
-#            ? binmode *$self->{FH} 
+#    return defined $self->{FH} 
+#            ? binmode $self->{FH} 
 #            : 1 ;
 }
 
 sub fileno
 {
     my $self     = shift ;
-    return defined *$self->{FH} 
-            ? fileno(*$self->{FH}) 
+    return defined $self->{FH} 
+            ? fileno($self->{FH}) 
             : undef ;
 }
 
 sub opened
 {
     my $self     = shift ;
-    return ! *$self->{Closed} ;
+    return ! $self->{Closed} ;
 }
 
 sub autoflush
 {
     my $self     = shift ;
-    return defined *$self->{FH} 
-            ? *$self->{FH}->autoflush(@_) 
+    return defined $self->{FH} 
+            ? $self->{FH}->autoflush(< @_) 
             : undef ;
 }
 
