@@ -10,10 +10,10 @@ use File::GlobMapper;
 
 require Exporter;
 our ($VERSION, @ISA, @EXPORT, %EXPORT_TAGS, $HAS_ENCODE);
-@ISA = qw(Exporter);
+@ISA = @( qw(Exporter) );
 $VERSION = '2.006';
 
-@EXPORT = qw( isaFilehandle isaFilename whatIsInput whatIsOutput 
+@EXPORT = @( qw( isaFilehandle isaFilename whatIsInput whatIsOutput 
               isaFileGlobString cleanFileGlobString oneTarget
               setBinModeInput setBinModeOutput
               ckInOutParams 
@@ -29,9 +29,9 @@ $VERSION = '2.006';
               STATUS_ENDSTREAM
               STATUS_EOF
               STATUS_ERROR
-          );  
+          ) );  
 
-%EXPORT_TAGS = ( Status => \@(qw( STATUS_OK
+%EXPORT_TAGS = %( Status => \@(qw( STATUS_OK
                                  STATUS_ENDSTREAM
                                  STATUS_EOF
                                  STATUS_ERROR
@@ -46,7 +46,7 @@ use constant STATUS_ERROR     => -1;
 sub hasEncode()
 {
     if (! defined $HAS_ENCODE) {
-        eval
+        try
         {
             require Encode;
             Encode->import();
@@ -88,29 +88,20 @@ sub setBinModeInput($)
         if  $needBinmode;
 }
 
-sub setBinModeOutput($)
-{
-    my $handle = shift ;
-
-    binmode $handle 
-        if  $needBinmode;
-}
-
 sub isaFilehandle($)
 {
-    use utf8; # Pragma needed to keep Perl 5.6.0 happy
-    return (defined @_[0] and 
-             (UNIVERSAL::isa(@_[0],'GLOB') or 
-              UNIVERSAL::isa(@_[0],'IO::Handle') or
-              UNIVERSAL::isa(\@_[0],'GLOB')) 
-          )
+    return  (defined @_[0] and 
+               (UNIVERSAL::isa(@_[0],'GLOB')
+                   or UNIVERSAL::isa(@_[0],'IO::Handle')
+                     or UNIVERSAL::isa(\@_[0],'GLOB'))
+           )
 }
 
 sub isaFilename($)
 {
-    return (defined @_[0] and 
-           ! ref @_[0]    and 
-           UNIVERSAL::isa(\@_[0], 'SCALAR'));
+    return  (defined @_[0] and 
+               ! ref @_[0]    and 
+                 UNIVERSAL::isa(\@_[0], 'SCALAR'));
 }
 
 sub isaFileGlobString
@@ -135,13 +126,13 @@ use constant WANT_HASH  => 0 ;
 
 sub whatIsInput($;$)
 {
-    my $got = whatIs(@_);
+    my $got = whatIs(< @_);
     
     if (defined $got && $got eq 'filename' && defined @_[0] && @_[0] eq '-')
     {
         #use IO::File;
         $got = 'handle';
-        @_[0] = *STDIN;
+        @_[0] = \*STDIN;
         #$_[0] = new IO::File("<-");
     }
 
@@ -150,12 +141,12 @@ sub whatIsInput($;$)
 
 sub whatIsOutput($;$)
 {
-    my $got = whatIs(@_);
+    my $got = whatIs(< @_);
     
     if (defined $got && $got eq 'filename' && defined @_[0] && @_[0] eq '-')
     {
         $got = 'handle';
-        @_[0] = *STDOUT;
+        @_[0] = \*STDOUT;
         #$_[0] = new IO::File(">-");
     }
     
@@ -200,7 +191,7 @@ sub Validator::new
     my $error_ref = shift ;
     my $reportClass = shift ;
 
-    my %data = (Class       => $Class, 
+    my %data = %(Class       => $Class, 
                 Error       => $error_ref,
                 reportClass => $reportClass, 
                ) ;
@@ -265,14 +256,14 @@ sub Validator::new
     if ($inType eq 'fileglob') # && $outType ne 'fileglob'
     {
         my $glob = cleanFileGlobString(@_[0]);
-        my @inputs = glob($glob);
+        my @inputs = glob@( <$glob);
 
-        if (@inputs == 0)
+        if ((nelems @inputs) == 0)
         {
             # TODO -- legal or die?
             die "globmap matched zero file -- legal or die???" ;
         }
-        elsif (@inputs == 1)
+        elsif ((nelems @inputs) == 1)
         {
             $obj->validateInputFilenames(@inputs[0])
                 or return undef;
@@ -282,9 +273,9 @@ sub Validator::new
         }
         else
         {
-            $obj->validateInputFilenames(@inputs)
+            $obj->validateInputFilenames(< @inputs)
                 or return undef;
-            @_[0] = \@( @inputs ) ;
+            @_[0] = \@( < @inputs ) ;
             %data{inType} = 'filenames' ;
         }
     }
@@ -341,7 +332,7 @@ sub Validator::validateInputFilenames
 {
     my $self = shift ;
 
-    foreach my $filename (@_)
+    foreach my $filename (< @_)
     {
         $self->croakError("$self->{reportClass}: input filename is undef or null string")
             if ! defined $filename || $filename eq ''  ;
@@ -371,12 +362,12 @@ sub Validator::validateInputArray
 {
     my $self = shift ;
 
-    if ( @{ @_[0] } == 0 )
+    if ( (nelems @{ @_[0] }) == 0 )
     {
         return $self->saveErrorString("empty array reference") ;
     }    
 
-    foreach my $element ( @{ @_[0] } )
+    foreach my $element ( < @{ @_[0] } )
     {
         my $inType  = whatIsInput($element);
     
@@ -428,13 +419,12 @@ sub createSelfTiedObject
     my $class = shift || (caller)[[0]] ;
     my $error_ref = shift ;
 
-    my $obj = bless Symbol::gensym(), ref($class) || $class;
-    tie *$obj, $obj;
-    *$obj->{Closed} = 1 ;
+    my $obj = bless \%(), ref($class) || $class;
+    $obj->{Closed} = 1 ;
     $$error_ref = '';
-    *$obj->{Error} = $error_ref ;
+    $obj->{Error} = $error_ref ;
     my $errno = 0 ;
-    *$obj->{ErrorNo} = \$errno ;
+    $obj->{ErrorNo} = \$errno ;
 
     return $obj;
 }
@@ -456,7 +446,7 @@ sub createSelfTiedObject
                          )
                       );              
 
-push @EXPORT, @{ %EXPORT_TAGS{Parse} } ;
+push @EXPORT, < @{ %EXPORT_TAGS{Parse} } ;
 
 use constant Parse_any      => 0x01;
 use constant Parse_unsigned => 0x02;
@@ -486,7 +476,7 @@ sub ParseParameters
     my $sub = (caller($level + 1))[[3]] ;
     local $Carp::CarpLevel = 1 ;
     my $p = IO::Compress::Base::Parameters->new() ;
-    $p->parse(@_)
+    $p->parse(< @_)
         or croak "$sub: $p->{Error}" ;
 
     return $p;
@@ -514,7 +504,7 @@ sub IO::Compress::Base::Parameters::setError
 {
     my $self = shift ;
     my $error = shift ;
-    my $retval = @_ ? shift : undef ;
+    my $retval = (nelems @_) ? shift : undef ;
 
     $self->{Error} = $error ;
     return $retval;
@@ -533,17 +523,17 @@ sub IO::Compress::Base::Parameters::parse
     my $default = shift ;
 
     my $got = $self->{Got} ;
-    my $firstTime = keys %{ $got } == 0 ;
+    my $firstTime = nkeys %{ $got } == 0 ;
 
     my (@Bad) ;
-    my @entered = () ;
+    my @entered = @( () ) ;
 
     # Allow the options to be passed as a hash reference or
     # as the complete hash.
-    if (@_ == 0) {
-        @entered = () ;
+    if ((nelems @_) == 0) {
+        @entered = @( () ) ;
     }
-    elsif (@_ == 1) {
+    elsif ((nelems @_) == 1) {
         my $href = @_[0] ;    
         return $self->setError("Expected even number of parameters, got 1")
             if ! defined $href or ! ref $href or ref $href ne "HASH" ;
@@ -554,7 +544,7 @@ sub IO::Compress::Base::Parameters::parse
         }
     }
     else {
-        my $count = @_;
+        my $count = (nelems @_);
         return $self->setError("Expected even number of parameters, got $count")
             if $count % 2 != 0 ;
         
@@ -567,10 +557,10 @@ sub IO::Compress::Base::Parameters::parse
 
     while (my ($key, $v) = each %$default)
     {
-        croak "need 4 params [@$v]"
-            if @$v != 4 ;
+        croak "need 4 params [{join ' ', <@$v}]"
+            if (nelems @$v) != 4 ;
 
-        my ($first_only, $sticky, $type, $value) = @$v ;
+        my ($first_only, $sticky, $type, $value) = < @$v ;
         my $x ;
         $self->_checkType($key, \$value, $type, 0, \$x) 
             or return undef ;
@@ -584,11 +574,11 @@ sub IO::Compress::Base::Parameters::parse
             $got->{$key} = \@(0, $type, $value, $x, $first_only, $sticky) ;
         }
 
-        $got->{$key}[OFF_PARSED] = 0 ;
+        $got->{$key}->[OFF_PARSED] = 0 ;
     }
 
-    my %parsed = ();
-    for my $i (0.. @entered / 2 - 1) {
+    my %parsed = %( () );
+    for my $i (0.. (nelems @entered) / 2 - 1) {
         my $key = @entered[2* $i] ;
         my $value = @entered[2* $i+1] ;
 
@@ -599,9 +589,9 @@ sub IO::Compress::Base::Parameters::parse
         my $canonkey = lc $key;
  
         if ($got->{$canonkey} && ($firstTime ||
-                                  ! $got->{$canonkey}[OFF_FIRST_ONLY]  ))
+                                  ! $got->{$canonkey}->[OFF_FIRST_ONLY]  ))
         {
-            my $type = $got->{$canonkey}[OFF_TYPE] ;
+            my $type = $got->{$canonkey}->[OFF_TYPE] ;
             my $parsed = %parsed{$canonkey};
             ++ %parsed{$canonkey};
 
@@ -614,8 +604,8 @@ sub IO::Compress::Base::Parameters::parse
 
             $value = $$value ;
             if ($type ^&^ Parse_multiple) {
-                $got->{$canonkey}[OFF_PARSED] = 1;
-                push @{ $got->{$canonkey}[OFF_FIXED] }, $s ;
+                $got->{$canonkey}->[OFF_PARSED] = 1;
+                push @{ $got->{$canonkey}->[OFF_FIXED] }, $s ;
             }
             else {
                 $got->{$canonkey} = \@(1, $type, $value, $s) ;
@@ -625,9 +615,9 @@ sub IO::Compress::Base::Parameters::parse
           { push (@Bad, $key) }
     }
  
-    if (@Bad) {
-        my ($bad) = join(", ", @Bad) ;
-        return $self->setError("unknown key value(s) @Bad") ;
+    if ((nelems @Bad)) {
+        my ($bad) = join(", ", < @Bad) ;
+        return $self->setError("unknown key value(s) {join ' ', <@Bad}") ;
     }
 
     return 1;
@@ -729,7 +719,7 @@ sub IO::Compress::Base::Parameters::parsed
     my $self = shift ;
     my $name = shift ;
 
-    return $self->{Got}{lc $name}[OFF_PARSED] ;
+    return $self->{Got}->{lc $name}->[OFF_PARSED] ;
 }
 
 sub IO::Compress::Base::Parameters::value
@@ -737,14 +727,14 @@ sub IO::Compress::Base::Parameters::value
     my $self = shift ;
     my $name = shift ;
 
-    if (@_)
+    if ((nelems @_))
     {
-        $self->{Got}{lc $name}[OFF_PARSED]  = 1;
-        $self->{Got}{lc $name}[OFF_DEFAULT] = @_[0] ;
-        $self->{Got}{lc $name}[OFF_FIXED]   = @_[0] ;
+        $self->{Got}->{lc $name}->[OFF_PARSED]  = 1;
+        $self->{Got}->{lc $name}->[OFF_DEFAULT] = @_[0] ;
+        $self->{Got}->{lc $name}->[OFF_FIXED]   = @_[0] ;
     }
 
-    return $self->{Got}{lc $name}[OFF_FIXED] ;
+    return $self->{Got}->{lc $name}->[OFF_FIXED] ;
 }
 
 sub IO::Compress::Base::Parameters::valueOrDefault
@@ -753,7 +743,7 @@ sub IO::Compress::Base::Parameters::valueOrDefault
     my $name = shift ;
     my $default = shift ;
 
-    my $value = $self->{Got}{lc $name}[OFF_DEFAULT] ;
+    my $value = $self->{Got}->{lc $name}->[OFF_DEFAULT] ;
 
     return $value if defined $value ;
     return $default ;
@@ -764,7 +754,7 @@ sub IO::Compress::Base::Parameters::wantValue
     my $self = shift ;
     my $name = shift ;
 
-    return defined $self->{Got}{lc $name}[OFF_DEFAULT] ;
+    return defined $self->{Got}->{lc $name}->[OFF_DEFAULT] ;
 
 }
 
@@ -775,7 +765,7 @@ sub IO::Compress::Base::Parameters::clone
     my %got ;
 
     while (my ($k, $v) = each %{ $self->{Got} }) {
-        %got{$k} = \@( @$v );
+        %got{$k} = \@( < @$v );
     }
 
     $obj->{Error} = $self->{Error};
@@ -797,11 +787,11 @@ sub new
     my $high = 0 ;
     my $low  = 0 ;
 
-    if (@_ == 2) {
+    if ((nelems @_) == 2) {
         $high = shift ;
         $low  = shift ;
     }
-    elsif (@_ == 1) {
+    elsif ((nelems @_) == 1) {
         $low  = shift ;
     }
 
@@ -833,7 +823,7 @@ sub reset
 sub clone
 {
     my $self = shift;
-    bless \@( @$self ), ref $self ;
+    bless \@( < @$self ), ref $self ;
 }
 
 sub getHigh
@@ -888,7 +878,7 @@ sub getPacked_V64
 {
     my $self = shift;
 
-    return pack "V V", @$self ;
+    return pack "V V", < @$self ;
 }
 
 sub getPacked_V32
