@@ -16,10 +16,10 @@ our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyUncompressError);
 $VERSION = '2.006';
 $AnyUncompressError = '';
 
-@ISA = qw( IO::Uncompress::Base Exporter );
-@EXPORT_OK = qw( $AnyUncompressError anyuncompress ) ;
-%EXPORT_TAGS = %IO::Uncompress::Base::DEFLATE_CONSTANTS ;
-push @{ %EXPORT_TAGS{all} }, @EXPORT_OK ;
+@ISA = @( qw( IO::Uncompress::Base Exporter ) );
+@EXPORT_OK = @( qw( $AnyUncompressError anyuncompress ) ) ;
+%EXPORT_TAGS = %( < %IO::Uncompress::Base::DEFLATE_CONSTANTS ) ;
+push @{ %EXPORT_TAGS{all} }, < @EXPORT_OK ;
 Exporter::export_ok_tags('all');
 
 # TODO - allow the user to pick a set of the three formats to allow
@@ -45,19 +45,19 @@ sub new
 {
     my $class = shift ;
     my $obj = createSelfTiedObject($class, \$AnyUncompressError);
-    $obj->_create(undef, 0, @_);
+    $obj->_create(undef, 0, < @_);
 }
 
 sub anyuncompress
 {
     my $obj = createSelfTiedObject(undef, \$AnyUncompressError);
-    return $obj->_inf(@_) ;
+    return $obj->_inf(< @_) ;
 }
 
 sub getExtraParams
 {
     use IO::Compress::Base::Common v2.006 qw(:Parse);
-    return ( 'RawInflate' => \@(1, 1, Parse_boolean,  0) ) ;
+    return  @( 'RawInflate' => \@(1, 1, Parse_boolean,  0) ) ;
 }
 
 sub ckParams
@@ -83,18 +83,18 @@ sub mkUncomp
     # try zlib first
     if (defined $IO::Uncompress::RawInflate::VERSION )
     {
-        my ($obj, $errstr, $errno) = IO::Uncompress::Adapter::Inflate::mkUncompObject();
+        my ($obj, $errstr, $errno) = < IO::Uncompress::Adapter::Inflate::mkUncompObject();
 
         return $self->saveErrorString(undef, $errstr, $errno)
             if ! defined $obj;
 
         *$self->{Uncomp} = $obj;
         
-        my @possible = qw( Inflate Gunzip Unzip );
+        my @possible = @( qw( Inflate Gunzip Unzip ) );
         unshift @possible, 'RawInflate' 
             if $got->value('RawInflate');
 
-        $magic = $self->ckMagic( @possible );
+        $magic = $self->ckMagic( < @possible );
         
         if ($magic) {
             *$self->{Info} = $self->readHeader($magic)
@@ -109,7 +109,7 @@ sub mkUncomp
         *$self->{Info} = $self->readHeader($magic)
             or return undef ;
 
-        my ($obj, $errstr, $errno) = IO::Uncompress::Adapter::Bunzip2::mkUncompObject();
+        my ($obj, $errstr, $errno) = < IO::Uncompress::Adapter::Bunzip2::mkUncompObject();
 
         return $self->saveErrorString(undef, $errstr, $errno)
             if ! defined $obj;
@@ -125,7 +125,7 @@ sub mkUncomp
         *$self->{Info} = $self->readHeader($magic)
             or return undef ;
 
-        my ($obj, $errstr, $errno) = IO::Uncompress::Adapter::LZO::mkUncompObject();
+        my ($obj, $errstr, $errno) = < IO::Uncompress::Adapter::LZO::mkUncompObject();
 
         return $self->saveErrorString(undef, $errstr, $errno)
             if ! defined $obj;
@@ -141,7 +141,7 @@ sub mkUncomp
         *$self->{Info} = $self->readHeader($magic)
             or return undef ;
 
-        my ($obj, $errstr, $errno) = IO::Uncompress::Adapter::Lzf::mkUncompObject();
+        my ($obj, $errstr, $errno) = < IO::Uncompress::Adapter::Lzf::mkUncompObject();
 
         return $self->saveErrorString(undef, $errstr, $errno)
             if ! defined $obj;
@@ -159,10 +159,10 @@ sub mkUncomp
 sub ckMagic
 {
     my $self = shift;
-    my @names = @_ ;
+    my @names = @( < @_ ) ;
 
     my $keep = ref $self ;
-    for my $class ( map { "IO::Uncompress::$_" } @names)
+    for my $class ( map { "IO::Uncompress::$_" } < @names)
     {
         bless $self => $class;
         my $magic = $self->ckMagic();
@@ -212,7 +212,6 @@ IO::Uncompress::AnyUncompress - Uncompress gzip, zip, bzip2 or lzop file/buffer
 
     $data = $z->trailingData()
     $status = $z->nextStream()
-    $data = $z->getHeaderInfo()
     $z->tell()
     $z->seek($position, $whence)
     $z->binmode()
@@ -788,20 +787,6 @@ Usage is
 
 
 
-=head2 getHeaderInfo
-
-Usage is
-
-    $hdr  = $z->getHeaderInfo();
-    @hdrs = $z->getHeaderInfo();
-
-This method returns either a hash reference (in scalar context) or a list
-or hash references (in array context) that contains information about each
-of the header fields in the compressed data stream(s).
-
-
-
-
 =head2 tell
 
 Usage is
