@@ -14,12 +14,12 @@ sub mkCompObject
     my $level    = shift ;
     my $strategy = shift ;
 
-    return bless \%(
+    return @( bless \%(
                   'CompSize'   => 0,
                   'UnCompSize' => 0,
                   'Error'      => '',
                   'ErrorNo'    => 0,
-                 ) ;     
+                 ) ) ;     
 }
 
 sub compr
@@ -63,13 +63,6 @@ sub reset
     return STATUS_OK;    
 }
 
-sub deflateParams 
-{
-    my $self = shift ;
-
-    return STATUS_OK;   
-}
-
 #sub total_out
 #{
 #    my $self = shift ;
