@@ -20,7 +20,7 @@ sub lexless_anon_sub {
     # Uses a closure (on $__ExPr__) to pass in the code to be executed.
     # (eval on one line to keep line numbers as expected by caller)
     eval sprintf
-    'package %s; %s strict; sub { @_=(); eval q[my $__ExPr__;] . $__ExPr__; }',
+    'package %s; %s strict; sub { @_= @(); eval q[my $__ExPr__;] . $__ExPr__; }',
 		@_[0], @_[1] ? 'use' : 'no';
 }
 
@@ -43,7 +43,8 @@ my $default_root  = 0;
 # Don't share stuff like *UNIVERSAL:: otherwise code from the
 # compartment can 0wn functions in UNIVERSAL
 my $default_share = \@(qw[
-    *_
+    $_
+    @_
     &PerlIO::get_layers
     &UNIVERSAL::isa
     &UNIVERSAL::can
@@ -98,13 +99,13 @@ my $default_share = \@(qw[
 ]);
 
 sub new {
-    my($class, $root, $mask) = @_;
+    my($class, $root, $mask) = < @_;
     my $obj = \%();
     bless $obj, $class;
 
     if (defined($root)) {
 	croak "Can't use \"$root\" as root name"
-	    if $root =~ m/^main\b/ or $root !~ m/^\w[:\w]*$/;
+	    if $root =~ m/^main\b/ or $root !~ m/^\w+::\w[:\w]*$/;
 	$obj->{Root}  = $root;
 	$obj->{Erase} = 0;
     }
@@ -124,7 +125,7 @@ sub new {
     # for reasons I don't completely understand, we need to share
     # the whole glob *_ rather than $_ and @_ separately, otherwise
     # @_ in non default packages within the compartment don't work.
-    $obj->share_from('main', $default_share);
+    $obj->share_from('', $default_share);
     Opcode::_safe_pkg_prep($obj->{Root}) if($Opcode::VERSION +> 1.04);
     return $obj;
 }
@@ -135,12 +136,12 @@ sub DESTROY {
 }
 
 sub erase {
-    my ($obj, $action) = @_;
+    my ($obj, $action) = < @_;
     my $pkg = $obj->root();
     my ($stem, $leaf);
 
     no strict 'refs';
-    $pkg = "main::{$pkg}::";	# expand to full symbol table name
+    $pkg = "{$pkg}::";	# expand to full symbol table name
     ($stem, $leaf) = $pkg =~ m/(.*)::(\w+::)$/;
 
     # The 'my $foo' is needed! Without it you get an
@@ -153,10 +154,16 @@ sub erase {
 
 #    delete $stem_symtab->{$leaf};
 
-    my $leaf_glob   = $stem_symtab->{$leaf};
-    my $leaf_symtab = *{$leaf_glob}{HASH};
+    delete $stem_symtab->{$leaf};
+    return;
+
+    my $leaf_globref   = \($stem_symtab->{$leaf});
+    my $leaf_symtab = *{$leaf_globref}{HASH};
 #    warn " leaf_symtab ", join(', ', %$leaf_symtab),"\n";
-    %$leaf_symtab = ();
+    # FIXME this does not clear properly yet: %$leaf_symtab = %( () );
+    for (keys %$leaf_symtab) {
+        delete $leaf_symtab->{$_};
+    }
     #delete $leaf_symtab->{'__ANON__'};
     #delete $leaf_symtab->{'foo'};
     #delete $leaf_symtab->{'main::'};
@@ -165,8 +172,9 @@ sub erase {
     if ($action and $action eq 'DESTROY') {
         delete $stem_symtab->{$leaf};
     } else {
-        $obj->share_from('main', $default_share);
+        $obj->share_from('', $default_share);
     }
+
     1;
 }
 
@@ -179,50 +187,50 @@ sub reinit {
 
 sub root {
     my $obj = shift;
-    croak("Safe root method now read-only") if @_;
+    croak("Safe root method now read-only") if (nelems @_);
     return $obj->{Root};
 }
 
 
 sub mask {
     my $obj = shift;
-    return $obj->{Mask} unless @_;
-    $obj->deny_only(@_);
+    return $obj->{Mask} unless (nelems @_);
+    $obj->deny_only(< @_);
 }
 
 # v1 compatibility methods
-sub trap   { shift->deny(@_)   }
-sub untrap { shift->permit(@_) }
+sub trap   { shift->deny(< @_)   }
+sub untrap { shift->permit(< @_) }
 
 sub deny {
     my $obj = shift;
-    $obj->{Mask} ^|^= opset(@_);
+    $obj->{Mask} ^|^= opset(< @_);
 }
 sub deny_only {
     my $obj = shift;
-    $obj->{Mask} = opset(@_);
+    $obj->{Mask} = opset(< @_);
 }
 
 sub permit {
     my $obj = shift;
     # XXX needs testing
-    $obj->{Mask} ^&^= invert_opset opset(@_);
+    $obj->{Mask} ^&^= invert_opset opset(< @_);
 }
 sub permit_only {
     my $obj = shift;
-    $obj->{Mask} = invert_opset opset(@_);
+    $obj->{Mask} = invert_opset opset(< @_);
 }
 
 
 sub dump_mask {
     my $obj = shift;
-    print opset_to_hex($obj->{Mask}),"\n";
+    print < opset_to_hex($obj->{Mask}),"\n";
 }
 
 
 
 sub share {
-    my($obj, @vars) = @_;
+    my($obj, < @vars) = < @_;
     $obj->share_from(scalar(caller), \@vars);
 }
 
@@ -235,10 +243,10 @@ sub share_from {
     croak("vars not an array ref") unless ref $vars eq 'ARRAY';
     no strict 'refs';
     # Check that 'from' package actually exists
-    croak("Package \"$pkg\" does not exist")
-	unless keys %{Symbol::stash("$pkg")};
+#     croak("Package \"$pkg\" does not exist")
+# 	unless %{Symbol::stash("$pkg")};
     my $arg;
-    foreach $arg (@$vars) {
+    foreach $arg (< @$vars) {
 	# catch some $safe->share($var) errors:
 	my ($var, $type);
 	$type = $1 if ($var = $arg) =~ s/^(\W)//;
@@ -260,7 +268,7 @@ sub share_record {
     my $vars = shift;
     my $shares = \%{$obj->{Shares} ||= \%()};
     # Record shares using keys of $obj->{Shares}. See reinit.
-    %{$shares}{[@$vars]} = ($pkg) x @$vars if @$vars;
+    %{$shares}{[< @$vars]} = ($pkg) x nelems @$vars if (nelems @$vars);
 }
 sub share_redo {
     my $obj = shift;
@@ -276,14 +284,13 @@ sub share_forget {
 }
 
 sub varglob {
-    my ($obj, $var) = @_;
-    no strict 'refs';
-    return *{Symbol::fetch_glob($obj->root()."::$var")};
+    my ($obj, $var) = < @_;
+    return Symbol::fetch_glob($obj->root()."::$var");
 }
 
 
 sub reval {
-    my ($obj, $expr, $strict) = @_;
+    my ($obj, $expr, $strict) = < @_;
     my $root = $obj->{Root};
 
     my $evalsub = lexless_anon_sub($root,$strict, $expr);
@@ -291,7 +298,7 @@ sub reval {
 }
 
 sub rdo {
-    my ($obj, $file) = @_;
+    my ($obj, $file) = < @_;
     my $root = $obj->{Root};
 
     my $evalsub = eval
