@@ -1,9 +1,9 @@
 use Perl6::Form;
 
 sub obscure {
-	my $hidewords = join '|', map quotemeta, @_;
+	my $hidewords = join '|', map quotemeta, < @_;
 	return sub {
-		my ($data) = @_;
+		my ($data) = < @_;
 		$data =~ s/($hidewords)/{'X' x length $1}/gi;
 		return $data;
 	}
@@ -12,9 +12,9 @@ sub obscure {
 my $censor = obscure qw(villain plot libel treacherous murderer false deadly 'G');
 my $script = do{local$/; ~< *DATA};
 
-print form
+print < form
 	 "[Ye following tranfcript hath been cenfored by Order of ye King]\n\n",
-	 "         \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\}",
+	 "         \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\}", <
 	 $censor->($script);
 
 __DATA__
