@@ -1,6 +1,6 @@
 use Perl6::Form 'drill';
 
-my @data = (
+my @data = @(
 	\%(name=>'Smith', rank=>'PFC', num=>12345 ),
 	\%(name=>'Yeun',  rank=>'Corporal', num=>34521 ),
 	\%(name=>'Patton', rank=>'General', num=>00012 ),
@@ -8,7 +8,7 @@ my @data = (
 
 print form
 	'      Rank Name         Serial Number',
-	'{]]]]]]]]} {[[[[[[[[[}     {IIIII}',
+	'{]]]]]]]]} {[[[[[[[[[}     {IIIII}', <
 	drill @data, \@(), \@(qw{rank name num});
 
 print "\n\n";
@@ -16,7 +16,7 @@ print "\n\n";
 print form
 	'      Rank Name         Serial Number',
 	\%(under=>"="),
-	'{]]]]]]]]} {[[[[[[[[[}     {IIIII}',
+	'{]]]]]]]]} {[[[[[[[[[}     {IIIII}', <
 	drill @data, \@(), \@(qw{rank name num});
 
 print "\n\n";
