@@ -2,10 +2,10 @@ use Perl6::Form;
 
 my $bullet = "<>";
 
-my @items = ~< *DATA;
+my @items = @( ~< *DATA );
 
-for my $item (@items) {
-	print form "\{'\{*\}'\} \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\}",
+for my $item (< @items) {
+	print < form "\{'\{*\}'\} \{[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[[\}",
 		        $bullet,      $item;
 }
 
