@@ -96,9 +96,17 @@ Return the SV from the GV.
 /* This macro is deprecated.  Do not use! */
 #define GvREFCNT_inc(gv) ((GV*)SvREFCNT_inc(gv))	/* DO NOT USE */
 
-#define GvAVn(gv)	(GvGP(gv)->gp_av ? \
-			 GvGP(gv)->gp_av : \
-			 GvGP(gv_AVadd(gv))->gp_av)
+#define INLINE1(ret, name, arg1) static __inline__ ret ii##name(pTHX_ arg1)
+INLINE1(AV*, GvAVn, GV *gv) {
+    if (GvGP(gv)->gp_av) {
+	/* assert(SvTYPE(GvGP(gv)->gp_av) == SVt_PVAV); */
+	return GvGP(gv)->gp_av;
+    } else {
+	return GvGP(gv_AVadd(gv))->gp_av;
+    }
+}
+#define GvAVn(gv) iiGvAVn(aTHX_ gv)
+
 #define GvHV(gv)	((GvGP(gv))->gp_hv)
 
 #define GvHVn(gv)	(GvGP(gv)->gp_hv ? \
