@@ -141,10 +141,9 @@ Sean M. Burke C<sburke@cpan.org>
 ###########################################################################
 
 sub self_and_super_versions {
-  no strict 'refs';
-  map {
+  @( map {
         $_ => (defined(${*{Symbol::fetch_glob("$_\::VERSION")}}) ? ${*{Symbol::fetch_glob("$_\::VERSION")}} : undef)
-      } self_and_super_path(@_[0])
+      } < self_and_super_path(@_[0]))
 }
 
 # Also consider magic like:
@@ -167,8 +166,8 @@ sub self_and_super_versions {
 
 ###########################################################################
 sub super_path {
-  my @ret = &self_and_super_path(@_);
-  shift @ret if @ret;
+  my @ret = @( < &self_and_super_path(< @_) );
+  shift @ret if (nelems @ret);
   return @ret;
 }
 
@@ -177,15 +176,15 @@ sub self_and_super_path {
   # Assumption: searching is depth-first.
   # Assumption: '' (empty string) can't be a class package name.
   # Note: 'UNIVERSAL' is not given any special treatment.
-  return () unless @_;
+  return () unless (nelems @_);
 
-  my @out = ();
+  my @out = @( () );
 
-  my @in_stack = (@_[0]);
-  my %seen = (@_[0] => 1);
+  my @in_stack = @(@_[0]);
+  my %seen = %(@_[0] => 1);
 
   my $current;
-  while(@in_stack) {
+  while((nelems @in_stack)) {
     next unless defined($current = shift @in_stack) && length($current);
     print "At $current\n" if $Debug;
     push @out, $current;
@@ -198,7 +197,7 @@ sub self_and_super_path {
            # Should I ever canonize the Foo'Bar = Foo::Bar thing? 
           %seen{$c}++ ? () : $c;
         }
-        @{*{Symbol::fetch_glob("$current\::ISA")}}
+        < @{*{Symbol::fetch_glob("$current\::ISA")}}
     ;
     # I.e., if this class has any parents (at least, ones I've never seen
     # before), push them, in order, onto the stack of classes I need to
