@@ -5,7 +5,7 @@ use vars qw($VERSION %MMAP $AUTOLOAD);
 
 $VERSION = "1.15";
 
-%MMAP = (
+%MMAP = %(
   "SHA-1"      => \@("Digest::SHA1", \@("Digest::SHA", 1), \@("Digest::SHA2", 1)),
   "SHA-224"    => \@(\@("Digest::SHA", 224)),
   "SHA-256"    => \@(\@("Digest::SHA", 256), \@("Digest::SHA2", 256)),
@@ -28,10 +28,10 @@ sub new
     };
     $impl = \@($impl) unless ref($impl);
     my $err;
-    for  (@$impl) {
+    for  (< @$impl) {
 	my $class = $_;
 	my @args;
-	($class, @args) = @$class if ref($class);
+	($class, < @args) = < @$class if ref($class);
 	no strict 'refs';
 	unless (exists %{*{Symbol::fetch_glob("$class\::")}}{"VERSION"}) {
 	    eval "require $class";
@@ -40,7 +40,7 @@ sub new
 		next;
 	    }
 	}
-	return $class->new(@args, @_);
+	return $class->new(< @args, < @_);
     }
     die $err;
 }
