@@ -5,14 +5,14 @@ use ExtUtils::CBuilder::Base;
 
 use vars qw($VERSION @ISA);
 $VERSION = '0.22';
-@ISA = qw(ExtUtils::CBuilder::Base);
+@ISA = @( qw(ExtUtils::CBuilder::Base) );
 
 sub link_executable {
   my $self = shift;
   # $Config{cc} is usually a better bet for linking executables than $Config{ld}
-  local $self->{config}{ld} =
-    $self->{config}{cc} . " " . $self->{config}{ldflags};
-  return $self->SUPER::link_executable(@_);
+  local $self->{config}->{ld} =
+    $self->{config}->{cc} . " " . $self->{config}->{ldflags};
+  return $self->SUPER::link_executable(< @_);
 }
 
 sub link {
@@ -26,12 +26,12 @@ sub link {
   
   local $cf->{ld} = $cf->{ld};
   if (ref $cf->{ld}) {
-    unshift @{$cf->{ld}}, 'env' if $cf->{ld}[0] =~ m/^\s*\w+=/;
+    unshift @{$cf->{ld}}, 'env' if $cf->{ld}->[0] =~ m/^\s*\w+=/;
   } else {
     $cf->{ld} =~ s/^(\s*\w+=)/env $1/;
   }
   
-  return $self->SUPER::link(@_);
+  return $self->SUPER::link(< @_);
 }
 
 1;
