@@ -6,12 +6,12 @@ use File::Spec;
 
 use vars qw($VERSION @ISA);
 $VERSION = '0.22';
-@ISA = qw(ExtUtils::CBuilder::Platform::Unix);
+@ISA = @( qw(ExtUtils::CBuilder::Platform::Unix) );
 
 sub need_prelink { 1 }
 
 sub link {
-  my ($self, %args) = @_;
+  my ($self, < %args) = < @_;
   my $cf = $self->{config};
 
   (my $baseext = %args{module_name}) =~ s/.*:://;
@@ -20,11 +20,11 @@ sub link {
   # Massage some very naughty bits in %Config
   local $cf->{lddlflags} = $cf->{lddlflags};
   for ($cf->{lddlflags}) {
-    s/\Q$(BASEEXT)\E/$baseext/;
-    s/\Q$(PERL_INC)\E/$perl_inc/;
+    s/\$ [(] BASEEXT [)] /$baseext/x;
+    s/\$ [(] PERL_INC [)] /$perl_inc/x;
   }
 
-  return $self->SUPER::link(%args);
+  return $self->SUPER::link(< %args);
 }
 
 
