@@ -19,7 +19,7 @@ $VERSION = '1.43';
 $VERSION = eval $VERSION;
 
 sub _is_prefix {
-    my ($self, $path, $prefix) = @_;
+    my ($self, $path, $prefix) = < @_;
     return unless defined $prefix && defined $path;
 
     if( $Is_VMS ) {
@@ -38,107 +38,107 @@ sub _is_prefix {
         $prefix =~ s|\\|/|g;
         return 1 if $path =~ m{^\Q$prefix\E}i;
     }
-    return(0);
+    return 0;
 }
 
 sub _is_doc {
-    my ($self, $path) = @_;
+    my ($self, $path) = < @_;
 
-    my $man1dir = $self->{':private:'}{Config}{man1direxp};
-    my $man3dir = $self->{':private:'}{Config}{man3direxp};
-    return(($man1dir && $self->_is_prefix($path, $man1dir))
+    my $man1dir = $self->{':private:'}->{Config}->{man1direxp};
+    my $man3dir = $self->{':private:'}->{Config}->{man3direxp};
+    return ($man1dir && $self->_is_prefix($path, $man1dir))
            ||
            ($man3dir && $self->_is_prefix($path, $man3dir))
-           ? 1 : 0)
+           ? 1 : 0;
 }
 
 sub _is_type {
-    my ($self, $path, $type) = @_;
+    my ($self, $path, $type) = < @_;
     return 1 if $type eq "all";
 
-    return($self->_is_doc($path)) if $type eq "doc";
+    return $self->_is_doc($path) if $type eq "doc";
 
     if ($type eq "prog") {
-        return($self->_is_prefix($path, $self->{':private:'}{Config}{prefix} || $self->{':private:'}{Config}{prefixexp})
+        return ($self->_is_prefix($path, $self->{':private:'}->{Config}->{prefix} || $self->{':private:'}->{Config}->{prefixexp})
                &&
                !($self->_is_doc($path))
                ? 1 : 0);
     }
-    return(0);
+    return 0;
 }
 
 sub _is_under {
-    my ($self, $path, @under) = @_;
-    @under[0] = "" if (! @under);
-    foreach my $dir (@under) {
-        return(1) if ($self->_is_prefix($path, $dir));
+    my ($self, $path, < @under) = < @_;
+    @under[0] = "" if (! nelems @under);
+    foreach my $dir (< @under) {
+        return 1 if ($self->_is_prefix($path, $dir));
     }
 
-    return(0);
+    return 0;
 }
 
 sub new {
     my ($class) = shift(@_);
     $class = ref($class) || $class;
 
-    my %args = @_;
+    my %args = %( < @_ );
 
     my $self = \%();
 
     if (%args{config_override}) {
-        eval {
-            $self->{':private:'}{Config} = \%( %{%args{config_override}} );
-        } or Carp::croak(
+        try {
+            $self->{':private:'}->{Config} = \%( < %{%args{config_override}} );
+        } or die(
             "The 'config_override' parameter must be a hash reference."
         );
     }
     else {
-        $self->{':private:'}{Config} = \%Config;
+        $self->{':private:'}->{Config} = \%Config;
     }
     
-    for my $tuple (\@(inc_override => INC => \@( @INC ) ),
+    for my $tuple (\@(inc_override => INC => \@( < @INC ) ),
                    \@( extra_libs => EXTRA => \@() )) 
     {
-        my ($arg,$key,$val)=@$tuple;
+        my ($arg,$key,$val)=< @$tuple;
         if ( %args{$arg} ) {
-            eval {
-                $self->{':private:'}{$key} = \@( @{%args{$arg}} );
+            try {
+                $self->{':private:'}->{$key} = \@( < @{%args{$arg}} );
             } or Carp::croak(
                 "The '$arg' parameter must be an array reference."
             );
         }
         elsif ($val) {
-            $self->{':private:'}{$key} = $val;
+            $self->{':private:'}->{$key} = $val;
         }
     }
     {
         my %dupe;
-        @{$self->{':private:'}{INC}} = grep { -e $_ && !%dupe{$_}++ }
-            @{$self->{':private:'}{INC}}, @{$self->{':private:'}{EXTRA}};        
+        @{$self->{':private:'}->{INC}} = @( grep { -e $_ && !%dupe{$_}++ }
+            < @{$self->{':private:'}->{INC}}, < @{$self->{':private:'}->{EXTRA}} );        
     }                
     my $perl5lib = defined %ENV{PERL5LIB} ? %ENV{PERL5LIB} : "";
 
-    my @dirs = ( $self->{':private:'}{Config}{archlibexp},
-                 $self->{':private:'}{Config}{sitearchexp},
+    my @dirs = @( $self->{':private:'}->{Config}->{archlibexp},
+                 $self->{':private:'}->{Config}->{sitearchexp},
                  split(m/\Q%Config{path_sep}\E/, $perl5lib),
-                 @{$self->{':private:'}{EXTRA}},
+                 < @{$self->{':private:'}->{EXTRA}},
                );   
     
     # File::Find does not know how to deal with VMS filepaths.
     if( $Is_VMS ) {
         $_ = VMS::Filespec::unixify($_) 
-            for @dirs;
+            for < @dirs;
     }
 
     if ($DOSISH) {
-        s|\\|/|g for @dirs;
+        s|\\|/|g for < @dirs;
     }
     my $archlib = @dirs[0];
     
     # Read the core packlist
-    $self->{Perl}{packlist} =
+    $self->{Perl}->{packlist} =
       ExtUtils::Packlist->new( File::Spec->catfile($archlib, '.packlist') );
-    $self->{Perl}{version} = $self->{':private:'}{Config}{version};
+    $self->{Perl}->{version} = $self->{':private:'}->{Config}->{version};
 
     # Read the module packlists
     my $sub = sub {
@@ -148,7 +148,7 @@ sub new {
         # Hack of the leading bits of the paths & convert to a module name
         my $module = $File::Find::name;
         my $found;
-        for (@dirs) {
+        for (< @dirs) {
             $found = $module =~ s!\Q$_\E/?auto/(.*)/.packlist!$1!s
                 and last;
         }            
@@ -161,33 +161,33 @@ sub new {
         $module =~ s!/!::!g;
 
         # Find the top-level module file in @INC
-        $self->{$module}{version} = '';
-        foreach my $dir (@{$self->{':private:'}{INC}}) {
+        $self->{$module}->{version} = '';
+        foreach my $dir (< @{$self->{':private:'}->{INC}}) {
             my $p = File::Spec->catfile($dir, $modfile);
             if (-r $p) {
                 $module = _module_name($p, $module) if $Is_VMS;
 
-                $self->{$module}{version} = MM->parse_version($p);
+                $self->{$module}->{version} = MM->parse_version($p);
                 last;
             }
         }
 
         # Read the .packlist
-        $self->{$module}{packlist} =
+        $self->{$module}->{packlist} =
           ExtUtils::Packlist->new($File::Find::name);
     };
     my %dupe;
-    @dirs= grep { -e $_ && !%dupe{$_}++ } @dirs;
-    $self->{':private:'}{LIBDIRS} = \@dirs;    
-    find($sub, @dirs) if @dirs;
+    @dirs= @( grep { -e $_ && !%dupe{$_}++ } < @dirs );
+    $self->{':private:'}->{LIBDIRS} = \@dirs;    
+    find($sub, < @dirs) if (nelems @dirs);
 
-    return(bless($self, $class));
+    return bless($self, $class);
 }
 
 # VMS's non-case preserving file-system means the package name can't
 # be reconstructed from the filename.
 sub _module_name {
-    my($file, $orig_module) = @_;
+    my($file, $orig_module) = < @_;
 
     my $module = '';
     if (open PACKFH, "<", $file) {
@@ -215,73 +215,71 @@ sub _module_name {
 
 
 sub modules {
-    my ($self) = @_;
+    my ($self) = < @_;
 
     # Bug/feature of sort in scalar context requires this.
-    return wantarray
-        ? sort grep { not m/^:private:$/ } keys %$self
-        : grep { not m/^:private:$/ } keys %$self;
+    return @( sort grep { not m/^:private:$/ } keys %$self);
 }
 
 sub files {
-    my ($self, $module, $type, @under) = @_;
+    my ($self, $module, $type, < @under) = < @_;
 
     # Validate arguments
-    Carp::croak("$module is not installed") if (! exists($self->{$module}));
+    die("$module is not installed") if (! exists($self->{$module}));
     $type = "all" if (! defined($type));
-    Carp::croak('type must be "all", "prog" or "doc"')
+    die('type must be "all", "prog" or "doc"')
         if ($type ne "all" && $type ne "prog" && $type ne "doc");
 
     my (@files);
-    foreach my $file (keys(%{$self->{$module}{packlist}})) {
+    foreach my $file (keys(%{$self->{$module}->{packlist}})) {
         push(@files, $file)
           if ($self->_is_type($file, $type) &&
-              $self->_is_under($file, @under));
+              $self->_is_under($file, < @under));
     }
-    return(@files);
+    return @files;
 }
 
 sub directories {
-    my ($self, $module, $type, @under) = @_;
+    my ($self, $module, $type, < @under) = < @_;
     my (%dirs);
-    foreach my $file ($self->files($module, $type, @under)) {
+    foreach my $file ( <$self->files($module, $type, < @under)) {
         %dirs{dirname($file)}++;
     }
-    return sort keys %dirs;
+    return @( sort keys %dirs);
 }
 
 sub directory_tree {
-    my ($self, $module, $type, @under) = @_;
+    my ($self, $module, $type, < @under) = < @_;
     my (%dirs);
-    foreach my $dir ($self->directories($module, $type, @under)) {
+    foreach my $dir ( <$self->directories($module, $type, < @under)) {
         %dirs{$dir}++;
         my ($last) = ("");
         while ($last ne $dir) {
             $last = $dir;
             $dir = dirname($dir);
-            last if !$self->_is_under($dir, @under);
+            last if !$self->_is_under($dir, < @under);
             %dirs{$dir}++;
         }
     }
-    return(sort(keys(%dirs)));
+    return @(sort(keys(%dirs)));
 }
 
 sub validate {
-    my ($self, $module, $remove) = @_;
+    my ($self, $module, $remove) = < @_;
     Carp::croak("$module is not installed") if (! exists($self->{$module}));
-    return($self->{$module}{packlist}->validate($remove));
+    return $self->{$module}->{packlist}->validate($remove);
 }
 
 sub packlist {
-    my ($self, $module) = @_;
+    my ($self, $module) = < @_;
     Carp::croak("$module is not installed") if (! exists($self->{$module}));
-    return($self->{$module}{packlist});
+    return $self->{$module}->{packlist};
 }
 
 sub version {
-    my ($self, $module) = @_;
+    my ($self, $module) = < @_;
     Carp::croak("$module is not installed") if (! exists($self->{$module}));
-    return($self->{$module}{version});
+    return $self->{$module}->{version};
 }
 
 
