@@ -6,7 +6,7 @@ our $VERSION = 6.44;
 
 require ExtUtils::MM_Any;
 require ExtUtils::MM_Unix;
-our @ISA = qw( ExtUtils::MM_Unix );
+our @ISA = @( qw( ExtUtils::MM_Unix ) );
 
 
 =head1 NAME
@@ -34,7 +34,7 @@ Unless otherwise stated, it works just like ExtUtils::MM_Unix
 =cut
 
 sub os_flavor {
-    return('DOS');
+    return @('DOS');
 }
 
 =item B<replace_manpage_separator>
@@ -44,7 +44,7 @@ Generates Foo__Bar.3 style man page names
 =cut
 
 sub replace_manpage_separator {
-    my($self, $man) = @_;
+    my($self, $man) = < @_;
 
     $man =~ s,/+,__,g;
     return $man;
