@@ -25,7 +25,7 @@ use File::Basename;
 our $VERSION = '6.44';
 
 require ExtUtils::MM_Win32;
-our @ISA = qw(ExtUtils::MM_Win32);
+our @ISA = @( qw(ExtUtils::MM_Win32) );
 
 use ExtUtils::MakeMaker qw( &neatvalue );
 
@@ -43,7 +43,7 @@ We're Netware in addition to being Windows.
 
 sub os_flavor {
     my $self = shift;
-    return ($self->SUPER::os_flavor, 'Netware');
+    return  @($self->SUPER::os_flavor, 'Netware');
 }
 
 =item init_platform
@@ -128,7 +128,7 @@ sub platform_constants {
 =cut
 
 sub const_cccmd {
-    my($self,$libperl)=@_;
+    my($self,$libperl)=< @_;
     return $self->{CONST_CCCMD} if $self->{CONST_CCCMD};
     return '' unless $self->needs_linking();
     return $self->{CONST_CCCMD} = <<'MAKE_FRAG';
@@ -145,7 +145,7 @@ MAKE_FRAG
 =cut
 
 sub static_lib {
-    my($self) = @_;
+    my($self) = < @_;
 
     return '' unless $self->has_link_code;
 
@@ -192,7 +192,7 @@ Defines how to produce the *.so (or equivalent) files.
 =cut
 
 sub dynamic_lib {
-    my($self, %attribs) = @_;
+    my($self, < %attribs) = < @_;
     return '' unless $self->needs_linking(); #might be because of a subdir
 
     return '' unless $self->has_link_code;
