@@ -3,12 +3,12 @@ package ExtUtils::MY;
 use strict;
 require ExtUtils::MM;
 
-our $VERSION = 6.43_01;
-our @ISA = qw(ExtUtils::MM);
+our $VERSION = 6.44;
+our @ISA = @( qw(ExtUtils::MM) );
 
 {
     package MY;
-    our @ISA = qw(ExtUtils::MY);
+    our @ISA = @( qw(ExtUtils::MY) );
 }
 
 sub DESTROY {}
