@@ -13,11 +13,11 @@ use vars qw($VERSION @ISA @EXPORT_OK
           $Debug $Verbose $Quiet $MANIFEST $DEFAULT_MSKIP);
 
 $VERSION = '1.51_01';
-@ISA=('Exporter');
-@EXPORT_OK = qw(mkmanifest
+@ISA=@('Exporter');
+@EXPORT_OK = @( qw(mkmanifest
                 manicheck  filecheck  fullcheck  skipcheck
                 manifind   maniread   manicopy   maniadd
-               );
+               ) );
 
 $Is_MacOS = $^O eq 'MacOS';
 $Is_VMS   = $^O eq 'VMS';
@@ -84,7 +84,7 @@ that are found in the existing F<MANIFEST> file in the new one.
 =cut
 
 sub _sort {
-    return sort { lc $a cmp lc $b } @_;
+    return @(sort { lc $a cmp lc $b } < @_);
 }
 
 sub mkmanifest {
@@ -99,10 +99,10 @@ sub mkmanifest {
     my $skip = _maniskip();
     my $found = manifind();
     my($key,$val,$file,%all);
-    %all = (%$found, %$read);
+    %all = %(< %$found, < %$read);
     %all{$MANIFEST} = ($Is_VMS ? "$MANIFEST\t\t" : '') . 'This list of files'
         if $manimiss; # add new MANIFEST to known file list
-    foreach $file (_sort keys %all) {
+    foreach $file ( <_sort keys %all) {
 	if ($skip->($file)) {
 	    # Policy: only remove files if they're listed in MANIFEST.SKIP.
 	    # Don't remove files just because they don't exist.
@@ -214,7 +214,7 @@ refs.
 =cut
 
 sub fullcheck {
-    return \@(_check_files()), \@(_check_manifest());
+    return @(\@( <_check_files()), \@( <_check_manifest()));
 }
 
 
@@ -228,12 +228,12 @@ file.
 =cut
 
 sub skipcheck {
-    my($p) = @_;
+    my($p) = < @_;
     my $found = manifind();
     my $matches = _maniskip();
 
-    my @skipped = ();
-    foreach my $file (_sort keys %$found){
+    my @skipped = @( () );
+    foreach my $file ( <_sort keys %$found){
         if (&$matches($file)){
             warn "Skipping $file\n";
             push @skipped, $file;
@@ -251,8 +251,8 @@ sub _check_files {
     my $read = maniread() || \%();
     my $found = manifind($p);
 
-    my(@missfile) = ();
-    foreach my $file (_sort keys %$read){
+    my(@missfile) = @( () );
+    foreach my $file ( <_sort keys %$read){
         warn "Debug: manicheck checking from $MANIFEST $file\n" if $Debug;
         if ($dosnames){
             $file = lc $file;
@@ -270,13 +270,13 @@ sub _check_files {
 
 
 sub _check_manifest {
-    my($p) = @_;
+    my($p) = < @_;
     my $read = maniread() || \%();
     my $found = manifind($p);
     my $skip  = _maniskip();
 
-    my @missentry = ();
-    foreach my $file (_sort keys %$found){
+    my @missentry = @( () );
+    foreach my $file ( <_sort keys %$found){
         next if $skip->($file);
         warn "Debug: manicheck checking from disk $file\n" if $Debug;
         unless ( exists $read->{$file} ) {
@@ -303,7 +303,7 @@ start with C<#> in the C<MANIFEST> file are discarded.
 =cut
 
 sub maniread {
-    my ($mfile) = @_;
+    my ($mfile) = < @_;
     $mfile ||= $MANIFEST;
     my $read = \%();
     my $m;
@@ -325,11 +325,11 @@ sub maniread {
         }
         elsif ($Is_VMS) {
             require File::Basename;
-            my($base,$dir) = File::Basename::fileparse($file);
+            my($base,$dir) = < File::Basename::fileparse($file);
             # Resolve illegal file specifications in the same way as tar
-            $dir =~ tr/./_/;
-            my(@pieces) = split(m/\./,$base);
-            if (@pieces +> 2) { $base = shift(@pieces) . '.' . join('_',@pieces); }
+            $dir =~ s/./_/g;
+            my(@pieces) = @( split(m/\./,$base) );
+            if ((nelems @pieces) +> 2) { $base = shift(@pieces) . '.' . join('_',< @pieces); }
             my $okfile = "$dir$base";
             warn "Debug: Illegal name $file changed to $okfile\n" if $Debug;
             $file = $okfile;
@@ -357,13 +357,13 @@ sub _maniskip {
 	push @skip, _macify($_);
     }
     close M;
-    return sub {0} unless (scalar @skip +> 0);
+    return sub {0} unless (scalar nelems @skip +> 0);
 
     my $opts = $Is_VMS ? '(?i)' : '';
 
     # Make sure each entry is isolated in its own parentheses, in case
     # any of them contain alternations
-    my $regex = join '|', map "(?:$_)", @skip;
+    my $regex = join '|', map "(?:$_)", < @skip;
 
     return sub { @_[0] =~ qr{$opts$regex} };
 }
@@ -377,7 +377,7 @@ sub _maniskip {
 sub _check_mskip_directives {
     my $mfile = shift;
     local (*M, $_);
-    my @lines = ();
+    my @lines = @( () );
     my $flag = 0;
     unless (open M, "<", $mfile) {
         warn "Problem opening $mfile: $!";
@@ -385,8 +385,8 @@ sub _check_mskip_directives {
     }
     while ( ~< *M) {
         if (m/^#!include_default\s*$/) {
-	    if (my @default = _include_mskip_file()) {
-	        push @lines, @default;
+	    if (my @default = @( < _include_mskip_file() )) {
+	        push @lines, < @default;
 		warn "Debug: Including default MANIFEST.SKIP\n" if $Debug;
 		$flag++;
 	    }
@@ -394,8 +394,8 @@ sub _check_mskip_directives {
         }
 	if (m/^#!include\s+(.*)\s*$/) {
 	    my $external_file = $1;
-	    if (my @external = _include_mskip_file($external_file)) {
-	        push @lines, @external;
+	    if (my @external = @( < _include_mskip_file($external_file) )) {
+	        push @lines, < @external;
 		warn "Debug: Including external $external_file\n" if $Debug;
 		$flag++;
 	    }
@@ -413,7 +413,7 @@ sub _check_mskip_directives {
         warn "Problem opening $mfile: $!";
         return;
     }
-    print M $_ for (@lines);
+    print M $_ for (< @lines);
     close M;
     return;
 }
@@ -431,7 +431,7 @@ sub _include_mskip_file {
         warn "Problem opening $mskip: $!";
         return;
     }
-    my @lines = ();
+    my @lines = @( () );
     push @lines, "\n#!start included $mskip\n";
     push @lines, $_ while ~< *M;
     close M;
@@ -461,7 +461,7 @@ default.
 =cut
 
 sub manicopy {
-    my($read,$target,$how)=@_;
+    my($read,$target,$how)=< @_;
     die "manicopy() called without target argument" unless defined $target;
     $how ||= 'cp';
     require File::Path;
@@ -476,7 +476,7 @@ sub manicopy {
 		$dir =~ s/[^:]+$//;
 	    	File::Path::mkpath($dir,1,0755);
 	    }
-	    cp_if_diff($file, _maccat($target, $file), $how);
+	    cp_if_diff($file, < _maccat($target, $file), $how);
 	} else {
 	    $file = VMS::Filespec::unixify($file) if $Is_VMS;
 	    if ($file =~ m!/!) { # Ilya, that hurts, I fear, or maybe not?
@@ -490,7 +490,7 @@ sub manicopy {
 }
 
 sub cp_if_diff {
-    my($from, $to, $how)=@_;
+    my($from, $to, $how)=< @_;
     -f $from or warn "$0: $from not found";
     my($diff) = 0;
     local(*F,*T);
@@ -519,7 +519,7 @@ sub cp_if_diff {
 }
 
 sub cp {
-    my ($srcFile, $dstFile) = @_;
+    my ($srcFile, $dstFile) = < @_;
     my ($access,$mod) = (stat $srcFile)[[8,9]];
 
     copy($srcFile,$dstFile);
@@ -529,7 +529,7 @@ sub cp {
 
 
 sub ln {
-    my ($srcFile, $dstFile) = @_;
+    my ($srcFile, $dstFile) = < @_;
     return &cp if $Is_VMS or ($^O eq 'MSWin32' and Win32::IsWin95());
     link($srcFile, $dstFile);
 
@@ -544,18 +544,18 @@ sub ln {
 # 2) Let everyone read it.
 # 3) If the owner can execute it, everyone can.
 sub _manicopy_chmod {
-    my($srcFile, $dstFile) = @_;
+    my($srcFile, $dstFile) = < @_;
 
     my $perm = 0444 ^|^ (stat $srcFile)[[2]] ^&^ 0700;
     chmod( $perm ^|^ ( $perm ^&^ 0100 ? 0111 : 0 ), $dstFile );
 }
 
 # Files that are often modified in the distdir.  Don't hard link them.
-my @Exceptions = qw(MANIFEST META.yml SIGNATURE);
+my @Exceptions = @( qw(MANIFEST META.yml SIGNATURE) );
 sub best {
-    my ($srcFile, $dstFile) = @_;
+    my ($srcFile, $dstFile) = < @_;
 
-    my $is_exception = grep $srcFile =~ m/$_/, @Exceptions;
+    my $is_exception = grep $srcFile =~ m/$_/, < @Exceptions;
     if ($is_exception or !%Config{d_link} or -l $srcFile) {
 	cp($srcFile, $dstFile);
     } else {
@@ -564,7 +564,7 @@ sub best {
 }
 
 sub _macify {
-    my($file) = @_;
+    my($file) = < @_;
 
     return $file unless $Is_MacOS;
 
@@ -578,7 +578,7 @@ sub _macify {
 }
 
 sub _maccat {
-    my($f1, $f2) = @_;
+    my($f1, $f2) = < @_;
 
     return "$f1/$f2" unless $Is_MacOS;
 
@@ -588,13 +588,13 @@ sub _maccat {
 }
 
 sub _unmacify {
-    my($file) = @_;
+    my($file) = < @_;
 
     return $file unless $Is_MacOS;
 
     $file =~ s|^:||;
     $file =~ s|([/ \n])|{sprintf("\\\%03o", unpack("c", $1))}|g;
-    $file =~ y|:|/|;
+    $file =~ s|:|/|g;
 
     $file;
 }
@@ -617,13 +617,13 @@ sub maniadd {
     _fix_manifest($MANIFEST);
 
     my $manifest = maniread();
-    my @needed = grep { !exists $manifest->{$_} } keys %$additions;
-    return 1 unless @needed;
+    my @needed = @( grep { !exists $manifest->{$_} } keys %$additions );
+    return 1 unless (nelems @needed);
 
     open(MANIFEST, ">>", "$MANIFEST") or 
       die "maniadd() could not open $MANIFEST: $!";
 
-    foreach my $file (_sort @needed) {
+    foreach my $file ( <_sort < @needed) {
         my $comment = $additions->{$file} || '';
         printf MANIFEST "\%-40s \%s\n", $file, $comment;
     }
@@ -641,7 +641,7 @@ sub _fix_manifest {
 
     # Yes, we should be using seek(), but I'd like to avoid loading POSIX
     # to get SEEK_*
-    my @manifest = ~< *MANIFEST;
+    my @manifest = @( ~< *MANIFEST );
     close MANIFEST;
 
     unless( @manifest[-1] =~ m/\n\z/ ) {
