@@ -19,10 +19,8 @@ Make a filehandle. Same kind of idea as Symbol::gensym().
 
 sub mkfh()
 {
-no strict;
-my $fh = \*{Symbol::fetch_glob($fhname++)};
-use strict;
-return($fh);
+    my $fh = \*{Symbol::fetch_glob($fhname++)};
+    return $fh;
 }
 
 =item __find_relocations
@@ -51,56 +49,56 @@ sub __find_relocations
 
 sub new($$)
 {
-my ($class, $packfile) = @_;
-$class = ref($class) || $class;
-my %self;
-tie(%self, $class, $packfile);
-return(bless(\%self, $class));
+    my ($class, $packfile) = < @_;
+    $class = ref($class) || $class;
+    my %self;
+    tie(%self, $class, $packfile);
+    return (bless(\%self, $class));
 }
 
 sub TIEHASH
 {
-my ($class, $packfile) = @_;
-my $self = \%( packfile => $packfile );
-bless($self, $class);
-$self->read($packfile) if (defined($packfile) && -f $packfile);
-return($self);
+    my ($class, $packfile) = < @_;
+    my $self = \%( packfile => $packfile );
+    bless($self, $class);
+    $self->read($packfile) if (defined($packfile) && -f $packfile);
+    return ($self);
 }
 
 sub STORE
 {
-@_[0]->{data}->{@_[1]} = @_[2];
+    @_[0]->{data}->{@_[1]} = @_[2];
 }
 
 sub FETCH
 {
-return(@_[0]->{data}->{@_[1]});
+    return @_[0]->{data}->{@_[1]};
 }
 
 sub FIRSTKEY
 {
-my $reset = scalar(keys(%{@_[0]->{data}}));
-return(each(%{@_[0]->{data}}));
+    keys(%{@_[0]->{data}});
+    return each(%{@_[0]->{data}});
 }
 
 sub NEXTKEY
 {
-return(each(%{@_[0]->{data}}));
+    return each(%{@_[0]->{data}});
 }
 
 sub EXISTS
 {
-return(exists(@_[0]->{data}->{@_[1]}));
+    return exists(@_[0]->{data}->{@_[1]});
 }
 
 sub DELETE
 {
-return(delete(@_[0]->{data}->{@_[1]}));
+    return delete(@_[0]->{data}->{@_[1]});
 }
 
 sub CLEAR
 {
-%{@_[0]->{data}} = ();
+    %{@_[0]->{data}} = %( () );
 }
 
 sub DESTROY
@@ -109,7 +107,7 @@ sub DESTROY
 
 sub read($;$)
 {
-my ($self, $packfile) = @_;
+my ($self, $packfile) = < @_;
 $self = tied(%$self) || $self;
 
 if (defined($packfile)) { $self->{packfile} = $packfile; }
@@ -132,7 +130,7 @@ while (defined($line = ~< $fh))
       {
 	  require File::Spec;
 	  require Cwd;
-	  my ($vol, $dir) = File::Spec->splitpath($packfile);
+	  my ($vol, $dir) = < File::Spec->splitpath($packfile);
 	  my $newpath = File::Spec->catpath($vol, $dir, $data->{relocate_as});
 	  $key = Cwd::realpath($newpath);
       }
@@ -145,14 +143,14 @@ close($fh);
 
 sub write($;$)
 {
-my ($self, $packfile) = @_;
+my ($self, $packfile) = < @_;
 $self = tied(%$self) || $self;
 if (defined($packfile)) { $self->{packfile} = $packfile; }
 else { $packfile = $self->{packfile}; }
 die("No packlist filename specified") if (! defined($packfile));
 my $fh = mkfh();
 open($fh, ">", "$packfile") || die("Can't open file $packfile: $!");
-foreach my $key (sort(keys(%{$self->{data}})))
+foreach my $key (sort(keys(%{$self->{data} || \%()})))
    {
        my $data = $self->{data}->{$key};
        if (%Config{userelocatableinc}) {
@@ -161,12 +159,12 @@ foreach my $key (sort(keys(%{$self->{data}})))
 	       # We are writing into a subdirectory of a run-time relocated
 	       # path. Figure out if the this file is also within a subdir.
 	       my $prefix = $1;
-	       if (File::Spec->no_upwards(File::Spec->abs2rel($key, $prefix)))
+	       if (File::Spec->no_upwards( <File::Spec->abs2rel($key, $prefix)))
 	       {
 		   # The relocated path is within the found prefix
 		   my $packfile_prefix;
 		   (undef, $packfile_prefix)
-		       = File::Spec->splitpath($packfile);
+		       = < File::Spec->splitpath($packfile);
 
 		   my $relocate_as
 		       = File::Spec->abs2rel($key, $packfile_prefix);
@@ -193,7 +191,7 @@ close($fh);
 
 sub validate($;$)
 {
-my ($self, $remove) = @_;
+my ($self, $remove) = < @_;
 $self = tied(%$self) || $self;
 my @missing;
 foreach my $key (sort(keys(%{$self->{data}})))
@@ -201,17 +199,17 @@ foreach my $key (sort(keys(%{$self->{data}})))
    if (! -e $key)
       {
       push(@missing, $key);
-      delete($self->{data}{$key}) if ($remove);
+      delete($self->{data}->{$key}) if ($remove);
       }
    }
-return(@missing);
+return @(@missing);
 }
 
 sub packlist_file($)
 {
-my ($self) = @_;
+my ($self) = < @_;
 $self = tied(%$self) || $self;
-return($self->{packfile});
+return @($self->{packfile});
 }
 
 1;
