@@ -15,12 +15,12 @@ use warnings;
 
 sub doglob {
     my $cond = shift;
-    my @retval = ();
+    my @retval = @( () );
     #print "doglob: ", join('|', @_), "\n";
   OUTER:
-    for my $pat (@_) {
-	my @matched = ();
-	my @globdirs = ();
+    for my $pat (< @_) {
+	my @matched = @( () );
+	my @globdirs = @( () );
 	my $head = '.';
 	my $sepchr = '/';
         my $tail;
@@ -42,9 +42,9 @@ sub doglob {
 	    #print "div: |$head|$sepchr|$tail|\n";
 	    push (@retval, $pat), next OUTER if $tail eq '';
 	    if ($head =~ m/[*?]/) {
-		@globdirs = doglob('d', $head);
-		push(@retval, doglob($cond, map {"$_$sepchr$tail"} @globdirs)),
-		    next OUTER if @globdirs;
+		@globdirs = @( < doglob('d', $head) );
+		push(@retval, < doglob($cond, map {"$_$sepchr$tail"} < @globdirs)),
+		    next OUTER if (nelems @globdirs);
 	    }
 	    $head .= $sepchr if $head eq '' or $head =~ m/^[A-Za-z]:\z/s;
 	    $pat = $tail;
@@ -60,7 +60,7 @@ sub doglob {
 	    next OUTER;
 	}
 	opendir(D, $head) or next OUTER;
-	my @leaves = readdir D;
+	my @leaves = @( readdir D );
 	closedir D;
 	$head = '' if $head eq '.';
 	$head .= $sepchr unless $head eq '' or substr($head,-1) eq $sepchr;
@@ -74,7 +74,7 @@ sub doglob {
 	#print "regex: '$pat', head: '$head'\n";
 	my $matchsub = sub { @_[0] =~ m|^$pat\z|is };
       INNER:
-	for my $e (@leaves) {
+	for my $e (< @leaves) {
 	    next INNER if $e eq '.' or $e eq '..';
 	    next INNER if $cond eq 'd' and ! -d "$head$e";
 	    push(@matched, "$head$e"), next INNER if &$matchsub($e);
@@ -89,7 +89,7 @@ sub doglob {
 		push(@matched, "$head$e"), next INNER if &$matchsub("$e.");
 	    }
 	}
-	push @retval, @matched if @matched;
+	push @retval, < @matched if (nelems @matched);
     }
     return @retval;
 }
@@ -100,14 +100,14 @@ sub doglob {
 #
 sub doglob_Mac {
     my $cond = shift;
-    my @retval = ();
+    my @retval = @( () );
 
 	#print "doglob_Mac: ", join('|', @_), "\n";
   OUTER:
-    for my $arg (@_) {
+    for my $arg (< @_) {
         local $_ = $arg;
-	my @matched = ();
-	my @globdirs = ();
+	my @matched = @( () );
+	my @globdirs = @( () );
 	my $head = ':';
 	my $not_esc_head = $head;
 	my $sepchr = ':';	
@@ -138,9 +138,9 @@ sub doglob_Mac {
 		$tmp_head =~ s/(\\*)([*?])/{$2 x ((length($1) + 1) % 2)}/g;
 	
 		if ($tmp_head =~ m/[*?]/) { # if there are wildcards ...	
-		@globdirs = doglob_Mac('d', $head);
-		push(@retval, doglob_Mac($cond, map {"$_$sepchr$tail"} @globdirs)),
-		    next OUTER if @globdirs;
+		@globdirs = @( < doglob_Mac('d', $head) );
+		push(@retval, < doglob_Mac($cond, map {"$_$sepchr$tail"} < @globdirs)),
+		    next OUTER if (nelems @globdirs);
 	    }
 		
 		$head .= $sepchr; 
@@ -171,7 +171,7 @@ sub doglob_Mac {
 	}
 	#print "opendir($not_esc_head)\n";
 	opendir(D, $not_esc_head) or next OUTER;
-	my @leaves = readdir D;
+	my @leaves = @( readdir D );
 	closedir D;
 
 	# escape regex metachars but not '\' and glob chars '*', '?'
@@ -184,7 +184,7 @@ sub doglob_Mac {
 	my $matchsub = eval 'sub { $_[0] =~ m|^' . $_ . '\z|ios }';
 	warn($@), next OUTER if $@;
       INNER:
-	for my $e (@leaves) {
+	for my $e (< @leaves) {
 	    next INNER if $e eq '.' or $e eq '..';
 	    next INNER if $cond eq 'd' and ! -d "$not_esc_head$e";
 		
@@ -200,7 +200,7 @@ sub doglob_Mac {
 			next INNER;
 		}
 	}
-	push @retval, @matched if @matched;
+	push @retval, < @matched if (nelems @matched);
     }
     return @retval;
 }
@@ -220,18 +220,18 @@ sub _expand_volume {
 	
 	require MacPerl; # to be verbose
 	
-	my @pat = @_;
-	my @new_pat = ();
-	my @FSSpec_Vols = MacPerl::Volumes();
-	my @mounted_volumes = ();
+	my @pat = @( < @_ );
+	my @new_pat = @( () );
+	my @FSSpec_Vols = @( < MacPerl::Volumes() );
+	my @mounted_volumes = @( () );
 
-	foreach my $spec_vol (@FSSpec_Vols) {		
+	foreach my $spec_vol (< @FSSpec_Vols) {		
 		# push all mounted volumes into array
-     	push @mounted_volumes, MacPerl::MakePath($spec_vol);
+     	push @mounted_volumes, < MacPerl::MakePath($spec_vol);
 	}
 	#print "mounted volumes: |@mounted_volumes|\n";
 	
-	while (@pat) {
+	while ((nelems @pat)) {
 		my $pat = shift @pat;	
 		if ($pat =~ m/^([^:]+:)(.*)\z/) { # match a volume name?
 			my $vol_pat = $1;
@@ -244,7 +244,7 @@ sub _expand_volume {
 			$vol_pat =~ s/(\\*)([*?])/{$1 . ('.' x ((length($1) + 1) % 2)) . $2}/g;
 			#print "volume regex: '$vol_pat' \n";
 				
-			foreach my $volume (@mounted_volumes) {
+			foreach my $volume (< @mounted_volumes) {
 				if ($volume =~ m|^$vol_pat\z|ios) {
 					#
 					# On Mac OS, the two glob metachars '*' and '?' and the  
@@ -268,9 +268,9 @@ sub _expand_volume {
 # from the pattern, unless it's a volume name pattern like "*HD:"
 #
 sub _preprocess_pattern {
-	my @pat = @_;
+	my @pat = @( < @_ );
 	
-	foreach my $p (@pat) {
+	foreach my $p (< @pat) {
 		my $proceed;
 		# resolve any updirs, e.g. "*HD:t?p::a*" -> "*HD:a*"
 		do {
@@ -289,7 +289,7 @@ sub _preprocess_pattern {
 # metachars '*', '?' and '\'.
 #
 sub _un_escape {
-	foreach (@_) {
+	foreach (< @_) {
 		s/\\([*?\\])/$1/g;
 	}
 	return @_;
@@ -306,7 +306,7 @@ my %iter;
 my %entries;
 
 sub glob {
-    my($pat,$cxix) = @_;
+    my($pat,$cxix) = < @_;
     my @pat;
 
     # glob without args defaults to $_
@@ -315,7 +315,7 @@ sub glob {
     # extract patterns
     if ($pat =~ m/\s/) {
 	require Text::ParseWords;
-	@pat = Text::ParseWords::parse_line('\s+',0,$pat);
+	@pat = @( < Text::ParseWords::parse_line('\s+',0,$pat) );
     }
     else {
 	push @pat, $pat;
@@ -326,8 +326,8 @@ sub glob {
     #   abc1 abc2 will be put in @appendpat.
     # This was just the esiest way, not nearly the best.
     REHASH: {
-	my @appendpat = ();
-	for (@pat) {
+	my @appendpat = @( () );
+	for (< @pat) {
 	    # There must be a "," I.E. abc{efg} is not what we want.
 	    while ( m/^(.*)(?<!\\)\{(.*?)(?<!\\)\,.*?(?<!\\)\}(.*)$/ ) {
 		my ($start, $match, $end) = ($1, $2, $3);
@@ -350,17 +350,17 @@ sub glob {
 		#FIXME: There should be checking for this.
 		#  How or what should be done about failure is beond me.
 	}
-	if (( @appendpat-1) != -1
+	if (( (nelems @appendpat)-1) != -1
 		) {
 	    #print "LOOP\n";
 	    #FIXME: Max loop, no way! :")
-	    for ( @appendpat ) {
+	    for ( < @appendpat ) {
 	        push @pat, $_;
 	    }
 	    goto REHASH;
 	}
     }
-    for ( @pat ) {
+    for ( < @pat ) {
 	s/\\{/\{/g;
 	s/\\}/\}/g;
 	s/\\,/,/g;
@@ -375,31 +375,18 @@ sub glob {
     if (%iter{$cxix} == 0) {
 	if ($^O eq 'MacOS') {
 		# first, take care of updirs and trailing colons
-		@pat = _preprocess_pattern(@pat);
+		@pat = @( < _preprocess_pattern(< @pat) );
 		# expand volume names
-		@pat = _expand_volume(@pat);
-		%entries{$cxix} = (@pat) ? \@(_un_escape( doglob_Mac(1,@pat) )) : \@();
+		@pat = @( < _expand_volume(< @pat) );
+		%entries{$cxix} = (nelems @pat) ? \@( <_un_escape( < doglob_Mac(1,< @pat) )) : \@();
 	} else {
-		%entries{$cxix} = \@(doglob(1,@pat));
+		%entries{$cxix} = \@( <doglob(1,< @pat));
     }
 	}
 
     # chuck it all out, quick or slow
-    if (wantarray) {
-	delete %iter{$cxix};
-	return @{delete %entries{$cxix}};
-    }
-    else {
-	if (%iter{$cxix} = scalar @{%entries{$cxix}}) {
-	    return shift @{%entries{$cxix}};
-	}
-	else {
-	    # return undef for EOL
-	    delete %iter{$cxix};
-	    delete %entries{$cxix};
-	    return undef;
-	}
-    }
+    delete %iter{$cxix};
+    return @{delete %entries{$cxix}};
 }
 
 {
@@ -407,7 +394,7 @@ sub glob {
 
     sub import {
     my $pkg = shift;
-    return unless @_;
+    return unless (nelems @_);
     my $sym = shift;
     my $callpkg = ($sym =~ s/^GLOBAL_//s ? 'CORE::GLOBAL' : caller(0));
     *{Symbol::fetch_glob($callpkg.'::'.$sym)} = \&{*{Symbol::fetch_glob($pkg.'::'.$sym)}} if $sym eq 'glob';
