@@ -6,7 +6,7 @@ require File::Spec::Unix;
 
 $VERSION = '3.2701';
 
-@ISA = qw(File::Spec::Unix);
+@ISA = @(qw(File::Spec::Unix));
 
 use File::Basename;
 use VMS::Filespec;
@@ -34,7 +34,7 @@ Removes redundant portions of file specifications according to VMS syntax.
 =cut
 
 sub canonpath {
-    my($self,$path) = @_;
+    my($self,$path) = <@_;
 
     return undef unless defined $path;
 
@@ -45,7 +45,8 @@ sub canonpath {
       else          { return vmsify($path);  }
     }
     else {
-	$path =~ tr/<>/[]/;			# < and >       ==> [ and ]
+	$path =~ s/</[/g;
+        $path =~ s/>/]/g;			# < and >       ==> [ and ]
 	$path =~ s/\]\[\./\.\]\[/g;		# ][.		==> .][
 	$path =~ s/\[000000\.\]\[/\[/g;		# [000000.][	==> [
 	$path =~ s/\[000000\./\[/g;		# [000000.	==> [
@@ -89,11 +90,11 @@ cases (e.g. elements other than the first being absolute filespecs).
 sub catdir {
     my $self = shift;
     my $dir = pop;
-    my @dirs = grep {defined() && length()} @_;
+    my @dirs = @( grep {defined() && length()} < @_ );
 
     my $rslt;
     if (@dirs) {
-	my $path = (@dirs == 1 ? @dirs[0] : $self->catdir(@dirs));
+	my $path = ((nelems @dirs) == 1) ? @dirs[0] : $self->catdir(< @dirs);
 	my ($spath,$sdir) = ($path,$dir);
 	$spath =~ s/\.dir\Z(?!\n)//; $sdir =~ s/\.dir\Z(?!\n)//; 
 	$sdir = $self->eliminate_macros($sdir) unless $sdir =~ m/^[\w\-]+\Z(?!\n)/s;
@@ -123,11 +124,11 @@ VMS-syntax file specification.
 sub catfile {
     my $self = shift;
     my $file = $self->canonpath(pop());
-    my @files = grep {defined() && length()} @_;
+    my @files = @(grep {defined() && length()} < @_);
 
     my $rslt;
     if (@files) {
-	my $path = (@files == 1 ? @files[0] : $self->catdir(@files));
+	my $path = ((nelems @files) == 1) ? @files[0] : $self->catdir(<@files);
 	my $spath = $path;
 	$spath =~ s/\.dir\Z(?!\n)//;
 	if ($spath =~ m/^[^\)\]\/:>]+\)\Z(?!\n)/s && basename($file) eq $file) {
@@ -222,7 +223,7 @@ to C<split> string value of C<%ENV{'PATH'}>.
 sub path {
     my (@dirs,$dir,$i);
     while ($dir = %ENV{'DCL$PATH;' . $i++}) { push(@dirs,$dir); }
-    return @dirs;
+    return < @dirs;
 }
 
 =item file_name_is_absolute (override)
@@ -232,7 +233,7 @@ Checks for VMS directory spec as well as Unix separators.
 =cut
 
 sub file_name_is_absolute {
-    my ($self,$file) = @_;
+    my ($self,$file) = <@_;
     # If it's a logical name, expand it.
     $file = %ENV{$file} while $file =~ m/^[\w\$\-]+\Z(?!\n)/s && %ENV{$file};
     return scalar($file =~ m!^/!s             ||
@@ -247,11 +248,11 @@ Splits using VMS syntax.
 =cut
 
 sub splitpath {
-    my($self,$path) = @_;
+    my($self,$path) = <@_;
     my($dev,$dir,$file) = ('','','');
 
     vmsify($path) =~ m/(.+:)?([\[<].*[\]>])?(.*)/s;
-    return ($1 || '',$2 || '',$3);
+    return @($1 || '',$2 || '',$3);
 }
 
 =item splitdir (override)
@@ -261,10 +262,11 @@ Split dirspec using VMS syntax.
 =cut
 
 sub splitdir {
-    my($self,$dirspec) = @_;
-    my @dirs = ();
+    my($self,$dirspec) = <@_;
+    my @dirs = @();
     return @dirs if ( (!defined $dirspec) || ('' eq $dirspec) );
-    $dirspec =~ tr/<>/[]/;			# < and >	==> [ and ]
+    $dirspec =~ s/</[/g;
+    $dirspec =~ s/>/]/g;			# < and >	==> [ and ]
     $dirspec =~ s/\]\[\./\.\]\[/g;		# ][.		==> .][
     $dirspec =~ s/\[000000\.\]\[/\[/g;		# [000000.][	==> [
     $dirspec =~ s/\[000000\./\[/g;		# [000000.	==> [
@@ -279,9 +281,9 @@ sub splitdir {
 						# [--]		==> [-.-]
     $dirspec = "[$dirspec]" unless $dirspec =~ m/[\[<]/; # make legal
     $dirspec =~ s/^(\[|<)\./$1/;
-    @dirs = split m/(?<!\^)\./, vmspath($dirspec);
+    @dirs = @( split m/(?<!\^)\./, vmspath($dirspec) );
     @dirs[0] =~ s/^[\[<]//s;  @dirs[-1] =~ s/[\]>]\Z(?!\n)//s;
-    @dirs;
+    < @dirs;
 }
 
 
@@ -292,7 +294,7 @@ Construct a complete filespec using VMS syntax
 =cut
 
 sub catpath {
-    my($self,$dev,$dir,$file) = @_;
+    my($self,$dev,$dir,$file) = <@_;
     
     # We look for a volume in $dev, then in $dir, but not both
     my ($dir_volume, $dir_dir, $dir_file) = $self->splitpath($dir);
@@ -316,10 +318,10 @@ Use VMS syntax when converting filespecs.
 
 sub abs2rel {
     my $self = shift;
-    return vmspath(File::Spec::Unix::abs2rel( $self, @_ ))
-        if grep m{/}, @_;
+    return vmspath(File::Spec::Unix::abs2rel( $self, < @_ ))
+        if grep m{/}, < @_;
 
-    my($path,$base) = @_;
+    my($path,$base) = < @_;
     $base = $self->_cwd() unless defined $base and length $base;
 
     for ($path, $base) { $_ = $self->canonpath($_) }
@@ -377,7 +379,7 @@ Use VMS syntax when converting filespecs.
 
 sub rel2abs {
     my $self = shift ;
-    my ($path,$base ) = @_;
+    my ($path,$base ) = < @_;
     return undef unless defined $path;
     if ($path =~ m/\//) {
 	$path = ( -d $path || $path =~ m/\/\z/  # educated guessing about
@@ -400,7 +402,7 @@ sub rel2abs {
 
         # Split up paths
         my ( $path_directories, $path_file ) =
-            ($self->splitpath( $path ))[1,2] ;
+            ($self->splitpath( $path ))[[1,2]] ;
 
         my ( $base_volume, $base_directories ) =
             $self->splitpath( $base ) ;
@@ -431,7 +433,7 @@ sub rel2abs {
 # Please consider these two methods deprecated.  Do not patch them,
 # patch the ones in ExtUtils::MM_VMS instead.
 sub eliminate_macros {
-    my($self,$path) = @_;
+    my($self,$path) = <@_;
     return '' unless (defined $path) && ($path ne '');
     $self = \%() unless ref $self;
 
@@ -439,8 +441,8 @@ sub eliminate_macros {
       return join ' ', map { $self->eliminate_macros($_) } split m/\s+/, $path;
     }
 
-    my($npath) = unixify($path);
-    my($complex) = 0;
+    my $npath = unixify($path);
+    my $complex = 0;
     my($head,$macro,$tail);
 
     # perform m##g in scalar context so it acts as an iterator
@@ -449,7 +451,7 @@ sub eliminate_macros {
             ($head,$macro,$tail) = ($1,$2,$3);
             if (ref $self->{$macro}) {
                 if (ref $self->{$macro} eq 'ARRAY') {
-                    $macro = join ' ', @{$self->{$macro}};
+                    $macro = join ' ', <@{$self->{$macro}};
                 }
                 else {
                     print "Note: can't expand macro \$($macro) containing ",ref($self->{$macro}),
