@@ -6,11 +6,11 @@ our($VERSION, @ISA, @EXPORT, @EXPORT_OK);
 $VERSION = "2.01";
 
 require IO::File;
-@ISA = qw(IO::File);
+@ISA = @( qw(IO::File) );
 
-@EXPORT = qw(_IOFBF _IOLBF _IONBF);
+@EXPORT = @( qw(_IOFBF _IOLBF _IONBF) );
 
-@EXPORT_OK = qw(
+@EXPORT_OK = @( qw(
     pipe
 
     autoflush
@@ -23,13 +23,13 @@ require IO::File;
     printf
     getline
     getlines
-);
+) );
 
 #
 # Everything we're willing to export, we must first import.
 #
 require IO::Handle;
-IO::Handle->import(grep { !defined(&$_) } @EXPORT, @EXPORT_OK);
+IO::Handle->import(grep { !defined(&$_) } < @EXPORT, < @EXPORT_OK);
 
 #
 # Some people call "FileHandle::function", so all the functions
@@ -38,7 +38,7 @@ IO::Handle->import(grep { !defined(&$_) } @EXPORT, @EXPORT_OK);
 {
     no strict 'refs';
 
-    my %import = (
+    my %import = %(
 	'IO::Handle' =>
 	    \@(qw(new_from_fd fdopen close fileno getc ungetc gets
 		eof flush error clearerr setbuf setvbuf _open_mode_string)),
@@ -48,7 +48,7 @@ IO::Handle->import(grep { !defined(&$_) } @EXPORT, @EXPORT_OK);
 	    \@(qw(new new_tmpfile open))
     );
     for my $pkg (keys %import) {
-	for my $func (@{%import{$pkg}}) {
+	for my $func (< @{%import{$pkg}}) {
 	    my $c = *{Symbol::fetch_glob("{$pkg}::$func")}{CODE}
 		or die "{$pkg}::$func missing";
 	    *{Symbol::fetch_glob($func)} = $c;
@@ -63,13 +63,13 @@ sub import {
     my $pkg = shift;
     my $callpkg = caller;
     require Exporter;
-    Exporter::export($pkg, $callpkg, @_);
+    Exporter::export($pkg, $callpkg, < @_);
 
     #
     # If the Fcntl extension is available,
     #  export its constants.
     #
-    eval {
+    try {
 	require Fcntl;
 	Exporter::export('Fcntl', $callpkg);
     };
@@ -84,7 +84,7 @@ sub pipe {
     my $r = IO::Handle->new();
     my $w = IO::Handle->new();
     CORE::pipe($r, $w) or return undef;
-    ($r, $w);
+    return @($r, $w);
 }
 
 # Rebless standard file handles
