@@ -99,11 +99,13 @@ use Config;
 use File::Basename;
 use File::Spec;
 
-@EXPORT_OK = qw($Bin $Script $RealBin $RealScript $Dir $RealDir);
-%EXPORT_TAGS = (ALL => \@(qw($Bin $Script $RealBin $RealScript $Dir $RealDir)));
-@ISA = qw(Exporter);
 
-$VERSION = "1.49";
+our ($Bin, $Script, $RealBin, $RealScript, $Dir, $RealDir);
+our @EXPORT_OK = @( qw($Bin $Script $RealBin $RealScript $Dir $RealDir) );
+our %EXPORT_TAGS = %(ALL => \@(qw($Bin $Script $RealBin $RealScript $Dir $RealDir)));
+our @ISA = @( qw(Exporter) );
+
+our $VERSION = "1.49";
 
 
 # needed for VMS-specific filename translation
@@ -150,7 +152,7 @@ sub init
             && -f $script)
       {
        my $dir;
-       foreach $dir (File::Spec->path)
+       foreach $dir ( <File::Spec->path)
         {
         my $scr = File::Spec->catfile($dir, $script);
 
@@ -176,14 +178,14 @@ sub init
      $script = File::Spec->catfile(cwd2(), $script)
        unless File::Spec->file_name_is_absolute($script);
 
-     ($Script,$Bin) = fileparse($script);
+     ($Script,$Bin) = < fileparse($script);
 
      # Resolve $script if it is a link
      while(1)
       {
        my $linktext = readlink($script);
 
-       ($RealScript,$RealBin) = fileparse($script);
+       ($RealScript,$RealBin) = < fileparse($script);
        last unless defined $linktext;
 
        $script = (File::Spec->file_name_is_absolute($linktext))
