@@ -6,21 +6,21 @@ package I18N::LangTags;
 use strict;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION %Panic);
 require Exporter;
-@ISA = qw(Exporter);
-@EXPORT = qw();
-@EXPORT_OK = qw(is_language_tag same_language_tag
+@ISA = @( qw(Exporter) );
+@EXPORT = @( qw() );
+@EXPORT_OK = @( qw(is_language_tag same_language_tag
                 extract_language_tags super_languages
                 similarity_language_tag is_dialect_of
                 locale2language_tag alternate_language_tags
                 encode_language_tag panic_languages
                 implicate_supers
                 implicate_supers_strictly
-               );
-%EXPORT_TAGS = ('ALL' => \@EXPORT_OK);
+               ) );
+%EXPORT_TAGS = %('ALL' => \@EXPORT_OK);
 
 $VERSION = "0.35";
 
-sub uniq { my %seen; return grep(!(%seen{$_}++), @_); } # a util function
+sub uniq { my %seen; return @( grep(!(%seen{$_}++), < @_) ); } # a util function
 
 
 =head1 NAME
@@ -239,11 +239,11 @@ sub similarity_language_tag {
   return undef if !defined($lang1) and !defined($lang2);
   return 0 if !defined($lang1) or !defined($lang2);
 
-  my @l1_subtags = split('-', $lang1);
-  my @l2_subtags = split('-', $lang2);
+  my @l1_subtags = @( split('-', $lang1) );
+  my @l2_subtags = @( split('-', $lang2) );
   my $similarity = 0;
 
-  while(@l1_subtags and @l2_subtags) {
+  while((nelems @l1_subtags) and nelems @l2_subtags) {
     if(shift(@l1_subtags) eq shift(@l2_subtags)) {
       ++$similarity;
     } else {
@@ -348,20 +348,20 @@ sub super_languages {
   $lang1 =~ s/^[ix](-hakka\b)/zh$1/i; # goes the right way
    # i-hakka-bork-bjork-bjark => zh-hakka-bork-bjork-bjark
 
-  my @l1_subtags = split('-', $lang1);
+  my @l1_subtags = @( split('-', $lang1) );
 
   ## Changes in the language tagging standards may have to be reflected here.
 
   # NB: (i-sil-...)?
 
-  my @supers = ();
-  foreach my $bit (@l1_subtags) {
+  my @supers = @( () );
+  foreach my $bit (< @l1_subtags) {
     push @supers, 
-      scalar(@supers) ? (@supers[-1] . '-' . $bit) : $bit;
+      scalar(nelems @supers) ? (@supers[-1] . '-' . $bit) : $bit;
   }
-  pop @supers if @supers;
-  shift @supers if @supers && @supers[0] =~ m<^[iIxX]$>s;
-  return reverse @supers;
+  pop @supers if (nelems @supers);
+  shift @supers if (nelems @supers) && @supers[0] =~ m<^[iIxX]$>s;
+  return @(reverse < @supers);
 }
 
 ###########################################################################
@@ -401,7 +401,7 @@ sub locale2language_tag {
 
   return $lang if &is_language_tag($lang); # like "en"
 
-  $lang =~ tr<_><->;  # "en_US" -> en-US
+  $lang =~ s<_><->g;  # "en_US" -> en-US
   $lang =~ s<(?:[\.\@][-_a-zA-Z0-9]+)+$><>s;  # "en_US.ISO8859-1" -> en-US
    # it_IT.utf8@euro => it-IT
 
@@ -594,7 +594,7 @@ valid language tag.
 
 =cut
 
-my %alt = qw( i x   x i   I X   X I );
+my %alt = %( qw( i x   x i   I X   X I ) );
 sub alternate_language_tags {
   my $tag = @_[0];
   return() unless &is_language_tag($tag);
@@ -638,7 +638,7 @@ sub alternate_language_tags {
 {
   # Init %Panic...
   
-  my @panic = (  # MUST all be lowercase!
+  my @panic = @(  # MUST all be lowercase!
    # Only large ("national") languages make it in this list.
    #  If you, as a user, are so bizarre that the /only/ language
    #  you claim to accept is Galician, then no, we won't do you
@@ -688,10 +688,10 @@ sub alternate_language_tags {
 
   );
   my($k,$v);
-  while(@panic) {
+  while((nelems @panic)) {
     ($k,$v) = splice(@panic,0,2);
-    foreach my $k (ref($k) ? @$k : $k) {
-      foreach my $v (ref($v) ? @$v : $v) {
+    foreach my $k (ref($k) ? < @$k : $k) {
+      foreach my $v (ref($v) ? < @$v : $v) {
         push @{%Panic{$k} ||= \@()}, $v unless $k eq $v;
       }
     }
@@ -732,13 +732,13 @@ A useful construct you might consider using is:
 sub panic_languages {
   # When in panic or in doubt, run in circles, scream, and shout!
   my(@out, %seen);
-  foreach my $t (@_) {
+  foreach my $t (< @_) {
     next unless $t;
     next if %seen{$t}++; # so we don't return it or hit it again
     # push @out, super_languages($t); # nah, keep that separate
-    push @out, @{ %Panic{lc $t} || next };
+    push @out, < @{ %Panic{lc $t} || next };
   }
-  return grep !%seen{$_}++,  @out, 'en';
+  return @(grep !%seen{$_}++,  < @out, 'en');
 }
 
 #---------------------------------------------------------------------------
@@ -793,28 +793,28 @@ as far as I'm concerned) you'd use implicate_supers.
 =cut
 
 sub implicate_supers {
-  my @languages = grep is_language_tag($_), @_;
+  my @languages = @( grep is_language_tag($_), < @_ );
   my %seen_encoded;
-  foreach my $lang (@languages) {
+  foreach my $lang (< @languages) {
     %seen_encoded{ I18N::LangTags::encode_language_tag($lang) } = 1
   }
 
   my(@output_languages);
-  foreach my $lang (@languages) {
+  foreach my $lang (< @languages) {
     push @output_languages, $lang;
-    foreach my $s ( I18N::LangTags::super_languages($lang) ) {
+    foreach my $s ( < I18N::LangTags::super_languages($lang) ) {
       # Note that super_languages returns the longest first.
       last if %seen_encoded{ I18N::LangTags::encode_language_tag($s) };
       push @output_languages, $s;
     }
   }
-  return uniq( @output_languages );
+  return uniq( < @output_languages );
 
 }
 
 sub implicate_supers_strictly {
-  my @tags = grep is_language_tag($_), @_;
-  return uniq( @_,   map super_languages($_), @_ );
+  my @tags = @( grep is_language_tag($_), < @_ );
+  return uniq( < @_,   map < super_languages($_), < @_ );
 }
 
 
