@@ -14,7 +14,7 @@ BEGIN { unless(defined &DEBUG) { *DEBUG = sub () {0} } }
  # define the constant 'DEBUG' at compile-time
 
 $VERSION = "1.10_01";
-@ISA = ();
+@ISA = @( () );
 
 $MATCH_SUPERS = 1;
 $MATCH_SUPERS_TIGHTLY = 1;
@@ -27,31 +27,31 @@ $USING_LANGUAGE_TAGS  = 1;
 $USE_LITERALS = 1 unless defined $USE_LITERALS;
  # a hint for compiling bracket-notation things.
 
-my %isa_scan = ();
+my %isa_scan = %( () );
 
 ###########################################################################
 
 sub quant {
-  my($handle, $num, @forms) = @_;
+  my($handle, $num, < @forms) = < @_;
 
-  return $num if @forms == 0; # what should this mean?
-  return @forms[2] if @forms +> 2 and $num == 0; # special zeroth case
+  return $num if (nelems @forms) == 0; # what should this mean?
+  return @forms[2] if (nelems @forms) +> 2 and $num == 0; # special zeroth case
 
   # Normal case:
   # Note that the formatting of $num is preserved.
-  return( $handle->numf($num) . ' ' . $handle->numerate($num, @forms) );
+  return $handle->numf($num) . ' ' . $handle->numerate($num, < @forms);
    # Most human languages put the number phrase before the qualified phrase.
 }
 
 
 sub numerate {
  # return this lexical item in a form appropriate to this number
-  my($handle, $num, @forms) = @_;
+  my($handle, $num, < @forms) = < @_;
   my $s = ($num == 1);
 
-  return '' unless @forms;
-  if(@forms == 1) { # only the headword form specified
-    return $s ? @forms[0] : (@forms[0] . 's'); # very cheap hack.
+  return '' unless (nelems @forms);
+  if((nelems @forms) == 1) { # only the headword form specified
+    return $s ? @forms[0] :  @(@forms[0] . 's'); # very cheap hack.
   } else { # sing and plural were specified
     return $s ? @forms[0] : @forms[1];
   }
@@ -73,15 +73,15 @@ sub numf {
    #  backtrack so it un-eats the rightmost three, and then we
    #  insert the comma there.
 
-  $num =~ tr<.,><,.> if ref($handle) and $handle->{'numf_comma'};
+  $num =~ s<(.,)><{$1 eq ',' ? '.' : ','}>g if ref($handle) and $handle->{'numf_comma'};
    # This is just a lame hack instead of using Number::Format
   return $num;
 }
 
 sub sprintf {
   no integer;
-  my($handle, $format, @params) = @_;
-  return CORE::sprintf($format, @params);
+  my($handle, $format, < @params) = < @_;
+  return CORE::sprintf($format, < @params);
     # "CORE::" is there to avoid confusion with myself!
 }
 
@@ -93,13 +93,13 @@ sub language_tag {
   my $it = ref(@_[0]) || @_[0];
   return undef unless $it =~ m/([^':]+)(?:::)?$/s;
   $it = lc($1);
-  $it =~ tr<_><->;
+  $it =~ s<_><->g;
   return $it;
 }
 
 sub encoding {
   my $it = @_[0];
-  return(
+  return @(
    (ref($it) && $it->{'encoding'})
    || "iso-8859-1"   # Latin-1
   );
@@ -107,16 +107,16 @@ sub encoding {
 
 #--------------------------------------------------------------------------
 
-sub fallback_languages { return('i-default', 'en', 'en-US') }
+sub fallback_languages { return @('i-default', 'en', 'en-US') }
 
 sub fallback_language_classes { return () }
 
 #--------------------------------------------------------------------------
 
 sub fail_with { # an actual attribute method!
-  my($handle, @params) = @_;
+  my($handle, < @params) = < @_;
   return unless ref($handle);
-  $handle->{'fail'} = @params[0] if @params;
+  $handle->{'fail'} = @params[0] if (nelems @params);
   return $handle->{'fail'};
 }
 
@@ -126,7 +126,7 @@ sub failure_handler_auto {
   # Meant to be used like:
   #  $handle->fail_with('failure_handler_auto')
 
-  my($handle, $phrase, @params) = @_;
+  my($handle, $phrase, < @params) = < @_;
   $handle->{'failure_lex'} ||= \%();
   my $lex = $handle->{'failure_lex'};
 
@@ -135,7 +135,7 @@ sub failure_handler_auto {
 
   # Dumbly copied from sub maketext:
   {
-    eval { $value = &$value($handle, @_) };
+    try { $value = &$value($handle, < @_) };
   }
   # If we make it here, there was an exception thrown in the
   #  call to $value, and so scream:
@@ -169,7 +169,7 @@ sub init { return } # no-op
 
 sub maketext {
   # Remember, this can fail.  Failure is controllable many ways.
-  Carp::croak "maketext requires at least one parameter" unless @_ +> 1;
+  Carp::croak "maketext requires at least one parameter" unless (nelems @_) +> 1;
 
   my($handle, $phrase) = splice(@_,0,2);
 
@@ -180,7 +180,7 @@ sub maketext {
 
   my $value;
   foreach my $h_r (
-    @{  %isa_scan{ref($handle) || $handle} || $handle->_lex_refs  }
+    < @{  %isa_scan{ref($handle) || $handle} || $handle->_lex_refs  }
   ) {
     print "* Looking up \"$phrase\" in $h_r\n" if DEBUG;
     if(exists $h_r->{$phrase}) {
@@ -208,10 +208,10 @@ sub maketext {
       print "WARNING0: maketext fails looking for <$phrase>\n" if DEBUG;
       my $fail;
       if(ref($fail = $handle->{'fail'}) eq 'CODE') { # it's a sub reference
-        return &{$fail}($handle, $phrase, @_);
+        return &{$fail}($handle, $phrase, < @_);
          # If it ever returns, it should return a good value.
       } else { # It's a method name
-        return $handle->?$fail($phrase, @_);
+        return $handle->?$fail($phrase, < @_);
          # If it ever returns, it should return a good value.
       }
     } else {
@@ -224,17 +224,17 @@ sub maketext {
   return $value unless ref($value) eq 'CODE';
   
   {
-    eval { $value = &$value($handle, @_) };
+    try { $value = &$value($handle, < @_) };
   }
   # If we make it here, there was an exception thrown in the
   #  call to $value, and so scream:
   if($@) {
-    my $err = $@;
+    my $err = $@->message;
     # pretty up the error message
     $err =~ s<\s+at\s+\(eval\s+\d+\)\s+line\s+(\d+)\.?\n?>
              <\n in bracket code [compiled line $1],>s;
     #$err =~ s/\n?$/\n/s;
-    Carp::croak "Error in maketexting \"$phrase\":\n$err as used";
+    die "Error in maketexting \"$phrase\":\n$err as used";
     # Rather unexpected, but suppose that the sub tried calling
     # a method that didn't exist.
   } else {
@@ -248,35 +248,35 @@ sub get_handle {  # This is a constructor and, yes, it CAN FAIL.
   # Its class argument has to be the base class for the current
   # application's l10n files.
 
-  my($base_class, @languages) = @_;
+  my($base_class, < @languages) = < @_;
   $base_class = ref($base_class) || $base_class;
    # Complain if they use __PACKAGE__ as a project base class?
   
-  if( @languages ) {
-    DEBUG and print "Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+  if( (nelems @languages) ) {
+    DEBUG and print "Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
     if($USING_LANGUAGE_TAGS) {   # An explicit language-list was given!
-      @languages =
-       map {; $_, I18N::LangTags::alternate_language_tags($_) }
+      @languages = @(
+       map {; $_, < I18N::LangTags::alternate_language_tags($_) }
         # Catch alternation
        map I18N::LangTags::locale2language_tag($_),
         # If it's a lg tag, fine, pass thru (untainted)
         # If it's a locale ID, try converting to a lg tag (untainted),
         # otherwise nix it.
-       @languages;
-      DEBUG and print "Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+       < @languages );
+      DEBUG and print "Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
     }
   } else {
-    @languages = $base_class->_ambient_langprefs;
+    @languages = @( < $base_class->_ambient_langprefs );
   }
  
-  @languages = $base_class->_langtag_munging(@languages);
+  @languages = @( < $base_class->_langtag_munging(< @languages) );
 
   my %seen;
-  foreach my $module_name ( map { $base_class . "::" . $_ }  @languages ) {
+  foreach my $module_name ( map { $base_class . "::" . $_ }  < @languages ) {
     next unless length $module_name; # sanity
     next if %seen{$module_name}++        # Already been here, and it was no-go
-            || !&_try_use($module_name); # Try to use() it, but can't it.
-    return($module_name->new); # Make it!
+            || ! _try_use($module_name); # Try to use() it, but can't it.
+    return $module_name->new; # Make it!
   }
 
   return undef; # Fail!
@@ -285,48 +285,49 @@ sub get_handle {  # This is a constructor and, yes, it CAN FAIL.
 ###########################################################################
 
 sub _langtag_munging {
-  my($base_class, @languages) = @_;
+  my($base_class, < @languages) = < @_;
 
   # We have all these DEBUG statements because otherwise it's hard as hell
   # to diagnose ifwhen something goes wrong.
 
-  DEBUG and print "Lgs1: ", map("<$_>", @languages), "\n";
+  DEBUG and print "Lgs1: ", map("<$_>", < @languages), "\n";
 
   if($USING_LANGUAGE_TAGS) {
-    DEBUG and print "Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
-    @languages     = $base_class->_add_supers( @languages );
+    DEBUG and print "Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
+    @languages     = @( < $base_class->_add_supers( < @languages ) );
 
-    push @languages, I18N::LangTags::panic_languages(@languages);
+    push @languages, < I18N::LangTags::panic_languages(< @languages);
     DEBUG and print "After adding panic languages:\n", 
-      " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+      " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
 
-    push @languages, $base_class->fallback_languages;
+    push @languages, < $base_class->fallback_languages;
      # You are free to override fallback_languages to return empty-list!
-    DEBUG and print "Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+    DEBUG and print "Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
 
-    @languages =  # final bit of processing to turn them into classname things
+    @languages = @(  # final bit of processing to turn them into classname things
       map {
         my $it = $_;  # copy
-        $it =~ tr<-A-Z><_a-z>; # lc, and turn - to _
-        $it =~ tr<_a-z0-9><>cd;  # remove all but a-z0-9_
+        $it = lc($it);
+        $it =~ s<-><_>g; # lc, and turn - to _
+        $it =~ s<[^_a-z0-9]><>g;  # remove all but a-z0-9_
         $it;
-      } @languages
+      } < @languages )
     ;
     DEBUG and print "Nearing end of munging:\n", 
-      " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+      " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
   } else {
     DEBUG and print "Bypassing language-tags.\n", 
-      " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+      " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
   }
 
   DEBUG and print "Before adding fallback classes:\n", 
-    " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+    " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
 
-  push @languages, $base_class->fallback_language_classes;
+  push @languages, < $base_class->fallback_language_classes;
    # You are free to override that to return whatever.
 
   DEBUG and print "Finally:\n", 
-    " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+    " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
 
   return @languages;
 }
@@ -341,26 +342,26 @@ sub _ambient_langprefs {
 ###########################################################################
 
 sub _add_supers {
-  my($base_class, @languages) = @_;
+  my($base_class, < @languages) = < @_;
 
   if(!$MATCH_SUPERS) {
     # Nothing
     DEBUG and print "Bypassing any super-matching.\n", 
-      " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+      " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
 
   } elsif( $MATCH_SUPERS_TIGHTLY ) {
     DEBUG and print "Before adding new supers tightly:\n", 
-      " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
-    @languages = I18N::LangTags::implicate_supers( @languages );
+      " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
+    @languages = @( < I18N::LangTags::implicate_supers( < @languages ) );
     DEBUG and print "After adding new supers tightly:\n", 
-      " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+      " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
 
   } else {
     DEBUG and print "Before adding supers to end:\n", 
-      " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
-    @languages = I18N::LangTags::implicate_supers_strictly( @languages );
+      " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
+    @languages = @( < I18N::LangTags::implicate_supers_strictly( < @languages ) );
     DEBUG and print "After adding supers to end:\n", 
-      " Lgs\@", __LINE__, ": ", map("<$_>", @languages), "\n";
+      " Lgs\@", __LINE__, ": ", map("<$_>", < @languages), "\n";
   }
   
   return @languages;
@@ -376,7 +377,7 @@ use Locale::Maketext::GutsLoader;
 
 ###########################################################################
 
-my %tried = ();
+my %tried = %( () );
   # memoization of whether we've used this module, or found it unusable.
 
 sub _try_use {   # Basically a wrapper around "require Modulename"
@@ -385,8 +386,8 @@ sub _try_use {   # Basically a wrapper around "require Modulename"
 
   my $module = @_[0];   # ASSUME sane module name!
   { no strict 'refs';
-    return(%tried{$module} = 1)
-     if defined(%{*{Symbol::fetch_glob($module . "::Lexicon")}}) or defined(@{*{Symbol::fetch_glob($module . "::ISA")}});
+    return (%tried{$module} = 1)
+     if %{*{Symbol::fetch_glob($module . "::Lexicon")}} or @{*{Symbol::fetch_glob($module . "::ISA")}};
     # weird case: we never use'd it, but there it is!
   }
 
@@ -423,17 +424,17 @@ sub _lex_refs {  # report the lexicon references for this handle's class
 
   # Implements depth(height?)-first recursive searching of superclasses.
   # In hindsight, I suppose I could have just used Class::ISA!
-  foreach my $superclass (@{*{Symbol::fetch_glob($class . "::ISA")}}) {
+  foreach my $superclass (< @{*{Symbol::fetch_glob($class . "::ISA")}}) {
     print " Super-class search into $superclass\n" if DEBUG;
     next if $seen_r->{$superclass}++;
-    push @lex_refs, @{&_lex_refs($superclass, $seen_r)};  # call myself
+    push @lex_refs, < @{&_lex_refs($superclass, $seen_r)};  # call myself
   }
 
   %isa_scan{$class} = \@lex_refs; # save for next time
   return \@lex_refs;
 }
 
-sub clear_isa_scan { %isa_scan = (); return; } # end on a note of simplicity!
+sub clear_isa_scan { %isa_scan = %( () ); return; } # end on a note of simplicity!
 
 ###########################################################################
 1;
