@@ -5,15 +5,15 @@ our $VERSION = '1.01';
 our(@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 BEGIN { 
     use Exporter   ();
-    @EXPORT      = qw(gethostbyname gethostbyaddr gethost);
-    @EXPORT_OK   = qw(
+    @EXPORT      = @( qw(gethostbyname gethostbyaddr gethost) );
+    @EXPORT_OK   = @( qw(
 			$h_name	    	@h_aliases
 			$h_addrtype 	$h_length
 			@h_addr_list 	$h_addr
-		   );
-    %EXPORT_TAGS = ( FIELDS => \@( @EXPORT_OK, @EXPORT ) );
+		   ) );
+    %EXPORT_TAGS = %( FIELDS => \@( < @EXPORT_OK, < @EXPORT ) );
 }
-use vars      @EXPORT_OK;
+use vars      < @EXPORT_OK;
 
 # Class::Struct forbids use of @ISA
 sub import { goto &Exporter::import }
@@ -30,14 +30,14 @@ struct 'Net::hostent' => \@(
 sub addr { shift->addr_list->[0] }
 
 sub populate (@) {
-    return unless @_;
+    return unless (nelems @_);
     my $hob = new();
     $h_name 	 =    $hob->[0]     	     = @_[0];
-    @h_aliases	 = @{ $hob->[1] } = split ' ', @_[1];
+    @h_aliases	 = @( @{ $hob->[1] } = @( split ' ', @_[1] ) );
     $h_addrtype  =    $hob->[2] 	     = @_[2];
     $h_length	 =    $hob->[3] 	     = @_[3];
     $h_addr 	 =                             @_[4];
-    @h_addr_list = @{ $hob->[4] } =          @_[[ (4 .. (@_-1)) ]];
+    @h_addr_list = @( @{ $hob->[4] } = @(          @_[[ (4 .. ((nelems @_)-1)) ]] ) );
     return $hob;
 } 
 
@@ -46,15 +46,15 @@ sub gethostbyname ($)  { populate(CORE::gethostbyname(shift)) }
 sub gethostbyaddr ($;$) { 
     my ($addr, $addrtype);
     $addr = shift;
-    require Socket unless @_;
-    $addrtype = @_ ? shift : Socket::AF_INET();
+    require Socket unless (nelems @_);
+    $addrtype = (nelems @_) ? shift : Socket::AF_INET();
     populate(CORE::gethostbyaddr($addr, $addrtype)) 
 } 
 
 sub gethost($) {
     if (@_[0] =~ m/^\d+(?:\.\d+(?:\.\d+(?:\.\d+)?)?)?$/) {
 	require Socket;
-	&gethostbyaddr(Socket::inet_aton(shift));
+	&gethostbyaddr( <Socket::inet_aton(shift));
     } else {
 	&gethostbyname;
     } 
