@@ -5,11 +5,11 @@ our $VERSION = '1.00';
 our(@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 BEGIN { 
     use Exporter   ();
-    @EXPORT      = qw(getprotobyname getprotobynumber getprotoent getproto);
-    @EXPORT_OK   = qw( $p_name @p_aliases $p_proto );
-    %EXPORT_TAGS = ( FIELDS => \@( @EXPORT_OK, @EXPORT ) );
+    @EXPORT      = @( qw(getprotobyname getprotobynumber getprotoent getproto) );
+    @EXPORT_OK   = @( qw( $p_name @p_aliases $p_proto ) );
+    %EXPORT_TAGS = %( FIELDS => \@( < @EXPORT_OK, < @EXPORT ) );
 }
-use vars      @EXPORT_OK;
+use vars      < @EXPORT_OK;
 
 # Class::Struct forbids use of @ISA
 sub import { goto &Exporter::import }
@@ -22,10 +22,10 @@ struct 'Net::protoent' => \@(
 );
 
 sub populate (@) {
-    return unless @_;
+    return unless (nelems @_);
     my $pob = new();
     $p_name 	 =    $pob->[0]     	     = @_[0];
-    @p_aliases	 = @{ $pob->[1] } = split ' ', @_[1];
+    @p_aliases	 = @( @{ $pob->[1] } = @( split ' ', @_[1] ) );
     $p_proto	 =    $pob->[2] 	     = @_[2];
     return $pob;
 } 
@@ -36,7 +36,7 @@ sub getprotobynumber ($)  { populate(CORE::getprotobynumber(shift)) }
 
 sub getproto ($;$) {
     no strict 'refs';
-    return &{'getprotoby' . (@_[0]=~m/^\d+$/ ? 'number' : 'name')}(@_);
+    return &{'getprotoby' . (@_[0]=~m/^\d+$/ ? 'number' : 'name')}(< @_);
 }
 
 1;
