@@ -5,11 +5,11 @@ our $VERSION = '1.01';
 our(@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 BEGIN {
     use Exporter   ();
-    @EXPORT      = qw(getservbyname getservbyport getservent getserv);
-    @EXPORT_OK   = qw( $s_name @s_aliases $s_port $s_proto );
-    %EXPORT_TAGS = ( FIELDS => \@( @EXPORT_OK, @EXPORT ) );
+    @EXPORT      = @( qw(getservbyname getservbyport getservent getserv) );
+    @EXPORT_OK   = @( qw( $s_name @s_aliases $s_port $s_proto ) );
+    %EXPORT_TAGS = %( FIELDS => \@( < @EXPORT_OK, < @EXPORT ) );
 }
-use vars      @EXPORT_OK;
+use vars      < @EXPORT_OK;
 
 # Class::Struct forbids use of @ISA
 sub import { goto &Exporter::import }
@@ -23,10 +23,10 @@ struct 'Net::servent' => \@(
 );
 
 sub populate (@) {
-    return unless @_;
+    return unless (nelems @_);
     my $sob = new();
     $s_name 	 =    $sob->[0]     	     = @_[0];
-    @s_aliases	 = @{ $sob->[1] } = split ' ', @_[1];
+    @s_aliases	 = @( @{ $sob->[1] } = @( split ' ', @_[1] ) );
     $s_port	 =    $sob->[2] 	     = @_[2];
     $s_proto	 =    $sob->[3] 	     = @_[3];
     return $sob;
@@ -38,7 +38,7 @@ sub getservbyport ($;$) { populate(CORE::getservbyport(shift,shift||'tcp')) }
 
 sub getserv ($;$) {
     no strict 'refs';
-    return &{'getservby' . (@_[0]=~m/^\d+$/ ? 'port' : 'name')}(@_);
+    return &{'getservby' . (@_[0]=~m/^\d+$/ ? 'port' : 'name')}(< @_);
 }
 
 1;
