@@ -4,9 +4,9 @@
 package Pod::Escapes;
 require Exporter;
 use strict;
-our @ISA = ('Exporter');
+our @ISA = @('Exporter');
 our $VERSION = '1.04';
-our @EXPORT_OK = qw(
+our @EXPORT_OK = @( qw(
   %Code2USASCII
   %Name2character
   %Name2character_number
@@ -14,8 +14,8 @@ our @EXPORT_OK = qw(
   %Latin1Char_to_fallback
   e2char
   e2charnum
-);
-our %EXPORT_TAGS = ('ALL' => \@EXPORT_OK);
+) );
+our %EXPORT_TAGS = %('ALL' => \@EXPORT_OK);
 
 #==========================================================================
 
@@ -96,7 +96,7 @@ sub e2charnum {
 
 #--------------------------------------------------------------------------
 
-%Name2character_number = (
+%Name2character_number = %(
  # General XML/XHTML:
  'lt'   => 60,
  'gt'   => 62,
@@ -371,7 +371,7 @@ sub e2charnum {
 
 # Fill out %Name2character...
 {
-  %Name2character = ();
+  %Name2character = %( () );
   my($name, $number);
   while( ($name, $number) = each %Name2character_number) {
       %Name2character{$name} = chr $number;
@@ -389,7 +389,7 @@ sub e2charnum {
 
 #--------------------------------------------------------------------------
 
-%Code2USASCII = (
+%Code2USASCII = %(
 # mostly generated by
 #  perl -e "printf qq{  \x25 3s, '\x25s',\n}, $_, chr($_) foreach (32 .. 126)"
    32, ' ',
@@ -491,7 +491,7 @@ sub e2charnum {
 
 #--------------------------------------------------------------------------
 
-%Latin1Code_to_fallback = ();
+%Latin1Code_to_fallback = %( () );
 %Latin1Code_to_fallback{[0xA0 .. 0xFF]} = (
 # Copied from Text/Unidecode/x00.pm:
 
@@ -506,7 +506,7 @@ sub e2charnum {
 
 {
   # Now stuff %Latin1Char_to_fallback:
-  %Latin1Char_to_fallback = ();
+  %Latin1Char_to_fallback = %( () );
   my($k,$v);
   while( ($k,$v) = each %Latin1Code_to_fallback) {
     %Latin1Char_to_fallback{chr $k} = $v;
