@@ -35,7 +35,7 @@ use Carp qw(croak);
 use Pod::Simple ();
 use POSIX qw(strftime);
 
-@ISA = qw(Pod::Simple);
+@ISA = @( qw(Pod::Simple) );
 
 # Don't use the CVS revision as the version, since this module is also in Perl
 # core and too many things could munge CVS magic revision strings.  This
@@ -94,7 +94,7 @@ sub new {
     # to put them in our object as hash keys and values.  This could cause
     # problems if we ever clash with Pod::Simple's own internal class
     # variables.
-    %$self = (%$self, @_);
+    %$self = %(< %$self, < @_);
 
     # Initialize various other internal constants based on our arguments.
     $self->init_fonts;
@@ -120,7 +120,7 @@ sub toescape { (length (@_[0]) +> 1 ? '\f(' : '\f') . @_[0] }
 # fonts may be set by the user.  Sets the internal hash key FONTS which is
 # used to map our internal font escapes to actual *roff sequences later.
 sub init_fonts {
-    my ($self) = @_;
+    my ($self) = < @_;
 
     # Figure out the fixed-width font.  If user-supplied, make sure that they
     # are the right length.
@@ -154,7 +154,7 @@ sub init_fonts {
 # that the quotes will be safe against *roff.  Sets the internal hash keys
 # LQUOTE and RQUOTE.
 sub init_quotes {
-    my ($self) = (@_);
+    my ($self) = (< @_);
 
     %$self{quotes} ||= '"';
     if (%$self{quotes} eq 'none') {
@@ -178,7 +178,7 @@ sub init_quotes {
 
 # Initialize the page title information and indentation from our arguments.
 sub init_page {
-    my ($self) = @_;
+    my ($self) = < @_;
 
     # We used to try first to get the version number from a local binary, but
     # we shouldn't need that any more.  Get the version from the running Perl.
@@ -220,18 +220,18 @@ sub init_page {
 # Add a block of text to the contents of the current node, formatting it
 # according to the current formatting instructions as we do.
 sub _handle_text {
-    my ($self, $text) = @_;
+    my ($self, $text) = < @_;
     DEBUG +> 3 and print "== $text\n";
-    my $tag = %$self{PENDING}[-1];
+    my $tag = %$self{PENDING}->[-1];
     @$tag[2] .= $self->format_text (@$tag[1], $text);
 }
 
 # Given an element name, get the corresponding method name.
 sub method_for_element {
-    my ($self, $element) = @_;
-    $element =~ tr/-/_/;
-    $element =~ tr/A-Z/a-z/;
-    $element =~ tr/_a-z0-9//cd;
+    my ($self, $element) = < @_;
+    $element =~ s/-/_/g;
+    $element =~ s/([A-Z])/{lc($1)}/g;
+    $element =~ s/[^_a-z0-9]//g;
     return $element;
 }
 
@@ -240,8 +240,8 @@ sub method_for_element {
 # element method, and create a new tree into which we'll collect blocks of
 # text and nested elements.  Otherwise, if start_element is defined, call it.
 sub _handle_element_start {
-    my ($self, $element, $attrs) = @_;
-    DEBUG +> 3 and print "++ $element (<", join ('> <', %$attrs), ">)\n";
+    my ($self, $element, $attrs) = < @_;
+    DEBUG +> 3 and print "++ $element (<", join ('> <', < %$attrs), ">)\n";
     my $method = $self->method_for_element ($element);
 
     # If we have a command handler, we need to accumulate the contents of the
@@ -256,10 +256,10 @@ sub _handle_element_start {
         # and also depends on our parent tags.  Thankfully, inside tags that
         # turn off guesswork and reformatting, nothing else can turn it back
         # on, so this can be strictly inherited.
-        my $formatting = %$self{PENDING}[-1][1];
+        my $formatting = %$self{PENDING}->[-1]->[1];
         $formatting = $self->formatting ($formatting, $element);
         push (@{ %$self{PENDING} }, \@( $attrs, $formatting, '' ));
-        DEBUG +> 4 and print "Pending: [", pretty (%$self{PENDING}), "]\n";
+        DEBUG +> 4 and print "Pending: [", < pretty (%$self{PENDING}), "]\n";
     } elsif ($self->can ("start_$method")) {
         my $method = 'start_' . $method;
         $self->?$method ($attrs, '');
@@ -272,7 +272,7 @@ sub _handle_element_start {
 # this is where we pass along the tree that we built.  Otherwise, if we have
 # an end_ method for the element, call that.
 sub _handle_element_end {
-    my ($self, $element) = @_;
+    my ($self, $element) = < @_;
     DEBUG +> 3 and print "-- $element\n";
     my $method = $self->method_for_element ($element);
 
@@ -281,13 +281,13 @@ sub _handle_element_end {
     if ($self->can ("cmd_$method")) {
         DEBUG +> 2 and print "</$element> stops saving a tag\n";
         my $tag = pop @{ %$self{PENDING} };
-        DEBUG +> 4 and print "Popped: [", pretty ($tag), "]\n";
-        DEBUG +> 4 and print "Pending: [", pretty (%$self{PENDING}), "]\n";
+        DEBUG +> 4 and print "Popped: [", < pretty ($tag), "]\n";
+        DEBUG +> 4 and print "Pending: [", < pretty (%$self{PENDING}), "]\n";
         my $method = 'cmd_' . $method;
         my $text = $self->?$method (@$tag[0], @$tag[2]);
         if (defined $text) {
-            if (@{ %$self{PENDING} } +> 1) {
-                %$self{PENDING}[-1][2] .= $text;
+            if ((nelems @{ %$self{PENDING} }) +> 1) {
+                %$self{PENDING}->[-1]->[2] .= $text;
             } else {
                 $self->output ($text);
             }
@@ -311,12 +311,12 @@ sub _handle_element_end {
 # instructions but possibly with more things turned off depending on the
 # element.
 sub formatting {
-    my ($self, $current, $element) = @_;
+    my ($self, $current, $element) = < @_;
     my %options;
     if ($current) {
-        %options = %$current;
+        %options = %( < %$current );
     } else {
-        %options = (guesswork => 1, cleanup => 1, convert => 1);
+        %options = %(guesswork => 1, cleanup => 1, convert => 1);
     }
     if ($element eq 'Data') {
         %options{guesswork} = 0;
@@ -336,7 +336,7 @@ sub formatting {
 # format.  Currently, the only formatting options are guesswork, cleanup, and
 # convert, all of which are boolean.
 sub format_text {
-    my ($self, $options, $text) = @_;
+    my ($self, $options, $text) = < @_;
     my $guesswork = %$options{guesswork} && !%$self{IN_NAME};
     my $cleanup = %$options{cleanup};
     my $convert = %$options{convert};
@@ -557,18 +557,18 @@ sub guesswork {
 # outside font is always the "previous" font and end with \fP instead of \fR.
 # Idea from Zack Weinberg.
 sub mapfonts {
-    my ($self, $text) = @_;
+    my ($self, $text) = < @_;
     my ($fixed, $bold, $italic) = (0, 0, 0);
-    my %magic = (F => \$fixed, B => \$bold, I => \$italic);
+    my %magic = %(F => \$fixed, B => \$bold, I => \$italic);
     my $last = '\fR';
-    $text =~ s<
+    $text =~ s#
         \\f\((.)(.)
-    > <{
+    #{
         my $sequence = '';
         my $f;
         if ($last ne '\fR') { $sequence = '\fP' }
         ${ %magic{$1} } += ($2 eq 'S') ? 1 : -1;
-        $f = %$self{FONTS}{ ($fixed && 1) . ($bold && 1) . ($italic && 1) };
+        $f = %$self{FONTS}->{ ($fixed && 1) . ($bold && 1) . ($italic && 1) };
         if ($f eq $last) {
             '';
         } else {
@@ -576,7 +576,7 @@ sub mapfonts {
             $last = $f;
             $sequence;
         }
-    }>gx;
+    }#gx;
     return $text;
 }
 
@@ -586,15 +586,15 @@ sub mapfonts {
 # around this, use a separate textmapfonts for text blocks where the default
 # font is always R and only use the smart mapfonts for headings.
 sub textmapfonts {
-    my ($self, $text) = @_;
+    my ($self, $text) = < @_;
     my ($fixed, $bold, $italic) = (0, 0, 0);
-    my %magic = (F => \$fixed, B => \$bold, I => \$italic);
-    $text =~ s<
+    my %magic = %(F => \$fixed, B => \$bold, I => \$italic);
+    $text =~ s#
         \\f\((.)(.)
-    > <{
+    #{
         ${ %magic{$1} } += ($2 eq 'S') ? 1 : -1;
-        %$self{FONTS}{ ($fixed && 1) . ($bold && 1) . ($italic && 1) };
-    }>gx;
+        %$self{FONTS}->{ ($fixed && 1) . ($bold && 1) . ($italic && 1) };
+    }#gx;
     return $text;
 }
 
@@ -606,7 +606,7 @@ sub textmapfonts {
 # embedded double quotes doubled.  For other formatters, remap paired double
 # quotes to LQUOTE and RQUOTE.
 sub switchquotes {
-    my ($self, $command, $text, $extra) = @_;
+    my ($self, $command, $text, $extra) = < @_;
     $text =~ s/\\\*\([LR]\"/\"/g;
 
     # We also have to deal with \*C` and \*C', which are used to add the
@@ -635,10 +635,10 @@ sub switchquotes {
         # to Roman rather than the actual previous font when used in headings.
         # troff output may still be broken, but at least we can fix nroff by
         # just switching the font changes to the non-fixed versions.
-        $nroff =~ s/\Q%$self{FONTS}{100}\E(.*)\\f[PR]/$1/g;
-        $nroff =~ s/\Q%$self{FONTS}{101}\E(.*)\\f([PR])/\\fI$1\\f$2/g;
-        $nroff =~ s/\Q%$self{FONTS}{110}\E(.*)\\f([PR])/\\fB$1\\f$2/g;
-        $nroff =~ s/\Q%$self{FONTS}{111}\E(.*)\\f([PR])/\\f\(BI$1\\f$2/g;
+        $nroff =~ s/\Q%$self{FONTS}->{100}\E(.*)\\f[PR]/$1/g;
+        $nroff =~ s/\Q%$self{FONTS}->{101}\E(.*)\\f([PR])/\\fI$1\\f$2/g;
+        $nroff =~ s/\Q%$self{FONTS}->{110}\E(.*)\\f([PR])/\\fB$1\\f$2/g;
+        $nroff =~ s/\Q%$self{FONTS}->{111}\E(.*)\\f([PR])/\\f\(BI$1\\f$2/g;
 
         # Now finally output the command.  Bother with .ie only if the nroff
         # and troff output aren't the same.
@@ -658,7 +658,7 @@ sub switchquotes {
 # something that *roff would interpret as a command.  This is overkill, but
 # it's much simpler than trying to parse *roff here.
 sub protect {
-    my ($self, $text) = @_;
+    my ($self, $text) = < @_;
     $text =~ s/^([.\'\\])/\\&$1/mg;
     return $text;
 }
@@ -670,7 +670,7 @@ sub protect {
 # repeated =items, since calling makespace means we're about to begin the item
 # body.
 sub makespace {
-    my ($self) = @_;
+    my ($self) = < @_;
     $self->output (".PD\n") if %$self{ITEMS} +> 1;
     %$self{ITEMS} = 0;
     $self->output (%$self{INDENT} +> 0 ? ".Sp\n" : ".PP\n")
@@ -681,9 +681,9 @@ sub makespace {
 # argument.  Support multiple index entries in X<> separated by slashes, and
 # strip special escapes from index entries.
 sub outindex {
-    my ($self, $section, $index) = @_;
-    my @entries = map { split m%\s*/\s*% } @{ %$self{INDEX} };
-    return unless ($section || @entries);
+    my ($self, $section, $index) = < @_;
+    my @entries = @( map { split m%\s*/\s*% } < @{ %$self{INDEX} } );
+    return unless ($section || nelems @entries);
 
     # We're about to output all pending entries, so clear our pending queue.
     %$self{INDEX} = \@();
@@ -691,8 +691,8 @@ sub outindex {
     # Build the output.  Regular index entries are marked Xref, and headings
     # pass in their own section.  Undo some *roff formatting on headings.
     my @output;
-    if (@entries) {
-        push @output, \@( 'Xref', join (' ', @entries) );
+    if ((nelems @entries)) {
+        push @output, \@( 'Xref', join (' ', < @entries) );
     }
     if ($section) {
         $index =~ s/\\-/-/g;
@@ -701,8 +701,8 @@ sub outindex {
     }
 
     # Print out the .IX commands.
-    for (@output) {
-        my ($type, $entry) = @$_;
+    for (< @output) {
+        my ($type, $entry) = < @$_;
         $entry =~ s/\"/\"\"/g;
         $self->output (".IX $type " . '"' . $entry . '"' . "\n");
     }
@@ -710,8 +710,8 @@ sub outindex {
 
 # Output some text, without any additional changes.
 sub output {
-    my ($self, @text) = @_;
-    print { %$self{output_fh} } @text;
+    my ($self, < @text) = < @_;
+    print { %$self{output_fh} } < @text;
 }
 
 ##############################################################################
@@ -721,7 +721,7 @@ sub output {
 # Handle the start of the document.  Here we handle empty documents, as well
 # as setting up our basic macros in a preamble and building the page title.
 sub start_document {
-    my ($self, $attrs) = @_;
+    my ($self, $attrs) = < @_;
     if (%$attrs{contentless} && !%$self{ALWAYS_EMIT_SOMETHING}) {
         DEBUG and print "Document is contentless\n";
         %$self{CONTENTLESS} = 1;
@@ -734,7 +734,7 @@ sub start_document {
         $name = %$self{name};
         $section = %$self{section} || 1;
     } else {
-        ($name, $section) = $self->devise_title;
+        ($name, $section) = < $self->devise_title;
     }
     my $date = %$self{date} || $self->devise_date;
     $self->preamble ($name, $section, $date)
@@ -755,7 +755,7 @@ sub start_document {
 # Handle the end of the document.  This does nothing but print out a final
 # comment at the end of the document under debugging.
 sub end_document {
-    my ($self) = @_;
+    my ($self) = < @_;
     return if $self->bare_output;
     return if (%$self{CONTENTLESS} && !%$self{ALWAYS_EMIT_SOMETHING});
     $self->output (q(.\" [End document]) . "\n") if DEBUG;
@@ -765,7 +765,7 @@ sub end_document {
 # a list, returning an empty name and section 1 if we can't find any better
 # information.  Uses File::Basename and File::Spec as necessary.
 sub devise_title {
-    my ($self) = @_;
+    my ($self) = < @_;
     my $name = $self->source_filename || '';
     my $section = %$self{section} || 1;
     $section = 3 if (!%$self{section} && $name =~ m/\.pm\z/i);
@@ -791,11 +791,11 @@ sub devise_title {
         $name = uc File::Basename::basename ($name);
     } else {
         require File::Spec;
-        my ($volume, $dirs, $file) = File::Spec->splitpath ($name);
-        my @dirs = File::Spec->splitdir ($dirs);
+        my ($volume, $dirs, $file) = < File::Spec->splitpath ($name);
+        my @dirs = @( < File::Spec->splitdir ($dirs) );
         my $cut = 0;
         my $i;
-        for ($i = 0; $i +< @dirs; $i++) {
+        for ($i = 0; $i +< nelems @dirs; $i++) {
             if (@dirs[$i] =~ m/perl/) {
                 $cut = $i + 1;
                 $cut++ if (@dirs[$i + 1] && @dirs[$i + 1] eq 'lib');
@@ -813,9 +813,9 @@ sub devise_title {
 
         # Remove empty directories when building the module name; they
         # occur too easily on Unix by doubling slashes.
-        $name = join ('::', (grep { $_ ? $_ : () } @dirs), $file);
+        $name = join ('::', (grep { $_ ? $_ : () } < @dirs), $file);
     }
-    return ($name, $section);
+    return  @($name, $section);
 }
 
 # Determine the modification date and return that, properly formatted in ISO
@@ -824,7 +824,7 @@ sub devise_title {
 # handle as the source_filename for input from a file handle, so we have to
 # deal with that as well.
 sub devise_date {
-    my ($self) = @_;
+    my ($self) = < @_;
     my $input = $self->source_filename;
     my $time;
     if ($input) {
@@ -844,7 +844,7 @@ sub devise_date {
 # The order of date and release used to be reversed in older versions of this
 # module, but this order is correct for both Solaris and Linux.
 sub preamble {
-    my ($self, $name, $section, $date) = @_;
+    my ($self, $name, $section, $date) = < @_;
     my $preamble = $self->preamble_template;
 
     # Build the index line and make sure that it will be syntactically valid.
@@ -899,7 +899,7 @@ $preamble
 # the first paragraph of text after an =over, in which case we have to change
 # indentations for *roff.
 sub cmd_para {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     my $line = %$attrs{start_line};
 
     # Output the paragraph.  We also have to handle =over without =item.  If
@@ -923,7 +923,7 @@ sub cmd_para {
     $text =~ s/\s*$/\n/;
 
     # Output the paragraph.
-    $self->output ($self->protect ($self->textmapfonts ($text)));
+    $self->output ( $self->protect ( $self->textmapfonts ($text)));
     $self->outindex;
     %$self{NEEDSPACE} = 1;
     return '';
@@ -933,7 +933,7 @@ sub cmd_para {
 # to protect against commands and wrap in .Vb/.Ve (which we define in our
 # prelude).
 sub cmd_verbatim {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
 
     # Ignore an empty verbatim paragraph.
     return unless $text =~ m/\S/;
@@ -946,9 +946,9 @@ sub cmd_verbatim {
     # we'll pass to .Vb as its parameter.  This tells *roff to keep that many
     # lines together.  We don't want to tell *roff to keep huge blocks
     # together.
-    my @lines = split (m/\n/, $text);
+    my @lines = @( split (m/\n/, $text) );
     my $unbroken = 0;
-    for (@lines) {
+    for (< @lines) {
         last if m/^\s*$/;
         $unbroken++;
     }
@@ -967,7 +967,7 @@ sub cmd_verbatim {
 # Handle literal text (produced by =for and similar constructs).  Just output
 # it with the minimum of changes.
 sub cmd_data {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     $text =~ s/^\n+//;
     $text =~ s/\n{0,2}$/\n/;
     $self->output ($text);
@@ -982,7 +982,7 @@ sub cmd_data {
 # output.  It returns the cleaned up heading text (putting the heading all on
 # one line) and may do other things, like closing bad =item blocks.
 sub heading_common {
-    my ($self, $text, $line) = @_;
+    my ($self, $text, $line) = < @_;
     $text =~ s/\s+$//;
     $text =~ s/\s*\n\s*/ /g;
 
@@ -1004,11 +1004,11 @@ sub heading_common {
 # already uses small caps, so remove \s0 and \s-1.  Maintain IN_NAME as
 # appropriate.
 sub cmd_head1 {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     $text =~ s/\\s-?\d//g;
     $text = $self->heading_common ($text, %$attrs{start_line});
     my $isname = ($text eq 'NAME' || $text =~ m/\(NAME\)/);
-    $self->output ($self->switchquotes ('.SH', $self->mapfonts ($text)));
+    $self->output ( $self->switchquotes ('.SH', $self->mapfonts ($text)));
     $self->outindex ('Header', $text) unless $isname;
     %$self{NEEDSPACE} = 0;
     %$self{IN_NAME} = $isname;
@@ -1017,9 +1017,9 @@ sub cmd_head1 {
 
 # Second level heading.
 sub cmd_head2 {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     $text = $self->heading_common ($text, %$attrs{start_line});
-    $self->output ($self->switchquotes ('.Sh', $self->mapfonts ($text)));
+    $self->output ( $self->switchquotes ('.Sh', $self->mapfonts ($text)));
     $self->outindex ('Subsection', $text);
     %$self{NEEDSPACE} = 0;
     return '';
@@ -1028,7 +1028,7 @@ sub cmd_head2 {
 # Third level heading.  *roff doesn't have this concept, so just put the
 # heading in italics as a normal paragraph.
 sub cmd_head3 {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     $text = $self->heading_common ($text, %$attrs{start_line});
     $self->makespace;
     $self->output ($self->textmapfonts ('\f(IS' . $text . '\f(IE') . "\n");
@@ -1040,7 +1040,7 @@ sub cmd_head3 {
 # Fourth level heading.  *roff doesn't have this concept, so just put the
 # heading as a normal paragraph.
 sub cmd_head4 {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     $text = $self->heading_common ($text, %$attrs{start_line});
     $self->makespace;
     $self->output ($self->textmapfonts ($text) . "\n");
@@ -1062,7 +1062,7 @@ sub cmd_c { return @_[0]->quote_literal (@_[2]) }
 
 # Index entries are just added to the pending entries.
 sub cmd_x {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     push (@{ %$self{INDEX} }, $text);
     return '';
 }
@@ -1070,7 +1070,7 @@ sub cmd_x {
 # Links reduce to the text that we're given, wrapped in angle brackets if it's
 # a URL.
 sub cmd_l {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     return %$attrs{type} eq 'url' ? "<$text>" : $text;
 }
 
@@ -1082,7 +1082,7 @@ sub cmd_l {
 # first argument, and then the attr hash.  This is called by the handlers for
 # the four different types of lists (bullet, number, text, and block).
 sub over_common_start {
-    my ($self, $type, $attrs) = @_;
+    my ($self, $type, $attrs) = < @_;
     my $line = %$attrs{start_line};
     my $indent = %$attrs{indent};
     DEBUG +> 3 and print " Starting =over $type (line $line, indent ",
@@ -1097,7 +1097,7 @@ sub over_common_start {
     # pending indentation for the last level that we saw and haven't acted on
     # yet.  SHIFTS is the stack of indentations that we've actually emitted
     # code for.
-    if (@{ %$self{SHIFTS} } +< @{ %$self{INDENTS} }) {
+    if ((nelems @{ %$self{SHIFTS} }) +< nelems @{ %$self{INDENTS} }) {
         $self->output (".RS %$self{INDENT}\n");
         push (@{ %$self{SHIFTS} }, %$self{INDENT});
     }
@@ -1118,20 +1118,20 @@ sub over_common_start {
 # circumstance.  If we're still inside an indentation, we need to emit another
 # .RE and then a new .RS to unconfuse *roff.
 sub over_common_end {
-    my ($self) = @_;
+    my ($self) = < @_;
     DEBUG +> 3 and print " Ending =over\n";
     %$self{INDENT} = pop @{ %$self{INDENTS} };
     pop @{ %$self{ITEMTYPES} };
 
     # If we emitted code for that indentation, end it.
-    if (@{ %$self{SHIFTS} } +> @{ %$self{INDENTS} }) {
+    if ((nelems @{ %$self{SHIFTS} }) +> nelems @{ %$self{INDENTS} }) {
         $self->output (".RE\n");
         pop @{ %$self{SHIFTS} };
     }
 
     # If we're still in an indentation, *roff will have now lost track of the
     # right depth of that indentation, so fix that.
-    if (@{ %$self{INDENTS} } +> 0) {
+    if ((nelems @{ %$self{INDENTS} }) +> 0) {
         $self->output (".RE\n");
         $self->output (".RS %$self{INDENT}\n");
     }
@@ -1140,10 +1140,10 @@ sub over_common_end {
 }
 
 # Dispatch the start and end calls as appropriate.
-sub start_over_bullet { my $s = shift; $s->over_common_start ('bullet', @_) }
-sub start_over_number { my $s = shift; $s->over_common_start ('number', @_) }
-sub start_over_text   { my $s = shift; $s->over_common_start ('text',   @_) }
-sub start_over_block  { my $s = shift; $s->over_common_start ('block',  @_) }
+sub start_over_bullet { my $s = shift; $s->over_common_start ('bullet', < @_) }
+sub start_over_number { my $s = shift; $s->over_common_start ('number', < @_) }
+sub start_over_text   { my $s = shift; $s->over_common_start ('text',   < @_) }
+sub start_over_block  { my $s = shift; $s->over_common_start ('block',  < @_) }
 sub end_over_bullet { @_[0]->over_common_end }
 sub end_over_number { @_[0]->over_common_end }
 sub end_over_text   { @_[0]->over_common_end }
@@ -1156,7 +1156,7 @@ sub end_over_block  { @_[0]->over_common_end }
 # entries for things like bullets and numbers.  Newlines in an item title are
 # turned into spaces since *roff can't handle them embedded.
 sub item_common {
-    my ($self, $type, $attrs, $text) = @_;
+    my ($self, $type, $attrs, $text) = < @_;
     my $line = %$attrs{start_line};
     DEBUG +> 3 and print "  $type item (line $line): $text\n";
 
@@ -1183,7 +1183,7 @@ sub item_common {
     # directly following another one.  We only have to do that once for a
     # whole chain of items so do it for the second item in the change.  Note
     # that makespace is what undoes this.
-    if (@{ %$self{SHIFTS} } == @{ %$self{INDENTS} }) {
+    if ((nelems @{ %$self{SHIFTS} }) == nelems @{ %$self{INDENTS} }) {
         $self->output (".RE\n");
         pop @{ %$self{SHIFTS} };
     }
@@ -1191,7 +1191,7 @@ sub item_common {
 
     # Now, output the item tag itself.
     $item = $self->textmapfonts ($item);
-    $self->output ($self->switchquotes ('.IP', $item, %$self{INDENT}));
+    $self->output ( $self->switchquotes ('.IP', $item, %$self{INDENT}));
     %$self{NEEDSPACE} = 0;
     %$self{ITEMS}++;
     %$self{SHIFTWAIT} = 0;
@@ -1200,17 +1200,17 @@ sub item_common {
     if ($text) {
         $text =~ s/\s*$/\n/;
         $self->makespace;
-        $self->output ($self->protect ($self->textmapfonts ($text)));
+        $self->output ( $self->protect ( $self->textmapfonts ($text)));
         %$self{NEEDSPACE} = 1;
     }
     $self->outindex ($index ? ('Item', $index) : ());
 }
 
 # Dispatch the item commands to the appropriate place.
-sub cmd_item_bullet { my $self = shift; $self->item_common ('bullet', @_) }
-sub cmd_item_number { my $self = shift; $self->item_common ('number', @_) }
-sub cmd_item_text   { my $self = shift; $self->item_common ('text',   @_) }
-sub cmd_item_block  { my $self = shift; $self->item_common ('block',  @_) }
+sub cmd_item_bullet { my $self = shift; $self->item_common ('bullet', < @_) }
+sub cmd_item_number { my $self = shift; $self->item_common ('number', < @_) }
+sub cmd_item_text   { my $self = shift; $self->item_common ('text',   < @_) }
+sub cmd_item_block  { my $self = shift; $self->item_common ('block',  < @_) }
 
 ##############################################################################
 # Backward compatibility
@@ -1233,7 +1233,7 @@ sub parse_from_file {
     }
 
     # Do the work.
-    my $retval = $self->SUPER::parse_from_file (@_);
+    my $retval = $self->SUPER::parse_from_file (< @_);
 
     # Flush output, since Pod::Simple doesn't do this.  Ideally we should also
     # close the file descriptor if we had to open one, but we can't easily
@@ -1253,7 +1253,7 @@ sub parse_from_file {
 # parse_from_file supports.
 sub parse_from_filehandle {
     my $self = shift;
-    $self->parse_from_file (@_);
+    $self->parse_from_file (< @_);
 }
 
 ##############################################################################
