@@ -27,8 +27,8 @@ use strict;
 use vars qw(@EXPORT @ISA $VERSION);
 
 use Exporter;
-@ISA    = qw(Exporter);
-@EXPORT = qw(parselink);
+@ISA    = @( qw(Exporter) );
+@EXPORT = @( qw(parselink) );
 
 # Don't use the CVS revision as the version, since this module is also in Perl
 # core and too many things could munge CVS magic revision strings.  This
@@ -42,13 +42,13 @@ $VERSION = 1.06;
 
 # Parse the name and section portion of a link into a name and section.
 sub _parse_section {
-    my ($link) = @_;
+    my ($link) = < @_;
     $link =~ s/^\s+//;
     $link =~ s/\s+$//;
 
     # If the whole link is enclosed in quotes, interpret it all as a section
     # even if it contains a slash.
-    return (undef, $1) if ($link =~ m/^"\s*(.*?)\s*"$/);
+    return  @(undef, $1) if ($link =~ m/^"\s*(.*?)\s*"$/);
 
     # Split into page and section on slash, and then clean up quoting in the
     # section.  If there is no section and the name contains spaces, also
@@ -62,12 +62,12 @@ sub _parse_section {
         $page = undef unless $page;
         $section = undef unless $section;
     }
-    return ($page, $section);
+    return  @($page, $section);
 }
 
 # Infer link text from the page and section.
 sub _infer_text {
-    my ($page, $section) = @_;
+    my ($page, $section) = < @_;
     my $inferred;
     if ($page && !$section) {
         $inferred = $page;
@@ -83,19 +83,19 @@ sub _infer_text {
 # the possibly inferred link text, the name or URL, the section, and the type
 # of link (pod, man, or url).
 sub parselink {
-    my ($link) = @_;
+    my ($link) = < @_;
     $link =~ s/\s+/ /g;
     if ($link =~ m/\A\w+:[^:\s]\S*\Z/) {
-        return (undef, $link, $link, undef, 'url');
+        return  @(undef, $link, $link, undef, 'url');
     } else {
         my $text;
         if ($link =~ m/\|/) {
             ($text, $link) = split (m/\|/, $link, 2);
         }
-        my ($name, $section) = _parse_section ($link);
+        my ($name, $section) = < _parse_section ($link);
         my $inferred = $text || _infer_text ($name, $section);
         my $type = ($name && $name =~ m/\(\S*\)/) ? 'man' : 'pod';
-        return ($text, $inferred, $name, $section, $type);
+        return  @($text, $inferred, $name, $section, $type);
     }
 }
 
