@@ -9,9 +9,9 @@ use vars qw(@ISA);
 eval 'require Pod::Simple::Checker';
 if($@) {
   require Pod::Checker;
-  @ISA = ('Pod::Checker');
+  @ISA = @('Pod::Checker');
 } else {
-  @ISA = ('Pod::Simple::Checker');
+  @ISA = @('Pod::Simple::Checker');
 }
 
 sub is_pageable        { 1 }
@@ -19,7 +19,7 @@ sub write_with_binmode { 0 }
 sub output_extension   { 'txt' }
 
 sub if_zero_length {
-  my( $self, $file, $tmp, $tmpfd ) = @_;
+  my( $self, $file, $tmp, $tmpfd ) = < @_;
   print "No Pod errors in $file\n";
 }
 
