@@ -5,9 +5,9 @@ use strict;
 sub import {
   my($value,$variable);
   
-  if(@_ == 2) {
+  if((nelems @_) == 2) {
     $value = @_[1];
-  } elsif(@_ == 3) {
+  } elsif((nelems @_) == 3) {
     ($variable, $value) = @_[[1,2]];
     
     ($variable, $value) = ($value, $variable)
