@@ -1,8 +1,8 @@
 
 package Pod::Simple::DumpAsXML;
-$VERSION = '2.02';
+our $VERSION = '2.02';
 use Pod::Simple ();
-BEGIN {@ISA = ('Pod::Simple')}
+BEGIN {our @ISA = @('Pod::Simple')}
 
 use strict;
 use utf8;
@@ -13,7 +13,7 @@ BEGIN { *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG }
 
 sub new {
   my $self = shift;
-  my $new = $self->SUPER::new(@_);
+  my $new = $self->SUPER::new(< @_);
   $new->{'output_fh'} ||= *STDOUT{IO};
   $new->accept_codes('VerbatimFormatted');
   return $new;
@@ -23,30 +23,30 @@ sub new {
 
 sub _handle_element_start {
   # ($self, $element_name, $attr_hash_r)
-  my $fh = @_[0]{'output_fh'};
+  my $fh = @_[0]->{'output_fh'};
   my($key, $value);
   DEBUG and print "++ @_[1]\n";
   
-  print $fh   '  ' x (@_[0]{'indent'} || 0),  "<", @_[1];
+  print $fh   '  ' x (@_[0]->{'indent'} || 0),  "<", @_[1];
 
   foreach my $key (sort keys %{@_[2]}) {
     unless($key =~ m/^~/s) {
-      next if $key eq 'start_line' and @_[0]{'hide_line_numbers'};
-      _xml_escape($value = @_[2]{$key});
+      next if $key eq 'start_line' and @_[0]->{'hide_line_numbers'};
+      _xml_escape($value = @_[2]->{$key});
       print $fh ' ', $key, '="', $value, '"';
     }
   }
 
 
   print $fh ">\n";
-  @_[0]{'indent'}++;
+  @_[0]->{'indent'}++;
   return;
 }
 
 sub _handle_text {
   DEBUG and print "== \"@_[1]\"\n";
   if(length @_[1]) {
-    my $indent = '  ' x @_[0]{'indent'};
+    my $indent = '  ' x @_[0]->{'indent'};
     my $text = @_[1];
     _xml_escape($text);
     $text =~  # A not-totally-brilliant wrapping algorithm:
@@ -58,22 +58,22 @@ sub _handle_text {
        /$1\n$indent/gx     # => line-break here
     ;
     
-    print {@_[0]{'output_fh'}} $indent, $text, "\n";
+    print {@_[0]->{'output_fh'}} $indent, $text, "\n";
   }
   return;
 }
 
 sub _handle_element_end {
   DEBUG and print "-- @_[1]\n";
-  print {@_[0]{'output_fh'}}
-   '  ' x --@_[0]{'indent'}, "</", @_[1], ">\n";
+  print {@_[0]->{'output_fh'}}
+   '  ' x --@_[0]->{'indent'}, "</", @_[1], ">\n";
   return;
 }
 
 # . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .
 
 sub _xml_escape {
-  foreach my $x (@_) {
+  foreach my $x (< @_) {
     # Escape things very cautiously:
     $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/{'&#'.(ord($1)).';'
 }/g;
