@@ -8,7 +8,7 @@ use vars qw(
   $Title_Prefix $Title_Postfix $HTML_EXTENSION %ToIndex
   $Doctype_decl  $Content_decl
 );
-@ISA = ('Pod::Simple::PullParser');
+@ISA = @('Pod::Simple::PullParser');
 $VERSION = '3.03';
 
 use UNIVERSAL ();
@@ -38,7 +38,7 @@ $Perldoc_URL_Postfix = ''
 
 $Title_Prefix  = '' unless defined $Title_Prefix;
 $Title_Postfix = '' unless defined $Title_Postfix;
-%ToIndex = map {; $_ => 1 } qw(head1 head2 head3 head4 ); # item-text
+%ToIndex = %( map {; $_ => 1 } qw(head1 head2 head3 head4 ) ); # item-text
   # 'item-text' stuff in the index doesn't quite work, and may
   # not be a good idea anyhow.
 
@@ -78,7 +78,7 @@ __PACKAGE__->_accessorize(
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 my @_to_accept;
 
-%Tagmap = (
+%Tagmap = %(
   'Verbatim'  => "\n<pre$Computerese>",
   '/Verbatim' => "</pre>\n",
   'VerbatimFormatted'  => "\n<pre$Computerese>",
@@ -104,7 +104,7 @@ my @_to_accept;
   '/head4' => "</a></h4>\n",
 
   'X'  => "<!--\n\tINDEX: ",
-  '/X' => "\n-->",
+  '/X' => "\n-->", <
 
   changes(qw(
     Para=p
@@ -116,7 +116,7 @@ my @_to_accept;
     item-bullet=li
     item-number=li
     item-text=dt
-  )),
+  )), <
   changes2(
     map {; m/^([-a-z]+)/s && push @_to_accept, $1; $_ }
     qw[
@@ -152,30 +152,30 @@ my @_to_accept;
 );
 
 sub changes {
-  return map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
+  return @( map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
      ? ( $1, => "\n<$2>", "/$1", => "</$2>\n" ) : die "Funky $_"
-  } @_;
+  } < @_ );
 }
 sub changes2 {
-  return map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
+  return @( map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
      ? ( $1, => "<$2>", "/$1", => "</$2>" ) : die "Funky $_"
-  } @_;
+  } < @_ );
 }
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-sub go { exit Pod::Simple::HTML->parse_from_file(@ARGV) }
+sub go { exit Pod::Simple::HTML->parse_from_file(< @ARGV) }
  # Just so we can run from the command line.  No options.
  #  For that, use perldoc!
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 sub new {
-  my $new = shift->SUPER::new(@_);
+  my $new = shift->SUPER::new(< @_);
   #$new->nix_X_codes(1);
   $new->nbsp_for_S(1);
   $new->accept_targets( 'html', 'HTML' );
   $new->accept_codes('VerbatimFormatted');
-  $new->accept_codes(@_to_accept);
-  DEBUG +> 2 and print "To accept: ", join(' ',@_to_accept), "\n";
+  $new->accept_codes(< @_to_accept);
+  DEBUG +> 2 and print "To accept: ", join(' ',< @_to_accept), "\n";
 
   $new->perldoc_url_prefix(  $Perldoc_URL_Prefix  );
   $new->perldoc_url_postfix( $Perldoc_URL_Postfix );
@@ -194,12 +194,12 @@ sub new {
   );
   $new->html_footer( qq[\n<!-- end doc -->\n\n</body></html>\n] );
 
-  $new->{'Tagmap'} = \%(%Tagmap);
+  $new->{'Tagmap'} = \%(< %Tagmap);
   return $new;
 }
 
 sub batch_mode_page_object_init {
-  my($self, $batchconvobj, $module, $infile, $outfile, $depth) = @_;
+  my($self, $batchconvobj, $module, $infile, $outfile, $depth) = < @_;
   DEBUG and print "Initting $self\n  for $module\n",
     "  in $infile\n  out $outfile\n  depth $depth\n";
   $self->batch_mode(1);
@@ -249,7 +249,7 @@ sub do_beginning {
     $self->html_css =~ m/</
      ? $self->html_css # It's a big blob of markup, let's drop it in
      : sprintf(        # It's just a URL, so let's wrap it up
-      qq[<link rel="stylesheet" type="text/css" title="pod_stylesheet" href="\%s">\n],
+      qq[<link rel="stylesheet" type="text/css" title="pod_stylesheet" href="\%s">\n], <
       $self->html_css,
     );
     $after =~ s{(</head>)}{$link\n$1}i;  # otherwise nevermind
@@ -261,7 +261,7 @@ sub do_beginning {
     $self->html_javascript =~ m/</
      ? $self->html_javascript # It's a big blob of markup, let's drop it in
      : sprintf(        # It's just a URL, so let's wrap it up
-      qq[<script type="text/javascript" src="\%s"></script>\n],
+      qq[<script type="text/javascript" src="\%s"></script>\n], <
       $self->html_javascript,
     );
     $after =~ s{(</head>)}{$link\n$1}i;  # otherwise nevermind
@@ -278,7 +278,7 @@ sub do_beginning {
 }
 
 sub _add_top_anchor {
-  my($self, $text_r) = @_;
+  my($self, $text_r) = < @_;
   unless($$text_r and $$text_r =~ m/name=['"]___top['"]/) { # a hack
     $$text_r .= "<a name='___top' class='dummyTopAnchor' ></a>\n";
   }
@@ -289,7 +289,7 @@ sub version_tag_comment {
   my $self = shift;
   return sprintf
    "<!--\n  generated by \%s v\%s,\n  using \%s v\%s,\n  under Perl v\%s at \%s GMT.\n\n \%s\n\n-->\n",
-   esc(
+   (map { esc($_) }
     ref($self), $self->VERSION(), @ISA[0], @ISA[0]->VERSION(),
     $^V, scalar(gmtime),
    ), $self->_modnote(),
@@ -374,15 +374,15 @@ sub index_as_html {
 
   my $points = $self->{'PSHTML_index_points'} || \@();
   
-  @$points +> 1 or return qq[<div class='indexgroupEmpty'></div>\n];
+  (nelems @$points) +> 1 or return qq[<div class='indexgroupEmpty'></div>\n];
    # There's no point in having a 0-item or 1-item index, I dare say.
   
-  my(@out) = qq{\n<div class='indexgroup'>};
+  my(@out) = @( qq{\n<div class='indexgroup'>} );
   my $level = 0;
 
   my( $target_level, $previous_tagname, $tagname, $text, $anchorname, $indent);
-  foreach my $p (@$points, \@('head0', '(end)')) {
-    ($tagname, $text) = @$p;
+  foreach my $p (< @$points, \@('head0', '(end)')) {
+    ($tagname, $text) = < @$p;
     $anchorname = $self->section_escape($text);
     if( $tagname =~ m{^head(\d+)$} ) {
       $target_level = 0 + $1;
@@ -411,7 +411,7 @@ sub index_as_html {
     ;
   }
   push @out, "</div>\n";
-  return join "\n", @out;
+  return join "\n", < @out;
 }
 
 ###########################################################################
@@ -435,7 +435,7 @@ sub _do_middle_main_loop {
         $linkto = $self->do_link($token);
 
         if(defined $linkto and length $linkto) {
-          esc($linkto);
+          $linkto = esc($linkto);
             #   (Yes, SGML-escaping applies on top of %-escaping!
             #   But it's rarely noticeable in practice.)
           print $fh qq{<a href="$linkto" class="podlink$linktype"\n>};
@@ -455,16 +455,16 @@ sub _do_middle_main_loop {
           # TODO: support for X<...>'s found in here?  (maybe hack into linearize_tokens)
         }
 
-        my $name = $self->linearize_tokens(@to_unget);
+        my $name = $self->linearize_tokens(< @to_unget);
         
         print $fh "<a ";
         print $fh "class='u' href='#___top' title='click to go to top of document'\n"
          if $tagname =~ m/^head\d$/s;
         
         if(defined $name) {
-          my $esc = esc(  $self->section_name_tidy( $name ) );
+          my $esc = esc( $self->section_name_tidy( $name ) );
           print $fh qq[name="$esc"];
-          DEBUG and print "Linearized ", scalar(@to_unget),
+          DEBUG and print "Linearized ", scalar(nelems @to_unget),
            " tokens as \"$name\".\n";
           push @{ $self->{'PSHTML_index_points'} }, \@($tagname, $name)
            if %ToIndex{ $tagname };
@@ -472,11 +472,11 @@ sub _do_middle_main_loop {
             #  just their content), but ahwell.
            
         } else {  # ludicrously long, so nevermind
-          DEBUG and print "Linearized ", scalar(@to_unget),
+          DEBUG and print "Linearized ", scalar(nelems @to_unget),
            " tokens, but it was too long, so nevermind.\n";
         }
         print $fh "\n>";
-        $self->unget_token(@to_unget);
+        $self->unget_token(< @to_unget);
 
       } elsif ($tagname eq 'Data') {
         my $next = $self->get_token;
@@ -485,14 +485,14 @@ sub _do_middle_main_loop {
           $self->unget_token($next);
           next;
         }
-        DEBUG and print "    raw text ", $next->text, "\n";
+        DEBUG and print "    raw text ", < $next->text, "\n";
         printf $fh "\n" . $next->text . "\n";
         next;
        
       } else {
         if( $tagname =~ m/^over-/s ) {
           push @stack, '';
-        } elsif( $tagname =~ m/^item-/s and @stack and @stack[-1] ) {
+        } elsif( $tagname =~ m/^item-/s and nelems @stack and @stack[-1] ) {
           print $fh @stack[-1];
           @stack[-1] = '';
         }
@@ -507,7 +507,7 @@ sub _do_middle_main_loop {
         if( my $end = pop @stack ) {
           print $fh $end;
         }
-      } elsif( $tagname =~ m/^item-/s and @stack) {
+      } elsif( $tagname =~ m/^item-/s and nelems @stack) {
         @stack[-1] = $tagmap->{"/$tagname"};
         if( $tagname eq 'item-text' and defined(my $next = $self->get_token) ) {
           $self->unget_token($next);
@@ -523,7 +523,7 @@ sub _do_middle_main_loop {
 
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     } elsif( $type eq 'text' ) {
-      esc($type = $token->text);  # reuse $type, why not
+      $type = esc($token->text);  # reuse $type, why not
       $type =~ s/([\?\!\"\'\.\,]) /$1\n/g unless $dont_wrap;
       print $fh $type;
     }
@@ -536,15 +536,15 @@ sub _do_middle_main_loop {
 #
 
 sub do_link {
-  my($self, $token) = @_;
+  my($self, $token) = < @_;
   my $type = $token->attr('type');
   if(!defined $type) {
-    $self->whine("Typeless L!?", $token->attr('start_line'));
+    $self->whine("Typeless L!?", < $token->attr('start_line'));
   } elsif( $type eq 'pod') { return $self->do_pod_link($token);
   } elsif( $type eq 'url') { return $self->do_url_link($token);
   } elsif( $type eq 'man') { return $self->do_man_link($token);
   } else {
-    $self->whine("L of unknown type $type!?", $token->attr('start_line'));
+    $self->whine("L of unknown type $type!?", < $token->attr('start_line'));
   }
   return 'FNORG'; # should never get called
 }
@@ -560,7 +560,7 @@ sub do_man_link { return undef }
 
 sub do_pod_link {
   # And now things get really messy...
-  my($self, $link) = @_;
+  my($self, $link) = < @_;
   my $to = $link->attr('to');
   my $section = $link->attr('section');
   return undef unless(  # should never happen
@@ -628,26 +628,26 @@ sub do_pod_link {
 # . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .
 
 sub section_escape {
-  my($self, $section) = @_;
+  my($self, $section) = < @_;
   return $self->section_url_escape(
     $self->section_name_tidy($section)
   );
 }
 
 sub section_name_tidy {
-  my($self, $section) = @_;
-  $section =~ tr/ /_/;
-  $section =~ tr/\x[00]-\x[1F]\x[80]-\x[9F]//d; # drop crazy characters
+  my($self, $section) = < @_;
+  $section =~ s/ /_/g;
+  $section =~ s/\x[00]-\x[1F]\x[80]-\x[9F]//g; # drop crazy characters
   $section = $self->unicode_escape_url($section);
   $section = '_' unless length $section;
   return $section;
 }
 
-sub section_url_escape  { shift->general_url_escape(@_) }
-sub pagepath_url_escape { shift->general_url_escape(@_) }
+sub section_url_escape  { shift->general_url_escape(< @_) }
+sub pagepath_url_escape { shift->general_url_escape(< @_) }
 
 sub general_url_escape {
-  my($self, $string) = @_;
+  my($self, $string) = < @_;
  
   $string =~ s/([^\x[00]-\x[FF]])/{join '', map sprintf('%%%02X',$_), unpack 'C*', $1}/g;
      # express Unicode things as urlencode(utf(orig)).
@@ -674,13 +674,13 @@ sub resolve_pod_page_link {
   # resolve_pod_page_link must return a properly escaped URL
   my $self = shift;
   return $self->batch_mode()
-   ? $self->resolve_pod_page_link_batch_mode(@_)
-   : $self->resolve_pod_page_link_singleton_mode(@_)
+   ? $self->resolve_pod_page_link_batch_mode(< @_)
+   : $self->resolve_pod_page_link_singleton_mode(< @_)
   ;
 }
 
 sub resolve_pod_page_link_singleton_mode {
-  my($self, $it) = @_;
+  my($self, $it) = < @_;
   return undef unless defined $it and length $it;
   my $url = $self->pagepath_url_escape($it);
   
@@ -692,22 +692,22 @@ sub resolve_pod_page_link_singleton_mode {
 }
 
 sub resolve_pod_page_link_batch_mode {
-  my($self, $to) = @_;
+  my($self, $to) = < @_;
   DEBUG +> 1 and print " During batch mode, resolving $to ...\n";
-  my @path = grep length($_), split m/::/s, $to, -1;
-  unless( @path ) { # sanity
+  my @path = @( grep length($_), split m/::/s, $to, -1 );
+  unless( nelems @path ) { # sanity
     DEBUG and print "Very odd!  Splitting $to gives (nil)!\n";
     return undef;
   }
   $self->batch_mode_rectify_path(\@path);
-  my $out = join('/', map $self->pagepath_url_escape($_), @path)
+  my $out = join('/', map < $self->pagepath_url_escape($_), < @path)
     . $HTML_EXTENSION;
   DEBUG +> 1 and print " => $out\n";
   return $out;
 }
 
 sub batch_mode_rectify_path {
-  my($self, $pathbits) = @_;
+  my($self, $pathbits) = < @_;
   my $level = $self->batch_mode_current_level;
   $level--; # how many levels up to go to get to the root
   if($level +< 1) {
@@ -725,15 +725,15 @@ sub resolve_pod_link_by_table {
 
   return unless @_[0]->{'podhtml_LOT'};  # An optimizy shortcut
 
-  my($self, $to, $section) = @_;
+  my($self, $to, $section) = < @_;
 
   # TODO: add a method that actually populates podhtml_LOT from a file?
 
   if(defined $section) {
     $to = '' unless defined $to and length $to;
-    return $self->{'podhtml_LOT'}{"$to#$section"}; # quite possibly undef!
+    return $self->{'podhtml_LOT'}->{"$to#$section"}; # quite possibly undef!
   } else {
-    return $self->{'podhtml_LOT'}{$to};            # quite possibly undef!
+    return $self->{'podhtml_LOT'}->{$to};            # quite possibly undef!
   }
   return;
 }
@@ -767,7 +767,7 @@ sub linearize_tokens {  # self, tokens
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 sub unicode_escape_url {
-  my($self, $string) = @_;
+  my($self, $string) = < @_;
   $string =~ s/([^\x[00]-\x[FF]])/{'('.ord($1).')'}/g;
     #  Turn char 1234 into "(1234)"
   return $string;
@@ -775,30 +775,17 @@ sub unicode_escape_url {
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 sub esc { # a function.
-  if(defined wantarray) {
-    if(wantarray) {
-      @_ = splice @_; # break aliasing
-    } else {
-      my $x = shift;
-      $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/{'&#'.(ord($1)).';'
+  my $x = shift;
+  $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/{'&#'.(ord($1)).';'
 }/g;
-      return $x;
-    }
-  }
-  foreach my $x (@_) {
-    # Escape things very cautiously:
-    $x =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/{'&#'.(ord($1)).';'
-}/g
-     if defined $x;
-    # Leave out "- so that "--" won't make it thru in X-generated comments
-    #  with text in them.
+  return $x;
+  # Leave out "- so that "--" won't make it thru in X-generated comments
+  #  with text in them.
 
-    # Yes, stipulate the list without a range, so that this can work right on
-    #  all charsets that this module happens to run under.
-    # Altho, hmm, what about that ord?  Presumably that won't work right
-    #  under non-ASCII charsets.  Something should be done about that.
-  }
-  return @_;
+  # Yes, stipulate the list without a range, so that this can work right on
+  #  all charsets that this module happens to run under.
+  # Altho, hmm, what about that ord?  Presumably that won't work right
+  #  under non-ASCII charsets.  Something should be done about that.
 }
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
