@@ -5,7 +5,7 @@ use vars qw( $VERSION $HTML_RENDER_CLASS $HTML_EXTENSION
  $CSS $JAVASCRIPT $SLEEPY $SEARCH_CLASS @ISA
 );
 $VERSION = '3.02';
-@ISA = ();  # Yup, we're NOT a subclass of Pod::Simple::HTML!
+@ISA = @( () );  # Yup, we're NOT a subclass of Pod::Simple::HTML!
 
 # TODO: nocontents stylesheets. Strike some of the color variations?
 
@@ -50,7 +50,7 @@ Pod::Simple::_accessorize( __PACKAGE__,
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Just so we can run from the command line more easily
 sub go {
-  @ARGV == 2 or die sprintf(
+  (nelems @ARGV) == 2 or die sprintf(
     "Usage: perl -M\%s -e \%s:go indirs outdir\n  (or use \"\@INC\" for indirs)\n",
     __PACKAGE__, __PACKAGE__, 
   );
@@ -62,7 +62,7 @@ sub go {
     -w $d or die "Directory \"$d\" isn't writeable!\nAborting";
   }
   
-  __PACKAGE__->batch_convert(@ARGV);
+  __PACKAGE__->batch_convert(< @ARGV);
 }
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -94,9 +94,9 @@ sub new {
   
   $new->contents_page_end( sprintf(
     "\n\n<p class='contentsfooty'>Generated by \%s v\%s under Perl v\%s\n<br >At \%s GMT, which is \%s local time.</p>\n\n</body></html>\n",
-    esc(
+    (map { esc($_) }
       ref($new),
-      eval {$new->VERSION} || $VERSION,
+      try {$new->VERSION} || $VERSION,
       $^V, scalar(gmtime), scalar(localtime), 
   )));
 
@@ -108,7 +108,7 @@ sub new {
 sub muse {
   my $self = shift;
   if($self->verbose) {
-    print 'T+', int(time() - $self->{'_batch_start_time'}), "s: ", @_, "\n";
+    print 'T+', int(time() - $self->{'_batch_start_time'}), "s: ", < @_, "\n";
   }
   return 1;
 }
@@ -116,7 +116,7 @@ sub muse {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub batch_convert {
-  my($self, $dirs, $outdir) = @_;
+  my($self, $dirs, $outdir) = < @_;
   $self ||= __PACKAGE__; # tolerate being called as an optionless function
   $self = $self->new unless ref $self; # tolerate being used as a class method
 
@@ -142,7 +142,7 @@ sub batch_convert {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _batch_convert_main {
-  my($self, $dirs, $outdir) = @_;
+  my($self, $dirs, $outdir) = < @_;
   # $dirs is either false, or an arrayref.    
   # $outdir is a pathspec.
   
@@ -163,14 +163,14 @@ sub _batch_convert_main {
   }
   
   if($dirs) {
-    $self->muse(scalar(@$dirs), " dirs to scan: @$dirs");
+    $self->muse(scalar(nelems @$dirs), " dirs to scan: {join ' ', <@$dirs}");
   } else {
     $self->muse("Scanning \@INC.  This could take a minute or two.");
   }
   my $mod2path = $self->find_all_pods($dirs ? $dirs : ());
   $self->muse("Done scanning.");
 
-  my $total = keys %$mod2path;
+  my $total = nkeys %$mod2path;
   unless($total) {
     $self->muse("No pod found.  Aborting batch conversion.\n");
     return $self;
@@ -195,7 +195,7 @@ sub _batch_convert_main {
 
 
 sub _do_all_batch_conversions {
-  my($self, $mod2path, $outdir) = @_;
+  my($self, $mod2path, $outdir) = < @_;
   $self->{"__batch_conv_page_count"} = 0;
 
   foreach my $module (sort {lc($a) cmp lc($b)} keys %$mod2path) {
@@ -207,7 +207,7 @@ sub _do_all_batch_conversions {
 }
 
 sub _batch_convert_finish {
-  my($self, $outdir) = @_;
+  my($self, $outdir) = < @_;
   $self->write_contents_file($outdir);
   $self->muse("Done with batch conversion.  %$self{'__batch_conv_page_count'} files done.");
   $self->muse( "= ", scalar(localtime) );
@@ -218,20 +218,20 @@ sub _batch_convert_finish {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _do_one_batch_conversion {
-  my($self, $module, $mod2path, $outdir, $outfile) = @_;
+  my($self, $module, $mod2path, $outdir, $outfile) = < @_;
 
   my $retval;
-  my $total    = scalar keys %$mod2path;
+  my $total    = nkeys %$mod2path;
   my $infile   = $mod2path->{$module};
-  my @namelets = grep m/\S/, split "::", $module;
+  my @namelets = @( grep m/\S/, split "::", $module );
         # this can stick around in the contents LoL
-  my $depth    = scalar @namelets;
-  die "Contentless thingie?! $module $infile" unless @namelets; #sanity
+  my $depth    = scalar nelems @namelets;
+  die "Contentless thingie?! $module $infile" unless (nelems @namelets); #sanity
     
   $outfile  ||= do {
-    my @n = @namelets;
+    my @n = @( < @namelets );
     @n[-1] .= $HTML_EXTENSION || $Pod::Simple::HTML::HTML_EXTENSION;
-    $self->filespecsys->catfile( $outdir, @n );
+    $self->filespecsys->catfile( $outdir, < @n );
   };
 
   my $progress = $self->progress;
@@ -278,12 +278,12 @@ sub _do_one_batch_conversion {
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-sub filespecsys { @_[0]{'_filespecsys'} || 'File::Spec' }
+sub filespecsys { @_[0]->{'_filespecsys'} || 'File::Spec' }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub note_for_contents_file {
-  my($self, $namelets, $infile, $outfile) = @_;
+  my($self, $namelets, $infile, $outfile) = < @_;
 
   # I think the infile and outfile parts are never used. -- SMB
   # But it's handy to have them around for debugging.
@@ -291,7 +291,7 @@ sub note_for_contents_file {
   if( $self->contents_file ) {
     my $c = $self->_contents();
     push @$c,
-     \@( join("::", @$namelets), $infile, $outfile, $namelets )
+     \@( join("::", < @$namelets), $infile, $outfile, $namelets )
      #            0               1         2         3
     ;
     DEBUG +> 3 and print "Noting @$c[[-1]]\n";
@@ -302,16 +302,16 @@ sub note_for_contents_file {
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
 sub write_contents_file {
-  my($self, $outdir) = @_;
+  my($self, $outdir) = < @_;
   my $outfile  = $self->_contents_filespec($outdir) || return;
 
   $self->muse("Preparing list of modules for ToC");
 
   my($toplevel,           # maps  toplevelbit => [all submodules]
      $toplevel_form_freq, # ends up being  'foo' => 'Foo'
-    ) = $self->_prep_contents_breakdown;
+    ) = < $self->_prep_contents_breakdown;
 
-  my $Contents = eval { $self->_wopen($outfile) };
+  my $Contents = try { $self->_wopen($outfile) };
   if( $Contents ) {
     $self->muse( "Writing contents file $outfile" );
   } else {
@@ -328,7 +328,7 @@ sub write_contents_file {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _write_contents_start {
-  my($self, $Contents, $outfile) = @_;
+  my($self, $Contents, $outfile) = < @_;
   my $starter = $self->contents_page_start || '';
   
   {
@@ -354,20 +354,20 @@ sub _write_contents_start {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _write_contents_middle {
-  my($self, $Contents, $outfile, $toplevel2submodules, $toplevel_form_freq) = @_;
+  my($self, $Contents, $outfile, $toplevel2submodules, $toplevel_form_freq) = < @_;
 
   foreach my $t (sort keys %$toplevel2submodules) {
-    my @downlines = sort {$a->[-1] cmp $b->[-1]}
-                          @{ $toplevel2submodules->{$t} };
+    my @downlines = @( sort {$a->[-1] cmp $b->[-1]}
+                          < @{ $toplevel2submodules->{$t} } );
     
     printf $Contents qq[<dt><a name="\%s">\%s</a></dt>\n<dd>\n],
-      esc( $t, $toplevel_form_freq->{$t} )
+      esc( $t ), esc( $toplevel_form_freq->{$t} )
     ;
     
     my($path, $name);
-    foreach my $e (@downlines) {
+    foreach my $e (< @downlines) {
       $name = $e->[0];
-      $path = join( "/", '.', esc( @{$e->[3]} ) )
+      $path = join( "/", '.', map { esc($_) } < @{$e->[3]} )
         . ($HTML_EXTENSION || $Pod::Simple::HTML::HTML_EXTENSION);
       print $Contents qq{  <a href="$path">}, esc($name), "</a>&nbsp;&nbsp;\n";
     }
@@ -379,7 +379,7 @@ sub _write_contents_middle {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _write_contents_end {
-  my($self, $Contents, $outfile) = @_;
+  my($self, $Contents, $outfile) = < @_;
   unless(
     print $Contents "</dl>\n",
       $self->contents_page_end || '',
@@ -393,19 +393,19 @@ sub _write_contents_end {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _prep_contents_breakdown {
-  my($self) = @_;
+  my($self) = < @_;
   my $contents = $self->_contents;
   my %toplevel; # maps  lctoplevelbit => [all submodules]
   my %toplevel_form_freq; # ends up being  'foo' => 'Foo'
                                # (mapping anycase forms to most freq form)
   
-  foreach my $entry (@$contents) {
+  foreach my $entry (< @$contents) {
     my $toplevel = 
       $entry->[0] =~ m/^perl\w*$/ ? 'perl_core_docs'
           # group all the perlwhatever docs together
-      : $entry->[3][0] # normal case
+      : $entry->[3]->[0] # normal case
     ;
-    ++%toplevel_form_freq{ lc $toplevel }{ $toplevel };
+    ++%toplevel_form_freq{ lc $toplevel }->{ $toplevel };
     push @{ %toplevel{ lc $toplevel } }, $entry;
     push @$entry, lc($entry->[0]); # add a sort-order key to the end
   }
@@ -421,14 +421,13 @@ sub _prep_contents_breakdown {
     )[[0]];
   }
 
-  return(\%toplevel, \%toplevel_form_freq) if wantarray;
-  return \%toplevel;
+  return @(\%toplevel, \%toplevel_form_freq);
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _contents_filespec {
-  my($self, $outdir) = @_;
+  my($self, $outdir) = < @_;
   my $outfile = $self->contents_file;
   return unless $outfile;
   return $self->filespecsys->catfile( $outdir, $outfile );
@@ -437,9 +436,9 @@ sub _contents_filespec {
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
 sub makepath {
-  my($self, $outdir, $namelets) = @_;
-  return unless @$namelets +> 1;
-  for my $i (0 .. (@$namelets - 2)) {
+  my($self, $outdir, $namelets) = < @_;
+  return unless (nelems @$namelets) +> 1;
+  for my $i (0 .. ((nelems @$namelets) - 2)) {
     my $dir = $self->filespecsys->catdir( $outdir, @$namelets[[0 .. $i]] );
     if(-e $dir) {
       die "$dir exists but not as a directory!?" unless -d $dir;
@@ -457,15 +456,15 @@ sub makepath {
 
 sub batch_mode_page_object_init {
   my $self = shift;
-  my($page, $module, $infile, $outfile, $depth) = @_;
+  my($page, $module, $infile, $outfile, $depth) = < @_;
   
   # TODO: any further options to percolate onto this new object here?
 
   $page->default_title($module);
   $page->index( $self->index );
 
-  $page->html_css(        $self->       _css_wad_to_markup($depth) );
-  $page->html_javascript( $self->_javascript_wad_to_markup($depth) );
+  $page->html_css(         $self->       _css_wad_to_markup($depth) );
+  $page->html_javascript(  $self->_javascript_wad_to_markup($depth) );
 
   $self->add_header_backlink($page, $module, $infile, $outfile, $depth);
   $self->add_footer_backlink($page, $module, $infile, $outfile, $depth);
@@ -479,7 +478,7 @@ sub batch_mode_page_object_init {
 sub add_header_backlink {
   my $self = shift;
   return if $self->no_contents_links;
-  my($page, $module, $infile, $outfile, $depth) = @_;
+  my($page, $module, $infile, $outfile, $depth) = < @_;
   $page->html_header_after_title( join '',
     $page->html_header_after_title || '',
 
@@ -495,7 +494,7 @@ sub add_header_backlink {
 sub add_footer_backlink {
   my $self = shift;
   return if $self->no_contents_links;
-  my($page, $module, $infile, $outfile, $depth) = @_;
+  my($page, $module, $infile, $outfile, $depth) = < @_;
   $page->html_footer( join '',
     qq[<p class="backlinkbottom"><b><a name="___bottom" href="],
     $self->url_up_to_contents($depth),
@@ -509,7 +508,7 @@ sub add_footer_backlink {
 }
 
 sub url_up_to_contents {
-  my($self, $depth) = @_;
+  my($self, $depth) = < @_;
   --$depth;
   return join '/', ('..') x $depth, esc($self->contents_file);
 }
@@ -517,7 +516,7 @@ sub url_up_to_contents {
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
 sub find_all_pods {
-  my($self, $dirs) = @_;
+  my($self, $dirs) = < @_;
   # You can override find_all_pods in a subclass if you want to
   #  do extra filtering or whatnot.  But for the moment, we just
   #  pass to modnames2paths:
@@ -527,32 +526,32 @@ sub find_all_pods {
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
 
 sub modnames2paths { # return a hashref mapping modulenames => paths
-  my($self, $dirs) = @_;
+  my($self, $dirs) = < @_;
 
   my $m2p;
   {
     my $search = $SEARCH_CLASS->new;
     DEBUG and print "Searching via $search\n";
     $search->verbose(1) if DEBUG +> 10;
-    $search->progress( $self->progress->copy->goal(0) ) if $self->progress;
+    $search->progress( < $self->progress->copy->goal(0) ) if $self->progress;
     $search->shadows(0);  # don't bother noting shadowed files
     $search->inc(     $dirs ? 0      :  1 );
-    $search->survey(  $dirs ? @$dirs : () );
+    $search->survey(  $dirs ? < @$dirs : () );
     $m2p = $search->name2path;
     die "What, no name2path?!" unless $m2p;
   }
 
-  $self->muse("That's odd... no modules found!") unless keys %$m2p;
+  $self->muse("That's odd... no modules found!") unless %$m2p;
   if( DEBUG +> 4 ) {
     print "Modules found (name => path):\n";
     foreach my $m (sort {lc($a) cmp lc($b)} keys %$m2p) {
       print "  $m  %$m2p{$m}\n";
     }
-    print "(total ",     scalar(keys %$m2p), ")\n\n";
+    print "(total ",     nkeys %$m2p, ")\n\n";
   } elsif( DEBUG ) {
-    print      "Found ", scalar(keys %$m2p), " modules.\n";
+    print      "Found ", nkeys %$m2p, " modules.\n";
   }
-  $self->muse( "Found ", scalar(keys %$m2p), " modules." );
+  $self->muse( "Found ", nkeys %$m2p, " modules." );
   
   # return the Foo::Bar => /whatever/Foo/Bar.pod|pm hashref
   return $m2p;
@@ -562,7 +561,7 @@ sub modnames2paths { # return a hashref mapping modulenames => paths
 
 sub _wopen {
   # this is abstracted out so that the daemon class can override it
-  my($self, $outpath) = @_;
+  my($self, $outpath) = < @_;
   require Symbol;
   my $out_fh = Symbol::gensym();
   DEBUG +> 5 and print "Write-opening to $outpath\n";
@@ -574,7 +573,7 @@ sub _wopen {
 #==========================================================================
 
 sub add_css {
-  my($self, $url, $is_default, $name, $content_type, $media, $_code) = @_;
+  my($self, $url, $is_default, $name, $content_type, $media, $_code) = < @_;
   return unless $url;
   unless($name) {
     # cook up a reasonable name based on the URL
@@ -596,13 +595,13 @@ sub add_css {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _spray_css {
-  my($self, $outdir) = @_;
+  my($self, $outdir) = < @_;
 
   return unless $self->css_flurry();
   $self->_gen_css_wad();
 
   my $lol = $self->_css_wad;
-  foreach my $chunk (@$lol) {
+  foreach my $chunk (< @$lol) {
     my $url = $chunk->[0];
     my $outfile;
     if( ref($chunk->[-1]) and $url =~ m{^(_[-a-z0-9_]+\.css$)} ) {
@@ -628,10 +627,10 @@ sub _spray_css {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 sub _css_wad_to_markup {
-  my($self, $depth) = @_;
+  my($self, $depth) = < @_;
   
-  my @css  = @{ $self->_css_wad || return '' };
-  return '' unless @css;
+  my @css  = @( < @{ $self->_css_wad || return '' } );
+  return '' unless (nelems @css);
   
   my $rel = 'stylesheet';
   my $out = '';
@@ -639,12 +638,12 @@ sub _css_wad_to_markup {
   --$depth;
   my $uplink = $depth ? ('../' x $depth) : '';
 
-  foreach my $chunk (@css) {
-    next unless $chunk and @$chunk;
+  foreach my $chunk (< @css) {
+    next unless $chunk and nelems @$chunk;
 
     my( $url1, $url2, $title, $type, $media) = (
       $self->_maybe_uplink( $chunk->[0], $uplink ),
-      esc(grep !ref($_), @$chunk)
+      map { esc($_) } (grep !ref($_), < @$chunk)
     );
 
     $out .= qq{<link rel="$rel" title="$title" type="$type" href="$url1$url2" media="$media" >\n};
@@ -658,7 +657,7 @@ sub _css_wad_to_markup {
 sub _maybe_uplink {
   # if the given URL looks relative, return the given uplink string --
   # otherwise return emptystring
-  my($self, $url, $uplink) = @_;
+  my($self, $url, $uplink) = < @_;
   ($url =~ m{^\./} or $url !~ m{[/\:]} )
     ? $uplink
     : ''
@@ -696,9 +695,9 @@ sub _gen_css_wad {
   ]) {
 
     my $outname = $variation;
-    my($flipmode, @swap) = ( ($4 || ''), $1,$2,$3)
+    my($flipmode, < @swap) = ( ($4 || ''), $1,$2,$3)
       if $outname =~ s/^([012])([012])([[012])([a-z]*)=?//s;
-    @swap = () if '010' eq join '', @swap; # 010 is a swop-no-op!
+    @swap = @( () ) if '010' eq join '', < @swap; # 010 is a swop-no-op!
   
     my $this_css =
       "/* This file is autogenerated.  Do not edit.  $variation */\n\n"
@@ -710,8 +709,7 @@ sub _gen_css_wad {
       $this_css =~ s/\bthin\b/medium/g;
     }
     $this_css =~ s<#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])\b>
-                  <{ join '', '#', ($1,$2,$3)[[@swap]] 
-}>g   if @swap;
+                  |{ join '', '#', ($1,$2,$3)[[< @swap]] }|g   if (nelems @swap);
 
     if(   $flipmode =~ m/a/)
        { $this_css =~ s/#fff\b/#999/gi } # black -> dark grey
@@ -719,7 +717,7 @@ sub _gen_css_wad {
        { $this_css =~ s/#000\b/#666/gi } # white -> light grey
 
     my $name = $outname;    
-    $name =~ tr/-_/  /;
+    $name =~ s/-|_/ /g;
     $self->add_css( "_$outname.css", 0, $name, 0, 0, \$this_css);
   }
 
@@ -736,7 +734,7 @@ sub _gen_css_wad {
       "\n",
     ;
     my $name = $outname;    
-    $name =~ tr/-_/  /;
+    $name =~ s/-|_/ /g;
     $self->add_css( "_$outname.css", 0, $name, 0, 0, \$this_css);
   }
 
@@ -745,15 +743,15 @@ sub _gen_css_wad {
 
 sub _color_negate {
   my $x = lc @_[0];
-  $x =~ tr[0123456789abcdef]
-          [fedcba9876543210];
+  $x =~ s/([0123456789abcdef])/{ 
+     %( qw| 0 f 1 e 2 d 3 c 4 b 5 a 6 9 7 8 8 7 9 6 a 5 b 4 c 3 d 2 e 1 f 0 | ){$1} }/g;
   return $x;
 }
 
 #===========================================================================
 
 sub add_javascript {
-  my($self, $url, $content_type, $_code) = @_;
+  my($self, $url, $content_type, $_code) = < @_;
   return unless $url;
   push  @{ $self->_javascript_wad }, \@(
     $url, $content_type || 'text/javascript', $_code
@@ -762,12 +760,12 @@ sub add_javascript {
 }
 
 sub _spray_javascript {
-  my($self, $outdir) = @_;
+  my($self, $outdir) = < @_;
   return unless $self->javascript_flurry();
   $self->_gen_javascript_wad();
 
   my $lol = $self->_javascript_wad;
-  foreach my $script (@$lol) {
+  foreach my $script (< @$lol) {
     my $url = $script->[0];
     my $outfile;
     
@@ -799,22 +797,22 @@ sub _gen_javascript_wad {
 }
 
 sub _javascript_wad_to_markup {
-  my($self, $depth) = @_;
+  my($self, $depth) = < @_;
   
-  my @scripts  = @{ $self->_javascript_wad || return '' };
-  return '' unless @scripts;
+  my @scripts  = @( < @{ $self->_javascript_wad || return '' } );
+  return '' unless (nelems @scripts);
   
   my $out = '';
 
   --$depth;
   my $uplink = $depth ? ('../' x $depth) : '';
 
-  foreach my $s (@scripts) {
-    next unless $s and @$s;
+  foreach my $s (< @scripts) {
+    next unless $s and nelems @$s;
 
     my( $url1, $url2, $type, $media) = (
       $self->_maybe_uplink( $s->[0], $uplink ),
-      esc(grep !ref($_), @$s)
+      map { esc($_) } (grep !ref($_), < @$s)
     );
 
     $out .= qq{<script type="$type" src="$url1$url2"></script>\n};
