@@ -9,11 +9,11 @@ use Carp ();
 use Pod::Simple ();
 use vars qw( @ISA $VERSION );
 $VERSION = '2.02';
-@ISA = ('Pod::Simple');
+@ISA = @('Pod::Simple');
 
 sub new {
   my $self = shift;
-  my $new = $self->SUPER::new(@_);
+  my $new = $self->SUPER::new(< @_);
   $new->{'output_fh'} ||= *STDOUT{IO};
   $new->nix_X_codes(1);
   return $new;
@@ -22,19 +22,19 @@ sub new {
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 sub _handle_element_start {
-  print {@_[0]{'output_fh'}} "\n"  unless @_[1] =~ m/^[A-Z]$/s;
+  print {@_[0]->{'output_fh'}} "\n"  unless @_[1] =~ m/^[A-Z]$/s;
   return;
 }
 
 sub _handle_text {
-    @_[1] =~ tr/\x{AD}//d;
-    @_[1] =~ tr/\x{A0}/ /;
-    print {@_[0]{'output_fh'}} @_[1];
+    @_[1] =~ s/\x{AD}//g;
+    @_[1] =~ s/\x{A0}/ /g;
+    print {@_[0]->{'output_fh'}} @_[1];
     return;
 }
 
 sub _handle_element_end {
-  print {@_[0]{'output_fh'}} "\n"  unless @_[1] =~ m/^[A-Z]$/s;
+  print {@_[0]->{'output_fh'}} "\n"  unless @_[1] =~ m/^[A-Z]$/s;
   return;
 }
 
