@@ -9,20 +9,20 @@ $VERSION = '2.02';
 #  only for null-transcodings!  We use this when Encode isn't
 #  available.
 
-%Supported = (
+%Supported = %(
   'ascii'       => 1,
   'ascii-ctrl'  => 1,
   'utf8'  => 1,
   'null'        => 1,
   'latin1' => 1,
-  %Supported,
+  < %Supported,
 );
 
 sub is_dumb  {1}
 sub is_smart {0}
 
 sub all_encodings {
-  return sort keys %Supported;
+  return @( sort keys %Supported);
 }
 
 sub encoding_is_available {
@@ -38,7 +38,7 @@ sub make_transcoder {
   die "WHAT ENCODING!?!?" unless $e;
   my $x;
   if ($e eq "latin1") {
-      return sub { return map { join '', map { utf8::chr($_) } unpack "C*", $_; } @_ };
+      return sub { return @(map { join '', map { utf8::chr($_) } unpack "C*", $_; } < @_) };
   }
 
   return sub {;
