@@ -25,7 +25,7 @@ use strict;
 use vars qw(@ISA $VERSION);
 use utf8;
 
-@ISA = qw(Pod::Text);
+@ISA = @( qw(Pod::Text) );
 
 # Don't use the CVS revision as the version, since this module is also in Perl
 # core and too many things could munge CVS magic revision strings.  This
@@ -39,9 +39,9 @@ $VERSION = 2.03;
 # In the initialization method, grab our terminal characteristics as well as
 # do all the stuff we normally do.
 sub new {
-    my ($self, @args) = @_;
+    my ($self, < @args) = < @_;
     my ($ospeed, $term, $termios);
-    $self = $self->SUPER::new (@args);
+    $self = $self->SUPER::new (< @args);
 
     # $ENV{HOME} is usually not set on Windows.  The default Term::Cap path
     # may not work on Solaris.
@@ -51,7 +51,7 @@ sub new {
 
     # Fall back on a hard-coded terminal speed if POSIX::Termios isn't
     # available (such as on VMS).
-    eval { $termios = POSIX::Termios->new };
+    try { $termios = POSIX::Termios->new };
     if ($@) {
         $ospeed = 9600;
     } else {
@@ -60,7 +60,7 @@ sub new {
     }
 
     # Fall back on the ANSI escape sequences if Term::Cap doesn't work.
-    eval { $term = Term::Cap->Tgetent( \%( TERM => undef, OSPEED => $ospeed )) };
+    try { $term = Term::Cap->Tgetent( \%( TERM => undef, OSPEED => $ospeed )) };
     %$self{BOLD} = %$term{_md} || "\e[1m";
     %$self{UNDL} = %$term{_us} || "\e[4m";
     %$self{NORM} = %$term{_me} || "\e[m";
@@ -75,14 +75,14 @@ sub new {
 
 # Make level one headings bold.
 sub cmd_head1 {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     $text =~ s/\s+$//;
     $self->SUPER::cmd_head1 ($attrs, "%$self{BOLD}$text%$self{NORM}");
 }
 
 # Make level two headings bold.
 sub cmd_head2 {
-    my ($self, $attrs, $text) = @_;
+    my ($self, $attrs, $text) = < @_;
     $text =~ s/\s+$//;
     $self->SUPER::cmd_head2 ($attrs, "%$self{BOLD}$text%$self{NORM}");
 }
@@ -93,7 +93,7 @@ sub cmd_i { my $self = shift; return "%$self{UNDL}@_[1]%$self{NORM}" }
 
 # Output any included code in bold.
 sub output_code {
-    my ($self, $code) = @_;
+    my ($self, $code) = < @_;
     $self->output (%$self{BOLD} . $code . %$self{NORM});
 }
 
