@@ -33,8 +33,8 @@ The values are the original list elements.
 
 use strict;
 
-our @ISA = qw(Exporter);
-our @EXPORT = qw(abbrev);
+our @ISA = @( qw(Exporter) );
+our @EXPORT = @( qw(abbrev) );
 
 # Usage:
 #	abbrev \%foo, LIST;
@@ -44,17 +44,12 @@ our @EXPORT = qw(abbrev);
 sub abbrev {
     my ($word, $hashref, $glob, %table, $returnvoid);
 
-    @_ or return;   # So we don't autovivify onto @_ and trigger warning
-    if (ref(@_[0])) {           # hash reference preferably
-      $hashref = shift;
-      $returnvoid = 1;
-    } elsif (ref \@_[0] eq 'GLOB') {  # is actually a glob (deprecated)
-      $hashref = \%{shift()};
-      $returnvoid = 1;
-    }
-    %{$hashref} = ();
+    (nelems @_) or return;   # So we don't autovivify onto @_ and trigger warning
+    $hashref = shift;
+    $returnvoid = 1;
+    %{$hashref} = %( () );
 
-    WORD: foreach $word (@_) {
+    WORD: foreach $word (< @_) {
         for (my $len = (length $word) - 1; $len +> 0; --$len) {
 	    my $abbrev = substr($word,0,$len);
 	    my $seen = ++%table{$abbrev};
@@ -71,15 +66,11 @@ sub abbrev {
 	}
     }
     # Non-abbreviations always get entered, even if they aren't unique
-    foreach $word (@_) {
+    foreach $word (< @_) {
         $hashref->{$word} = $word;
     }
     return if $returnvoid;
-    if (wantarray) {
-      %{$hashref};
-    } else {
-      $hashref;
-    }
+    %{$hashref};
 }
 
 1;
