@@ -189,7 +189,7 @@ use warnings::register;
 
 sub new {
     my $pkg = shift;
-    $pkg->TIEHASH(@_);
+    $pkg->TIEHASH(< @_);
 }
 
 # Grandfather "new"
@@ -198,7 +198,7 @@ sub TIEHASH {
     my $pkg = shift;
     if (defined &{Symbol::fetch_glob("{$pkg}::new")}) {
 	warnings::warnif("WARNING: calling {$pkg}->new since {$pkg}->TIEHASH is missing");
-	$pkg->new(@_);
+	$pkg->new(< @_);
     }
     else {
 	die "$pkg doesn't define a TIEHASH method";
@@ -212,15 +212,15 @@ sub EXISTS {
 
 sub CLEAR {
     my $self = shift;
-    my $key = $self->FIRSTKEY(@_);
+    my $key = $self->FIRSTKEY(< @_);
     my @keys;
 
     while (defined $key) {
 	push @keys, $key;
-	$key = $self->NEXTKEY(@_, $key);
+	$key = $self->NEXTKEY(< @_, $key);
     }
-    foreach $key (@keys) {
-	$self->DELETE(@_, $key);
+    foreach $key (< @keys) {
+	$self->DELETE(< @_, $key);
     }
 }
 
@@ -234,23 +234,23 @@ package Tie::StdHash;
 sub TIEHASH  { bless \%(), @_[0] }
 sub STORE    { @_[0]->{@_[1]} = @_[2] }
 sub FETCH    { @_[0]->{@_[1]} }
-sub FIRSTKEY { my $a = scalar keys %{@_[0]}; each %{@_[0]} }
+sub FIRSTKEY { my $a = nelems(@( keys %{@_[0]})); each %{@_[0]} }
 sub NEXTKEY  { each %{@_[0]} }
 sub EXISTS   { exists @_[0]->{@_[1]} }
 sub DELETE   { delete @_[0]->{@_[1]} }
-sub CLEAR    { %{@_[0]} = () }
+sub CLEAR    { %{@_[0]} = %( () ) }
 sub SCALAR   { scalar %{@_[0]} }
 
 package Tie::ExtraHash;
 
-sub TIEHASH  { my $p = shift; bless \@(\%(), @_), $p }
-sub STORE    { @_[0][0]{@_[1]} = @_[2] }
-sub FETCH    { @_[0][0]{@_[1]} }
-sub FIRSTKEY { my $a = scalar keys %{@_[0][0]}; each %{@_[0][0]} }
-sub NEXTKEY  { each %{@_[0][0]} }
-sub EXISTS   { exists @_[0][0]->{@_[1]} }
-sub DELETE   { delete @_[0][0]->{@_[1]} }
-sub CLEAR    { %{@_[0][0]} = () }
-sub SCALAR   { scalar %{@_[0][0]} }
+sub TIEHASH  { my $p = shift; bless \@(\%(), < @_), $p }
+sub STORE    { @_[0]->[0]->{@_[1]} = @_[2] }
+sub FETCH    { @_[0]->[0]->{@_[1]} }
+sub FIRSTKEY { my $a = scalar keys %{@_[0]->[0]}; each %{@_[0]->[0]} }
+sub NEXTKEY  { each %{@_[0]->[0]} }
+sub EXISTS   { exists @_[0]->[0]->{@_[1]} }
+sub DELETE   { delete @_[0]->[0]->{@_[1]} }
+sub CLEAR    { %{@_[0]->[0]} = %( () ) }
+sub SCALAR   { scalar %{@_[0]->[0]} }
 
 1;
