@@ -4,23 +4,21 @@ package vars;
 our $VERSION = '1.01';
 
 use warnings::register;
-use strict;
-no strict 'refs';
 
 sub import {
     my $callpack = caller;
-    my ($pack, @imports) = @_;
+    my ($pack, < @imports) = < @_;
     my ($sym, $ch);
-    foreach (@imports) {
+    foreach (< @imports) {
         if (($ch, $sym) = m/^([\$\@\%\*\&])(.+)/) {
 	    if ($sym =~ m/\W/) {
 		# time for a more-detailed check-up
 		if ($sym =~ m/^\w+[[{].*[]}]$/) {
 		    die("Can't declare individual elements of hash or array");
-		} elsif (warnings::enabled() and length($sym) == 1 and $sym !~ tr/a-zA-Z//) {
+		} elsif (warnings::enabled() and length($sym) == 1 and $sym !~ m/[a-zA-Z]/) {
 		    warnings::warn("No need to declare built-in vars");
-		} elsif  (($^H ^&^= strict::bits('vars'))) {
-		    die("'$_' is not a valid variable name under strict vars");
+		} else {
+		    die("'$_' is not a valid variable name");
 		}
 	    }
 	    $sym = "{$callpack}::$sym" unless $sym =~ m/::/;
