@@ -246,6 +246,8 @@ package P5AST::op_sle; 		@ISA = 'P5AST::binop';
 package P5AST::op_sge; 		@ISA = 'P5AST::binop';
 package P5AST::op_seq; 		@ISA = 'P5AST::binop';
 package P5AST::op_sne; 		@ISA = 'P5AST::binop';
+package P5AST::op_ref_eq; 		@ISA = 'P5AST::binop';
+package P5AST::op_ref_ne; 		@ISA = 'P5AST::binop';
 package P5AST::op_scmp; 	@ISA = 'P5AST::binop';
 package P5AST::op_bit_and; 	@ISA = 'P5AST::binop';
 package P5AST::op_bit_xor; 	@ISA = 'P5AST::binop';
