@@ -161,6 +161,8 @@ S_mul128(pTHX_ SV *sv, U8 m)
   char           *s = SvPV(sv, len);
   char           *t;
 
+  PERL_ARGS_ASSERT_MUL128;
+
   if (!strnEQ(s, "0000", 4)) {  /* need to grow sv */
     SV * const tmpNew = newSVpvs("0000000000");
 
@@ -726,6 +728,8 @@ S_measure_struct(pTHX_ tempsym_t* symptr)
 {
     I32 total = 0;
 
+    PERL_ARGS_ASSERT_MEASURE_STRUCT;
+
     while (next_symbol(symptr)) {
 	I32 len;
 	int size;
@@ -835,6 +839,8 @@ S_measure_struct(pTHX_ tempsym_t* symptr)
 STATIC const char *
 S_group_end(pTHX_ register const char *patptr, register const char *patend, char ender)
 {
+    PERL_ARGS_ASSERT_GROUP_END;
+
     while (patptr < patend) {
 	const char c = *patptr++;
 
@@ -865,6 +871,9 @@ STATIC const char *
 S_get_num(pTHX_ register const char *patptr, I32 *lenptr )
 {
   I32 len = *patptr++ - '0';
+
+  PERL_ARGS_ASSERT_GET_NUM;
+
   while (isDIGIT(*patptr)) {
     if (len >= 0x7FFFFFFF/10)
       Perl_croak(aTHX_ "pack/unpack repeat count overflow");
@@ -883,6 +892,8 @@ S_next_symbol(pTHX_ tempsym_t* symptr )
   const char* patptr = symptr->patptr;
   const char* const patend = symptr->patend;
 
+  PERL_ARGS_ASSERT_NEXT_SYMBOL;
+
   symptr->flags &= ~FLAG_SLASH;
 
   while (patptr < patend) {
@@ -1063,6 +1074,8 @@ Perl_unpackstring(pTHX_ const char *pat, const char *patend, const char *s, cons
 {
     tempsym_t sym;
 
+    PERL_ARGS_ASSERT_UNPACKSTRING;
+
     TEMPSYM_INIT(&sym, pat, patend, flags);
 
     return unpack_rec(&sym, s, s, strend, NULL );
@@ -1075,7 +1088,6 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
     SV *sv;
     const I32 start_sp_offset = SP - PL_stack_base;
     howlen_t howlen;
-
     I32 checksum = 0;
     UV cuv = 0;
     NV cdouble = 0.0;
@@ -1084,6 +1096,9 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
     bool explicit_length;
     const bool unpack_only_one = (symptr->flags & FLAG_UNPACK_ONLY_ONE) != 0;
     bool utf8 = 0; /* (symptr->flags & FLAG_PARSE_UTF8) ? 1 : 0; */
+
+    PERL_ARGS_ASSERT_UNPACK_REC;
+
     symptr->strbeg = s - strbeg;
 
     while (next_symbol(symptr)) {
@@ -1148,6 +1163,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 	    symptr->previous = &savsym;
             symptr->level++;
 	    PUTBACK;
+	    if (len && unpack_only_one) len = 1;
 	    while (len--) {
   	        symptr->patptr = savsym.grpbeg;
 		if (utf8) symptr->flags |=  FLAG_PARSE_UTF8;
@@ -1183,7 +1199,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 	    sv = from <= s ?
 		newSVuv(  u8 ? (UV) utf8_length(from, s) : (UV) (s-from)) :
 		newSViv(-(u8 ? (IV) utf8_length(s, from) : (IV) (from-s)));
-	    XPUSHs(sv_2mortal(sv));
+	    mXPUSHs(sv);
 	    break;
 	}
 #ifdef PERL_PACK_CAN_SHRIEKSIGN
@@ -1327,7 +1343,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		sv = newSVpvn(s, ptr-s);
 	    } else sv = newSVpvn(s, len);
 
-	    XPUSHs(sv_2mortal(sv));
+	    mXPUSHs(sv);
 	    s += len;
 	    break;
 	case 'B':
@@ -1455,7 +1471,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		    aint -= 256;
 	      W_checksum:
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv((IV)aint)));
+		    mPUSHi(aint);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)aint;
 		else
@@ -1480,7 +1496,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		    Perl_croak(aTHX_ "Malformed UTF-8 string in unpack");
 		s += retlen;
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVuv((UV) auv)));
+		    mPUSHu(auv);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV) auv;
 		else
@@ -1494,7 +1510,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, ashort, datumtype);
 		DO_BO_UNPACK(ashort, s);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv((IV)ashort)));
+		    mPUSHi(ashort);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)ashort;
 		else
@@ -1518,7 +1534,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		    ai16 -= 65536;
 #endif
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv((IV)ai16)));
+		    mPUSHi(ai16);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)ai16;
 		else
@@ -1532,7 +1548,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, aushort, datumtype);
 		DO_BO_UNPACK(aushort, s);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVuv((UV) aushort)));
+		    mPUSHu(aushort);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)aushort;
 		else
@@ -1561,7 +1577,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		    au16 = vtohs(au16);
 #endif
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVuv((UV)au16)));
+		    mPUSHu(au16);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV) au16;
 		else
@@ -1586,7 +1602,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		    ai16 = (I16) vtohs((U16) ai16);
 # endif /* HAS_VTOHS */
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv((IV)ai16)));
+		    mPUSHi(ai16);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV) ai16;
 		else
@@ -1601,7 +1617,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, aint, datumtype);
 		DO_BO_UNPACK(aint, i);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv((IV)aint)));
+		    mPUSHi(aint);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)aint;
 		else
@@ -1615,7 +1631,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, auint, datumtype);
 		DO_BO_UNPACK(auint, i);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVuv((UV)auint)));
+		    mPUSHu(auint);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)auint;
 		else
@@ -1636,7 +1652,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		Perl_croak(aTHX_ "'j' not supported on this platform");
 #endif
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv(aiv)));
+		    mPUSHi(aiv);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)aiv;
 		else
@@ -1657,7 +1673,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		Perl_croak(aTHX_ "'J' not supported on this platform");
 #endif
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVuv(auv)));
+		    mPUSHu(auv);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)auv;
 		else
@@ -1671,7 +1687,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, along, datumtype);
 		DO_BO_UNPACK(along, l);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv((IV)along)));
+		    mPUSHi(along);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)along;
 		else
@@ -1693,7 +1709,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		if (ai32 > 2147483647) ai32 -= 4294967296;
 #endif
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv((IV)ai32)));
+		    mPUSHi(ai32);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)ai32;
 		else
@@ -1707,7 +1723,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, aulong, datumtype);
 		DO_BO_UNPACK(aulong, l);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVuv((UV)aulong)));
+		    mPUSHu(aulong);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)aulong;
 		else
@@ -1736,7 +1752,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		    au32 = vtohl(au32);
 #endif
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVuv((UV)au32)));
+		    mPUSHu(au32);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)au32;
 		else
@@ -1761,7 +1777,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		    ai32 = (I32)vtohl((U32)ai32);
 # endif
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSViv((IV)ai32)));
+		    mPUSHi(ai32);
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)ai32;
 		else
@@ -1775,7 +1791,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, aptr, datumtype);
 		DO_BO_UNPACK_PC(aptr);
 		/* newSVpv generates undef if aptr is NULL */
-		PUSHs(sv_2mortal(newSVpv(aptr, 0)));
+		mPUSHs(newSVpv(aptr, 0));
 	    }
 	    break;
 	case 'w':
@@ -1790,7 +1806,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		    /* UTF8_IS_XXXXX not right here - using constant 0x80 */
 		    if (ch < 0x80) {
 			bytes = 0;
-			PUSHs(sv_2mortal(newSVuv(auv)));
+			mPUSHu(auv);
 			len--;
 			auv = 0;
 			continue;
@@ -1811,7 +1827,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 			while (*t == '0')
 			    t++;
 			sv_chop(sv, t);
-			PUSHs(sv_2mortal(sv));
+			mPUSHs(sv);
 			len--;
 			auv = 0;
 		    }
@@ -1829,7 +1845,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, aptr, datumtype);
 		DO_BO_UNPACK_PC(aptr);
 		/* newSVpvn generates undef if aptr is NULL */
-		PUSHs(sv_2mortal(newSVpvn(aptr, len)));
+		PUSHs(newSVpvn_flags(aptr, len, SVs_TEMP));
 	    }
 	    break;
 #ifdef HAS_QUAD
@@ -1839,8 +1855,8 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, aquad, datumtype);
 		DO_BO_UNPACK(aquad, 64);
 		if (!checksum)
-                    PUSHs(sv_2mortal(aquad >= IV_MIN && aquad <= IV_MAX ?
-				     newSViv((IV)aquad) : newSVnv((NV)aquad)));
+                    mPUSHs(aquad >= IV_MIN && aquad <= IV_MAX ?
+			   newSViv((IV)aquad) : newSVnv((NV)aquad));
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)aquad;
 		else
@@ -1853,8 +1869,8 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, auquad, datumtype);
 		DO_BO_UNPACK(auquad, 64);
 		if (!checksum)
-		    PUSHs(sv_2mortal(auquad <= UV_MAX ?
-				     newSVuv((UV)auquad):newSVnv((NV)auquad)));
+		    mPUSHs(auquad <= UV_MAX ?
+			   newSVuv((UV)auquad) : newSVnv((NV)auquad));
 		else if (checksum > bits_in_uv)
 		    cdouble += (NV)auquad;
 		else
@@ -1869,7 +1885,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, afloat, datumtype);
 		DO_BO_UNPACK_N(afloat, float);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVnv((NV)afloat)));
+		    mPUSHn(afloat);
 		else
 		    cdouble += afloat;
 	    }
@@ -1880,7 +1896,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, adouble, datumtype);
 		DO_BO_UNPACK_N(adouble, double);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVnv((NV)adouble)));
+		    mPUSHn(adouble);
 		else
 		    cdouble += adouble;
 	    }
@@ -1891,7 +1907,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, anv, datumtype);
 		DO_BO_UNPACK_N(anv, NV);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVnv(anv)));
+		    mPUSHn(anv);
 		else
 		    cdouble += anv;
 	    }
@@ -1903,7 +1919,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		SHIFT_VAR(s, strend, aldouble, datumtype);
 		DO_BO_UNPACK_N(aldouble, long double);
 		if (!checksum)
-		    PUSHs(sv_2mortal(newSVnv((NV)aldouble)));
+		    mPUSHn(aldouble);
 		else
 		    cdouble += aldouble;
 	    }
@@ -1976,7 +1992,7 @@ S_unpack_rec(pTHX_ tempsym_t* symptr, const char *s, const char *strbeg, const c
 		}
 		sv = newSVuv(cuv);
 	    }
-	    XPUSHs(sv_2mortal(sv));
+	    mXPUSHs(sv);
 	    checksum = 0;
 	}
 
@@ -2067,6 +2083,8 @@ S_is_an_int(pTHX_ const char *s, STRLEN l)
   bool skip = 1;
   bool ignore = 0;
 
+  PERL_ARGS_ASSERT_IS_AN_INT;
+
   while (*s) {
     switch (*s) {
     case ' ':
@@ -2115,6 +2133,8 @@ S_div128(pTHX_ SV *pnum, bool *done)
     char *t = s;
     int m = 0;
 
+    PERL_ARGS_ASSERT_DIV128;
+
     *done = 1;
     while (*t) {
 	const int i = m * 10 + (*t - '0');
@@ -2144,6 +2164,8 @@ Perl_packlist(pTHX_ SV *cat, const char *pat, const char *patend, register SV **
     dVAR;
     tempsym_t sym;
 
+    PERL_ARGS_ASSERT_PACKLIST;
+
     TEMPSYM_INIT(&sym, pat, patend, FLAG_PACK);
 
     /* We're going to do changes through SvPVX(cat). Make sure it's valid.
@@ -2164,6 +2186,9 @@ S_sv_exp_grow(pTHX_ SV *sv, STRLEN needed) {
     const STRLEN cur = SvCUR(sv);
     const STRLEN len = SvLEN(sv);
     STRLEN extend;
+
+    PERL_ARGS_ASSERT_SV_EXP_GROW;
+
     if (len - cur > needed) return SvPVX(sv);
     extend = needed > len ? needed : len;
     return SvGROW(sv, len+extend+1);
@@ -2180,6 +2205,8 @@ S_pack_rec(pTHX_ SV *cat, tempsym_t* symptr, SV **beglist, SV **endlist )
     bool utf8 = (symptr->flags & FLAG_PARSE_UTF8) ? 1 : 0;
     bool warn_utf8 = ckWARN(WARN_UTF8);
 
+    PERL_ARGS_ASSERT_PACK_REC;
+
     symptr->strbeg = SvCUR(cat);
 
     while (found) {
@@ -2230,7 +2257,7 @@ S_pack_rec(pTHX_ SV *cat, tempsym_t* symptr, SV **beglist, SV **endlist )
 			       by copying it to a temporary.  */
 			    STRLEN len;
 			    const char *const pv = SvPV_const(*beglist, len);
-			    SV *const temp = sv_2mortal(newSVpvn(pv, len));
+			    SV *const temp = newSVpvn_flags(pv, len, SVs_TEMP);
 			    *beglist = temp;
 			}
 			count = sv_len(*beglist);
@@ -2627,11 +2654,14 @@ S_pack_rec(pTHX_ SV *cat, tempsym_t* symptr, SV **beglist, SV **endlist )
 		   any OS that needs it, or removed if and when VOS implements
 		   posix-976 (suggestion to support mapping to infinity).
 		   Paul.Green@stratus.com 02-04-02.  */
+{
+extern const float _float_constants[];
 		if (anv > FLT_MAX)
 		    afloat = _float_constants[0];   /* single prec. inf. */
 		else if (anv < -FLT_MAX)
 		    afloat = _float_constants[0];   /* single prec. inf. */
 		else afloat = (float) anv;
+}
 #else /* __VOS__ */
 # if defined(VMS) && !defined(__IEEE_FP)
 		/* IEEE fp overflow shenanigans are unavailable on VAX and optional
@@ -2663,11 +2693,14 @@ S_pack_rec(pTHX_ SV *cat, tempsym_t* symptr, SV **beglist, SV **endlist )
 		   for any OS that needs it, or removed if and when VOS
 		   implements posix-976 (suggestion to support mapping to
 		   infinity).  Paul.Green@stratus.com 02-04-02.  */
+{
+extern const double _double_constants[];
 		if (anv > DBL_MAX)
 		    adouble = _double_constants[0];   /* double prec. inf. */
 		else if (anv < -DBL_MAX)
 		    adouble = _double_constants[0];   /* double prec. inf. */
 		else adouble = (double) anv;
+}
 #else /* __VOS__ */
 # if defined(VMS) && !defined(__IEEE_FP)
 		/* IEEE fp overflow shenanigans are unavailable on VAX and optional
