@@ -17,7 +17,7 @@ require 'regen_lib.pl';
 # changes.  Um, what ?
 # safer_unlink ("warnings.h", "lib/warnings.pm");
 
-my %gen = (
+my %gen = %(
 	   'autodoc.pl'  => \@(qw[pod/perlapi.pod pod/perlintern.pod]),
 	   'embed.pl'    => \@(qw[proto.h embed.h embedvar.h global.sym
 				perlapi.h perlapi.c]),
@@ -32,7 +32,7 @@ my %gen = (
 sub do_cksum {
     my $pl = shift;
     my %cksum;
-    for my $f (@{ %gen{$pl} }) {
+    for my $f (< @{ %gen{$pl} }) {
 	local *FH;
 	if (open(FH, "<", $f)) {
 	    local $/;
@@ -49,16 +49,16 @@ foreach my $pl (qw (keywords.pl opcode.pl embed.pl
 		    regcomp.pl warnings.pl autodoc.pl reentr.pl)) {
   print "$^X $pl\n";
   my %cksum0;
-  %cksum0 = do_cksum($pl) unless $pl eq 'warnings.pl'; # the files were removed
+  %cksum0 = %( < do_cksum($pl) ) unless $pl eq 'warnings.pl'; # the files were removed
   system "$^X $pl";
   next if $pl eq 'warnings.pl'; # the files were removed
-  my %cksum1 = do_cksum($pl);
+  my %cksum1 = %( < do_cksum($pl) );
   my @chg;
-  for my $f (@{ %gen{$pl} }) {
+  for my $f (< @{ %gen{$pl} }) {
       push(@chg, $f)
 	  if !defined(%cksum0{$f}) ||
 	     !defined(%cksum1{$f}) ||
 	     %cksum0{$f} ne %cksum1{$f};
   }
-  print "Changed: @chg\n" if @chg;
+  print "Changed: {join ' ', <@chg}\n" if (nelems @chg);
 }
