@@ -2,7 +2,7 @@ package Moped::Msg;
 use strict;
 use vars qw(@ISA $VERSION);
 require DynaLoader;
-@ISA = qw(DynaLoader);
+@ISA = @( qw(DynaLoader) );
 $VERSION = '0.01';
  Moped::Msg->bootstrap();
 1;
