@@ -21,22 +21,22 @@ my $tmpfile = "tmp0000";
 1 while -e ++$tmpfile;
 END { 1 while unlink $tmpfile }
 
-my @prgs = () ;
-my @w_files = () ;
+my @prgs = @( () ) ;
+my @w_files = @( () ) ;
 
-if (@ARGV)
-  { print "ARGV = [@ARGV]\n" ;
+if ((nelems @ARGV))
+  { print "ARGV = [{join ' ', <@ARGV}]\n" ;
     if ($Is_MacOS) {
-      @w_files = map { s#^#:lib:$pragma_name:#; $_ } @ARGV
+      @w_files = @( map { s#^#:lib:$pragma_name:#; $_ } < @ARGV )
     } else {
-      @w_files = map { s#^#./lib/$pragma_name/#; $_ } @ARGV
+      @w_files = @( map { s#^#./lib/$pragma_name/#; $_ } < @ARGV )
     }
   }
 else
-  { @w_files = sort glob(catfile(curdir(), "lib", $pragma_name, "*")) }
+  { @w_files = @( sort <glob(catfile(curdir(), "lib", $pragma_name, "*")) ) }
 
 my $files = 0;
-foreach my $file (@w_files) {
+foreach my $file (< @w_files) {
 
     next if $file =~ m/(~|\.orig|\.got|,v)$/;
     next if $file =~ m/perlio$/ && !('PerlIO::Layer'->find( 'perlio'));
@@ -55,18 +55,18 @@ foreach my $file (@w_files) {
     {
         local $/ = undef;
         $files++;
-        @prgs = (@prgs, $file, split "\n########\n", ~< *F) ;
+        @prgs = @(< @prgs, $file, split "\n########\n", ~< *F) ;
     }
     close F ;
 }
 
 undef $/;
 
-plan tests => (scalar(@prgs)-$files);
+plan tests => (scalar(nelems @prgs)-$files);
 
 my $out_file;
 my $file;
-for (@prgs){
+for (< @prgs){
     unless (m/\n/)
      {
       print "# From $_\n";
@@ -80,10 +80,10 @@ for (@prgs){
      }
     my $src = $_;
     my $switch = "";
-    my @temps = () ;
-    my @temp_path = () ;
-    if (s/^\s*-\w+//){
-        $switch = $&;
+    my @temps = @( () ) ;
+    my @temp_path = @( () ) ;
+    if (s/^(\s*-\w+)//){
+        $switch = $1;
     }
     my($prog,$expected) = split(m/\nEXPECT(?:\n|$)/, $_, 2);
 
@@ -99,12 +99,12 @@ for (@prgs){
 	$todo_reason = $temp;
     }
     if ( $prog =~ m/--FILE--/) {
-        my(@files) = split(m/\n--FILE--\s*([^\s\n]*)\s*\n/, $prog) ;
+        my(@files) = @( split(m/\n--FILE--\s*([^\s\n]*)\s*\n/, $prog) ) ;
 	shift @files ;
 	die "Internal error: test $_ didn't split into pairs, got " .
-		scalar(@files) . "[" . join("\%\%\%\%", @files) ."]\n"
-	    if @files % 2 ;
-	while (@files +> 2) {
+		scalar(nelems @files) . "[" . join("\%\%\%\%", < @files) ."]\n"
+	    if (nelems @files) % 2 ;
+	while ((nelems @files) +> 2) {
 	    my $filename = shift @files ;
 	    my $code = shift @files ;
     	    push @temps, $filename ;
@@ -207,9 +207,9 @@ for (@prgs){
     our $TODO = $todo ? $todo_reason : 0;
     ok($ok);
 
-    foreach (@temps)
+    foreach (< @temps)
 	{ unlink $_ if $_ }
-    foreach (@temp_path)
+    foreach (< @temp_path)
 	{ rmtree $_ if -d $_ }
 }
 
@@ -218,15 +218,15 @@ sub randomMatch
     my $got = shift ;
     my $expected = shift;
 
-    my @got = sort split "\n", $got ;
-    my @expected = sort split "\n", $expected ;
+    my @got = @( sort split "\n", $got ) ;
+    my @expected = @( sort split "\n", $expected ) ;
 
-   return "@got" eq "@expected";
+   return "{join ' ', <@got}" eq "{join ' ', <@expected}";
 
 }
 
 sub print_err_line {
-    my($switch, $prog, $expected, $results, $todo) = @_;
+    my($switch, $prog, $expected, $results, $todo) = < @_;
     my $err_line = "FILE: $file\n" .
                    "PROG: $switch\n$prog\n" .
 		   "EXPECTED:\n$expected\n" .
