@@ -11,7 +11,7 @@ BEGIN
     # use Test::NoWarnings, if available
     my $extra = 0 ;
     $extra = 1
-        if eval { require Test::NoWarnings ;  'Test::NoWarnings'->import(); 1 };
+        if try { require Test::NoWarnings ;  'Test::NoWarnings'->import(); 1 };
 
     plan tests => 49 + $extra ;
 }
@@ -137,11 +137,11 @@ EOM
         # Skip to the flush point -- no-op for plain file
         my $status = $k->inflateSync();
         is $status, 1 
-            or diag $k->error() ;
+            or diag < $k->error() ;
      
         my $rest; 
         is $k->read($rest, length($hello)), length($hello)
-            or diag $k->error() ;
+            or diag < $k->error() ;
         ok $rest eq $hello ;
 
         ok $k->close();
@@ -180,12 +180,12 @@ EOM
         # Skip to the flush point
         $status = $k->inflateSync();
         is $status, 1, "   inflateSync returned 1"
-            or diag $k->error() ;
+            or diag < $k->error() ;
      
         my $rest; 
         is $k->read($rest, length($hello) + length($goodbye)), 
                 length($goodbye)
-            or diag $k->error() ;
+            or diag < $k->error() ;
         ok $rest eq $goodbye, " got expected output" ;
 
         ok $k->close();
@@ -217,7 +217,7 @@ EOM
         # Skip to the flush point
         $status = $k->inflateSync();
         is $status, 0 
-            or diag $k->error() ;
+            or diag < $k->error() ;
      
         ok $k->close();
         is $k->inflateSync(), 0 ;
