@@ -26,25 +26,25 @@ Typically, it is invoked as:
 
 use strict;
 
-my ($ext1, $ext2) = map {quotemeta} grep {!m/^--/} @ARGV;
-my %opts = (
+my ($ext1, $ext2) = map {quotemeta} grep {!m/^--/} < @ARGV;
+my %opts = %(
   #defaults
     'verbose' => 0,
     'recurse' => 1,
     'dummy' => 0,
     'say-subdir' => 0,
   #options itself
-    (map {m/^--([\-_\w]+)=(.*)$/} @ARGV),                            # --opt=smth
-    (map {m/^no-?(.*)$/i?($1=>0):($_=>1)} map {m/^--([\-_\w]+)$/} @ARGV),  # --opt --no-opt --noopt
+    (map {m/^--([\-_\w]+)=(.*)$/} < @ARGV),                            # --opt=smth
+    (map {m/^no-?(.*)$/i?($1=>0):($_=>1)} map {m/^--([\-_\w]+)$/} < @ARGV),  # --opt --no-opt --noopt
   );
 
 my $sp = '';
 sub xx {
   opendir DIR, '.';
-  my @t = readdir DIR;
-  my @f = map {m/^(.*)\.$ext1$/i} @t;
-  my %f = map {lc($_)=>$_} map {m/^(.*)\.$ext2$/i} @t;
-  for (@f) {
+  my @t = @( readdir DIR );
+  my @f = @( map {m/^(.*)\.$ext1$/i} < @t );
+  my %f = %( map {lc($_)=>$_} map {m/^(.*)\.$ext2$/i} < @t );
+  for (< @f) {
     my $lc = lc($_);
     if (exists %f{$lc} and %f{$lc} ne $_) {
       print STDERR "$sp%f{$lc}.$ext2 <==> $_.$ext1\n" if %opts{verbose};
@@ -57,7 +57,7 @@ sub xx {
     }
   }
   if (%opts{recurse}) {
-    for (grep {-d&&!m/^\.\.?$/} @t) {
+    for (grep {-d&&!m/^\.\.?$/} < @t) {
       print STDERR "$sp\\$_\n" if %opts{'say-subdir'};
       $sp .= ' ';
       chdir $_ or die;
